@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: H00_lurker.c,v 1.1 2001/09/27 19:07:40 alor Exp $
+    $Id: H00_lurker.c,v 1.2 2002/02/10 10:07:00 alor Exp $
 */
 
 #include <stdlib.h>
@@ -68,8 +68,11 @@ int lurker(void *buffer)              // very lame searching...
    ETH_header *eth;
    char IPS[16];
    char IPD[16];
+   RAW_PACKET *pck_raw;
 
-   eth = (ETH_header *) buffer;
+   pck_raw = (RAW_PACKET *)buffer;
+
+   eth = (ETH_header *) pck_raw->buffer;
    if ( ntohs(eth->type) == ETH_P_IP )
    {
       ip = (IP_header *)(eth+1);
