@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: H10_phantom.c,v 1.2 2001/10/16 19:56:00 alor Exp $
+    $Id: H10_phantom.c,v 1.4 2002/02/10 10:07:01 alor Exp $
 */
 
 #include <stdlib.h>
@@ -124,7 +124,7 @@ char * dns_spoof_ptr(const char *name);
 struct plugin_ops ops = {
    ettercap_version: VERSION,
    plug_info:        "Sniff/Spoof DNS requests",
-   plug_version:     20,
+   plug_version:     21,
    plug_type:        PT_HOOK,
    hook_point:       PCK_RECEIVED_RAW,
    hook_function:    &Parse_Packet,
@@ -233,8 +233,11 @@ int Parse_Packet(void *buffer)
    char activity[50];
    char answer[100];
    char query[100];
+   RAW_PACKET *pck_raw;
 
-   eth = (ETH_header *) buffer;
+   pck_raw = (RAW_PACKET *)buffer;
+
+   eth = (ETH_header *) pck_raw->buffer;
    if (eth->type == htons(ETH_P_IP))
    {
       ip = (IP_header *)(eth+1);
@@ -412,14 +415,14 @@ int Load_DNS_entries(void)
    fto = fopen( "./" DNS_FILE, "r");
    if (fto == NULL)
    {
-      fto = fopen( DATA_PATH DNS_FILE, "r");
+      fto = fopen( DATA_PATH "/" DNS_FILE, "r");
       if (fto == NULL)
       {
          Plugin_Hook_Output("\nCan't find " DNS_FILE " in ./ or " DATA_PATH);
          return 1;
       }
       else
-         Plugin_Hook_Output("\nLoading DNS entries from " DATA_PATH DNS_FILE "...\n\n");
+         Plugin_Hook_Output("\nLoading DNS entries from " DATA_PATH "/" DNS_FILE "...\n\n");
    }
    else
       Plugin_Hook_Output("\nLoading DNS entries from ./" DNS_FILE "...\n\n");
