@@ -18,7 +18,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: basilisk.c,v 1.2 2001/09/11 21:03:06 alor Exp $
+    $Id: basilisk.c,v 1.3 2001/09/27 19:07:40 alor Exp $
 */
 
 #include <stdlib.h>
@@ -33,19 +33,38 @@
 #include "../../src/include/ec_inet_forge.h"
 
 
-char Ettercap_Version[] = VERSION;                       // required -- for compatibility
-
-char PlugIn_Info[] = "Checks if the poisoning had success";
-
-short PlugIn_Version = 10;
-
 // protos...
 
-void PlugIn_Start(char**argv);
+int Plugin_Init(void *);
+int Plugin_Fini(void *);
+int basilisk(void *dummy);
 
-// ---------------------------
+// plugin operation
 
-void PlugIn_Start(char**argv)
+struct plugin_ops ops = {
+   ettercap_version: VERSION,
+   plug_info:        "Checks if the poisoning had success",
+   plug_version:     10,
+   plug_type:        PT_EXT,
+   hook_point:       HOOK_NONE,
+   hook_function:    &basilisk,
+};
+
+//==================================
+
+int Plugin_Init(void *params)
+{
+   return Plugin_Register(params, &ops);
+}
+
+int Plugin_Fini(void *params)
+{
+   return 0;
+}
+
+// =================================
+
+int basilisk(void *dummy)
 {
    int sock, MTU, len=0, hnumb, i, j, notrecv=1;
    char *ReceivedS, *ReceivedD, *MACHosts, *pck;
@@ -61,13 +80,13 @@ void PlugIn_Start(char**argv)
    if ( number_of_connections == -1 )
    {
       Plugin_Output("\nYou have to use this plugin during an ARPBased poisoning session\n");
-      return;
+      return 0;
    }
 
    if ( !strcmp(Host_Source.ip, "") && !strcmp(Host_Dest.ip, "") )
    {
       Plugin_Output("\nYou have to select at least either source or dest ip.\n");
-      return;
+      return 0;
    }
 
    sock = Inet_OpenRawSock(Options.netiface);
@@ -214,6 +233,7 @@ void PlugIn_Start(char**argv)
    free(ReceivedS);
    free(ReceivedD);
    free(MACHosts);
+   return 0;
 }
 
 /* EOF */
