@@ -27,19 +27,39 @@
 #include "../../src/include/ec_inet.h"
 #include "../../src/include/ec_inet_forge.h"
 
-char Ettercap_Version[] = VERSION;                       // required -- for compatibility
-
-char PlugIn_Info[] = "Find connections on a switched LAN";
-
-short PlugIn_Version = 11;
 
 // protos...
 
-void PlugIn_Start(char**argv);
+int Plugin_Init(void *);
+int Plugin_Fini(void *);
+int beholder(void *dummy);
 
-//--------------------------
+// plugin operation
 
-void PlugIn_Start(char**argv)
+struct plugin_ops ops = {
+   ettercap_version: VERSION,
+   plug_info:        "Find connections on a switched LAN",
+   plug_version:     11,
+   plug_type:        PT_EXT,
+   hook_point:       HOOK_NONE,
+   hook_function:    &beholder,
+};
+
+//==================================
+
+int Plugin_Init(void *params)
+{
+   return Plugin_Register(params, &ops);
+}
+
+int Plugin_Fini(void *params)
+{
+   return 0;
+}
+
+// =================================
+
+int beholder(void *dummy)
 {
    int MTU, sock;
    char *recv_pck;
@@ -89,7 +109,7 @@ void PlugIn_Start(char**argv)
       {
          Inet_Forge_packet_destroy( recv_pck );
          Inet_CloseRawSock(sock);
-         return;
+         return 0;
       }
    }
 }
