@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: imp.c,v 1.3 2001/09/10 16:41:33 alor Exp $
+    $Id: imp.c,v 1.4 2001/09/27 19:07:40 alor Exp $
 */
 
 #include <unistd.h>
@@ -32,18 +32,37 @@
 #include "../../src/include/ec_inet.h"
 #include "../../src/include/ec_inet_forge.h"
 
-char Ettercap_Version[] = VERSION;                       // required -- for compatibility
-
-char PlugIn_Info[] = "Retrieves some Windows names";     // required -- a little description (max 50 char)
-
-short PlugIn_Version = 12;                               // required -- the version ( 10 will be displayed as 1.0 )
-
 // protos...
 
+int Plugin_Init(void *);
+int Plugin_Fini(void *);
+int imp_function(void *dummy);
 void toggle( char *spacer);
-void PlugIn_Start(char**argv);
 
-//---------------------------
+// plugin operation
+
+struct plugin_ops ops = {
+   ettercap_version: VERSION,
+   plug_info:        "Retrieves some Windows names",
+   plug_version:     12,
+   plug_type:        PT_EXT,
+   hook_point:       HOOK_NONE,
+   hook_function:    &imp_function,
+};
+
+//==================================
+
+int Plugin_Init(void *params)
+{
+   return Plugin_Register(params, &ops);
+}
+
+int Plugin_Fini(void *params)
+{
+   return 0;
+}
+
+// =================================
 
 void toggle( char *spacer)
 {
@@ -56,7 +75,7 @@ void toggle( char *spacer)
       }
 }
 
-void PlugIn_Start(char**argv)                            // required -- the Entry point
+int imp_function(void *dummy)
 {
    int sock, i, MTU, reply=0;
    char dgram[]="\x01\xF8\x00\x10\x00\x01\x00\x00\x00\x00\x00\x00\x20"
@@ -73,13 +92,13 @@ void PlugIn_Start(char**argv)                            // required -- the Entr
    if (!strcmp(Host_Dest.ip, ""))
    {
       Plugin_Output("\nNo destination host selected !!\n");
-      return;
+      return 0;
    }
 
    if (!strcmp(Host_Dest.ip, Inet_MyIPAddress()))
    {
       Plugin_Output("\nThis plugin doesn't work on myself !!\n");
-      return;
+      return 0;
    }
 
    Plugin_Output("\nTry to retrieve some Windows names from %s...\n", Host_Dest.ip);
@@ -143,7 +162,7 @@ void PlugIn_Start(char**argv)                            // required -- the Entr
    {
       Plugin_Output("\nNo replies within 3 seconds!!! (host could be down)\n");
       Inet_Forge_packet_destroy(buf);
-      return;
+      return 0;
    }
 
    answers=parser[56];
@@ -152,7 +171,7 @@ void PlugIn_Start(char**argv)                            // required -- the Entr
    {
       Plugin_Output("No name in the answer....\n");
       Inet_Forge_packet_destroy(buf);
-      return;
+      return 0;
    }
 
    answers--;
@@ -180,6 +199,7 @@ void PlugIn_Start(char**argv)                            // required -- the Entr
 
    Inet_Forge_packet_destroy(buf);
    free(names);
+   return 0;
 }
 
 /* EOF */
