@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ooze.c,v 1.2 2001/08/31 13:32:28 alor Exp $
+    $Id: ooze.c,v 1.3 2001/09/27 19:07:40 alor Exp $
 */
 
 
@@ -33,19 +33,38 @@
 #include "../../src/include/ec_inet.h"
 #include "../../src/include/ec_inet_forge.h"
 
-char Ettercap_Version[] = VERSION;                       // required -- for compatibility
-
-char PlugIn_Info[] = "Ping a host.";
-
-short PlugIn_Version = 14;
-
 // protos...
 
-void PlugIn_Start(char**argv);
+int Plugin_Init(void *);
+int Plugin_Fini(void *);
+int ooze_function(void *dummy);
 
-//--------------------
+// plugin operation
 
-void PlugIn_Start(char**argv)
+struct plugin_ops ops = {
+   ettercap_version: VERSION,
+   plug_info:        "Ping a host",
+   plug_version:     14,
+   plug_type:        PT_EXT,
+   hook_point:       HOOK_NONE,
+   hook_function:    &ooze_function,
+};
+
+//==================================
+
+int Plugin_Init(void *params)
+{
+   return Plugin_Register(params, &ops);
+}
+
+int Plugin_Fini(void *params)
+{
+   return 0;
+}
+
+// =================================
+
+int ooze_function(void *dummy)
 {
    char *buf;
    int sock, MTU, i, reply=0;
@@ -60,13 +79,13 @@ void PlugIn_Start(char**argv)
    if (!strcmp(Host_Dest.ip, ""))
    {
       Plugin_Output("\nNo destination host selected !!\n");
-      return;
+      return 0;
    }
 
    if (!strcmp(Host_Dest.ip, Inet_MyIPAddress()))
    {
       Plugin_Output("\nThis plugin doesn't work on myself !!\n");
-      return;
+      return 0;
    }
 
    Plugin_Output("\nHow many ping ? ");
@@ -78,7 +97,7 @@ void PlugIn_Start(char**argv)
    Inet_GetIfaceInfo(Options.netiface, &MTU, NULL, NULL, NULL);
 
    Inet_GetMACfromString(Inet_MyMACAddress(), MyMAC);
-   //Inet_GetMACfromString(Host_Dest.mac, DestMAC);
+
    memcpy (DestMAC, Inet_MacFromIP(inet_addr(Host_Dest.ip)), 6);
 
    strncpy(MyIP,Inet_MyIPAddress(),16);
@@ -146,6 +165,8 @@ void PlugIn_Start(char**argv)
    if (!reply) Plugin_Output("\nNo replies within 3 seconds !! (host could be down)\n");
 
    Inet_CloseRawSock(sock);
+
+   return 0;
 }
 
 /* EOF */
