@@ -18,7 +18,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: triton.c,v 1.3 2001/09/15 15:29:03 alor Exp $
+    $Id: triton.c,v 1.4 2001/09/27 19:07:40 alor Exp $
 */
 
 #include <stdlib.h>
@@ -32,21 +32,40 @@
 #include "../../src/include/ec_inet.h"
 #include "../../src/include/ec_inet_forge.h"
 
-char Ettercap_Version[] = VERSION;                       // required -- for compatibility
-
-char PlugIn_Info[] = "Try to discover the LAN's gateway";
-
-short PlugIn_Version = 21;
-
 #define NON_LOCAL_IP  "216.136.171.201"     // we need a good non local ip (ettercap.sourceforge.net)
 
 // protos...
 
-void PlugIn_Start(char**argv);
+int Plugin_Init(void *);
+int Plugin_Fini(void *);
+int triton_function(void *dummy);
 
-// ---------------------------
+// plugin operation
 
-void PlugIn_Start(char**argv)
+struct plugin_ops ops = {
+   ettercap_version: VERSION,
+   plug_info:        "Try to discover the LAN's gateway",
+   plug_version:     21,
+   plug_type:        PT_EXT,
+   hook_point:       HOOK_NONE,
+   hook_function:    &triton_function,
+};
+
+//==================================
+
+int Plugin_Init(void *params)
+{
+   return Plugin_Register(params, &ops);
+}
+
+int Plugin_Fini(void *params)
+{
+   return 0;
+}
+
+// =================================
+
+int triton_function(void *dummy)
 {
    int sock, MTU, len=0, i;
    char c[2] = "";
@@ -94,7 +113,7 @@ void PlugIn_Start(char**argv)
             {
                Inet_Forge_packet_destroy( buf );
                Inet_CloseRawSock(sock);
-               return;
+               return 0;
             }
 
             if (len > 0)
@@ -124,7 +143,7 @@ void PlugIn_Start(char**argv)
 
                         Inet_Forge_packet_destroy( buf );
                         Inet_CloseRawSock(sock);
-                        return;
+                        return 0;
                      }
                   }
                }
@@ -137,7 +156,7 @@ void PlugIn_Start(char**argv)
       }
       Inet_Forge_packet_destroy( buf );
       Inet_CloseRawSock(sock);
-      return;
+      return 0;
    }
    else  // we don't have the list... search in passive mode...
    {
@@ -173,7 +192,7 @@ void PlugIn_Start(char**argv)
          {
             Inet_Forge_packet_destroy( buf );
             Inet_CloseRawSock(sock);
-            return;
+            return 0;
          }
       }  // end loop
 
