@@ -19,7 +19,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet_BSD.c,v 1.6 2001/12/08 16:38:43 alor Exp $
+    $Id: ec_inet_BSD.c,v 1.9 2002/02/11 01:15:48 alor Exp $
 */
 
 
@@ -68,7 +68,7 @@ int Inet_FindIFace(char *iface)
 
    for (ifa = ifalist; ifa; ifa = ifa->ifa_next)
    {
-      if ((ifa->ifa_flags & IFF_UP) == 0 || (ifa->ifa_flags & IFF_LOOPBACK))
+      if ((ifa->ifa_flags & IFF_UP) == 0 || (ifa->ifa_flags & IFF_LOOPBACK) || !strncmp(ifa->ifa_name, "pflog", 5))
          continue;
 
       ifp = ifa;
@@ -80,7 +80,7 @@ int Inet_FindIFace(char *iface)
       return -1;
    }
 
-   strcpy(iface, ifp->ifa_name);
+   strlcpy(iface, ifp->ifa_name, sizeof(Options.netiface));
 
 #ifdef DEBUG
    Debug_msg("Inet_FindIFace -- %s found !!", iface);
@@ -103,20 +103,20 @@ int Inet_FindIFace(char *iface)
 
    fd = socket(AF_INET, SOCK_DGRAM, 0);
    if (fd < 0)
-      Error_msg("ec_Inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_BSD:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    buf_size = 8192;
 
    for (;;) {
       buf = malloc (buf_size);
       if (buf == NULL)
-         Error_msg("ec_Inet_linux:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_BSD:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
       ifc.ifc_len = buf_size;
       ifc.ifc_buf = buf;
       memset (buf, 0, buf_size);
       if (ioctl(fd, SIOCGIFCONF, (char *)&ifc) < 0 && errno != EINVAL)
-         Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_BSD:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
       if (ifc.ifc_len < buf_size)
          break;
@@ -152,7 +152,7 @@ int Inet_FindIFace(char *iface)
       {
          if (errno == ENXIO)
             continue;
-         Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_BSD:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
       }
 
 #ifdef DEBUG
@@ -160,7 +160,7 @@ int Inet_FindIFace(char *iface)
 #endif
 
       /* Must be up and not the loopback */
-      if ((ifr.ifr_flags & IFF_UP) == 0 || (ifr.ifr_flags & IFF_LOOPBACK) != 0)
+      if ((ifr.ifr_flags & IFF_UP) == 0 || (ifr.ifr_flags & IFF_LOOPBACK) != 0  || !strncmp(ifr.ifa_name, "pflog", 5))
          continue;
 
       endcp = ifrp->ifr_name + strlen(ifrp->ifr_name);
@@ -186,7 +186,7 @@ int Inet_FindIFace(char *iface)
       return -1;
    }
 
-   strcpy(iface, mp->ifr_name);
+   strlcpy(iface, mp->ifr_name, sizeof(Options.netiface));
 
    free(buf);
 
@@ -216,7 +216,7 @@ int Inet_CorrectIface(char *iface)
 
    for (ifa = ifalist; ifa; ifa = ifa->ifa_next)
    {
-      if ( (ifa->ifa_flags & IFF_UP) == 0 || strcmp(iface, ifa->ifa_name) )
+      if ( (ifa->ifa_flags & IFF_UP) == 0 || (ifa->ifa_flags & IFF_LOOPBACK) != 0 || strcmp(iface, ifa->ifa_name) )
          continue;
 
       free(ifalist);
@@ -239,7 +239,7 @@ int Inet_CorrectIface(char *iface)
 
    sock = socket(AF_INET, SOCK_DGRAM, 0);
    if (sock < 0)
-      Error_msg("ec_Inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_BSD:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    memset(&ifr, 0, sizeof(ifr));
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
@@ -255,6 +255,12 @@ int Inet_CorrectIface(char *iface)
       return -1;
    }
 
+   if (ifr.ifr_flags & IFF_LOOPBACK )                    // check for loopback
+   {
+      Options.normal = 1;
+      Error_msg("Ettercap can't be run on loopback device");
+   }
+
    if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )             // check for alias
    {
       close(sock);
@@ -309,13 +315,13 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
       mib[5] = 0;
 
       if (sysctl(mib, 6, NULL, &len, NULL, 0) < 0)
-         Error_msg("ec_Inet_BSD:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_BSD:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
       if ((buf = (char *)malloc(len)) == NULL )
-         Error_msg("ec_Inet_BSD:%d malloc() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_BSD:%d malloc() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
       if (sysctl(mib, 6, buf, &len, NULL, 0) < 0)
-         Error_msg("ec_Inet_BSD:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_BSD:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
       end = buf + len;
 
@@ -339,14 +345,14 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    if (IP != NULL)
    {
       if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )
-         Error_msg("ec_Inet_BSD:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_BSD:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
       memcpy((char *)IP, ifr.ifr_addr.sa_data+2, 4);
    }
 
    if (NetMask != NULL)
    {
       if ( ioctl(sock, SIOCGIFNETMASK, &ifr) < 0 )
-         Error_msg("ec_Inet_BSD:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_BSD:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
       memcpy((char *)NetMask, ifr.ifr_addr.sa_data+2, 4);
       if (strcmp(Options.netmask, ""))       // specified on command line
          *NetMask = inet_addr(Options.netmask);
@@ -459,7 +465,7 @@ int Inet_OpenRawSock(char *iface)
    if (type != DLT_EN10MB)
       Error_msg("Interface not supported ( only DLT_EN10MB) | %d", type);
 
-#if defined(BIOCGHDRCMPLT) && defined(BIOCSHDRCMPLT)     // auoto fill the source mac address now set to OFF
+#if defined(BIOCGHDRCMPLT) && defined(BIOCSHDRCMPLT)     // auto fill the source mac address now set to OFF
     if (ioctl(fd, BIOCSHDRCMPLT, &spoof_eth_src) == -1)
       Error_msg("ec_inet_BSD:%d  ioctl(BIOCSHDRCMPLT) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 #endif
@@ -567,7 +573,7 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
          if (sent == len) return (sent);
       }
 
-      Error_msg("ec_Inet_BSD:%d write() %d(%d) | ERRNO : %d | %s \n", __LINE__, len, sent, errno, strerror(errno));
+      Error_msg("ec_inet_BSD:%d write() %d(%d) | ERRNO : %d | %s \n", __LINE__, len, sent, errno, strerror(errno));
    }
 
    return (sent);
@@ -583,7 +589,7 @@ int Inet_SetPromisc(char *iface)
 #endif
 
    if ( ioctl(fdprom, BIOCPROMISC, NULL) < 0 )
-      Error_msg("ec_Inet_BSD:%d ioctl(BIOCPROMISC) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_BSD:%d ioctl(BIOCPROMISC) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    return 0;
 }
