@@ -1,5 +1,6 @@
 /*
-    ettercap -- inet utilities -- Module for MacOsX darwin 1.3
+    ettercap -- inet utilities -- Module for MacOsX darwin 1.[34]
+                                                    darwin 5.[01]
 
     Copyright (C) 2001  ALoR <alor@users.sourceforge.net>, NaGA <crwm@freemail.it>
 
@@ -17,7 +18,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet_macosx.c,v 1.4 2001/11/22 20:13:55 alor Exp $
+    $Id: ec_inet_macosx.c,v 1.7 2002/02/11 01:15:48 alor Exp $
 */
 
 
@@ -64,20 +65,20 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 
    fd = socket(AF_INET, SOCK_DGRAM, 0);
    if (fd < 0)
-      Error_msg("ec_Inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    buf_size = 8192;
 
    for (;;) {
       buf = malloc (buf_size);
       if (buf == NULL)
-         Error_msg("ec_Inet_linux:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_macosx:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
       ifc.ifc_len = buf_size;
       ifc.ifc_buf = buf;
       memset (buf, 0, buf_size);
       if (ioctl(fd, SIOCGIFCONF, (char *)&ifc) < 0 && errno != EINVAL)
-         Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_macosx:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
       if (ifc.ifc_len < buf_size)
          break;
@@ -113,7 +114,7 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
       {
          if (errno == ENXIO)
             continue;
-         Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_macosx:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
       }
 
 #ifdef DEBUG
@@ -147,7 +148,7 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
       return -1;
    }
 
-   strcpy(iface, mp->ifr_name);
+   strlcpy(iface, mp->ifr_name, sizeof(Options.netiface));
 
    free(buf);
 
@@ -171,7 +172,7 @@ int Inet_CorrectIface(char *iface)
 
    sock = socket(AF_INET, SOCK_DGRAM, 0);
    if (sock < 0)
-      Error_msg("ec_Inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    memset(&ifr, 0, sizeof(ifr));
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
@@ -187,6 +188,12 @@ int Inet_CorrectIface(char *iface)
       return -1;
    }
 
+   if (ifr.ifr_flags & IFF_LOOPBACK )                    // check for loopback
+   {
+      Options.normal = 1;
+      Error_msg("Ettercap can't be run on loopback device");
+   }
+
    if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )             // check for alias
    {
       close(sock);
@@ -240,13 +247,13 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
       mib[5] = 0;
 
       if (sysctl(mib, 6, NULL, &len, NULL, 0) < 0)
-         Error_msg("ec_Inet_macosx:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_macosx:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
       if ((buf = (char *)malloc(len)) == NULL )
-         Error_msg("ec_Inet_macosx:%d malloc() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_macosx:%d malloc() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
       if (sysctl(mib, 6, buf, &len, NULL, 0) < 0)
-         Error_msg("ec_Inet_macosx:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_macosx:%d sysctl() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
       end = buf + len;
 
@@ -270,14 +277,14 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    if (IP != NULL)
    {
       if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )
-         Error_msg("ec_Inet_macosx:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_macosx:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
       memcpy((char *)IP, ifr.ifr_addr.sa_data+2, 4);
    }
 
    if (NetMask != NULL)
    {
       if ( ioctl(sock, SIOCGIFNETMASK, &ifr) < 0 )
-         Error_msg("ec_Inet_macosx:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_macosx:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
       memcpy((char *)NetMask, ifr.ifr_addr.sa_data+2, 4);
       if (strcmp(Options.netmask, ""))       // specified on command line
          *NetMask = inet_addr(Options.netmask);
@@ -354,14 +361,14 @@ int Inet_OpenRawSock(char *iface)
    } while (fd < 0 && errno == EBUSY);
 
    if (fd < 0)
-      Error_msg("ec_Inet_macosx:%d  no /dev/bpf* available (tried to open %d) | ERRNO : %d | %s", __LINE__, i, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d  no /dev/bpf* available (tried to open %d) | ERRNO : %d | %s", __LINE__, i, errno, strerror(errno));
 
 #ifdef DEBUG
    Debug_msg("Inet_OpenRawSock \t fd = %d -- /dev/bpf%d ", fd, i-1);
 #endif
 
    if (ioctl(fd, BIOCVERSION, (caddr_t)&bv) < 0)      // get bpf version
-      Error_msg("ec_Inet_macosx:%d  ioctl(BIOCVERSION) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d  ioctl(BIOCVERSION) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
 
    if (bv.bv_major != BPF_MAJOR_VERSION || bv.bv_minor < BPF_MINOR_VERSION)
@@ -376,32 +383,32 @@ int Inet_OpenRawSock(char *iface)
          break;  /* that size worked; we're done */
 
       if (errno != ENOBUFS)
-         Error_msg("ec_Inet_macosx:%d  ioctl(BIOCSETIF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_macosx:%d  ioctl(BIOCSETIF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
    }
 
    if (size == 0) Error_msg("BIOCSBLEN: No buffer size worked");
 
    if (ioctl(fd, BIOCGBLEN, (caddr_t)&size) < 0)
-     Error_msg("ec_Inet_macosx:%d  ioctl(BIOCGBLEN) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+     Error_msg("ec_inet_macosx:%d  ioctl(BIOCGBLEN) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    if (ioctl(fd, BIOCGDLT, (caddr_t)&type) == -1)           // Get the data link layer type.
-      Error_msg("ec_Inet_macosx:%d  ioctl(BIOCGDLT) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d  ioctl(BIOCGDLT) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    if (type != DLT_EN10MB)
       Error_msg("Interface not supported ( only DLT_EN10MB) | %d", type);
 
-#if defined(BIOCGHDRCMPLT) && defined(BIOCSHDRCMPLT)     // auoto fill the source mac address now set OFF
+#if defined(BIOCGHDRCMPLT) && defined(BIOCSHDRCMPLT)     // auto fill the source mac address now set OFF
     if (ioctl(fd, BIOCSHDRCMPLT, &spoof_eth_src) == -1)
-      Error_msg("ec_Inet_macosx:%d  ioctl(BIOCSHDRCMPLT) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d  ioctl(BIOCSHDRCMPLT) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 #endif
 
    i = 1;
    if (ioctl(fd, BIOCIMMEDIATE, &i) < 0)                    // Set immediate mode so packets are processed as they arrive.
-      Error_msg("ec_Inet_macosx:%d  ioctl(BIOCIMMEDIATE) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d  ioctl(BIOCIMMEDIATE) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
 
    if (ioctl(fd, BIOCSETF, (caddr_t)&filter) < 0)           // Set filter program.
-      Error_msg("ec_Inet_macosx:%d  ioctl(BIOCSETF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d  ioctl(BIOCSETF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
 
    fdprom = fd;
@@ -497,7 +504,7 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
          if (sent == len) return (sent);
       }
 
-      Error_msg("ec_Inet_macosx:%d write() %d(%d) | ERRNO : %d | %s \n", __LINE__, len, sent, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d write() %d(%d) | ERRNO : %d | %s \n", __LINE__, len, sent, errno, strerror(errno));
    }
 
    return (sent);
@@ -513,7 +520,7 @@ int Inet_SetPromisc(char *iface)
 #endif
 
    if ( ioctl(fdprom, BIOCPROMISC, NULL) < 0 )
-      Error_msg("ec_Inet_macosx:%d ioctl(BIOCPROMISC) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d ioctl(BIOCPROMISC) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    return 0;
 }
@@ -545,7 +552,7 @@ void Inet_DisableForwarding(void)
    len = sizeof(IpForward_status);
 
    if( (sysctl(mib, 4, &IpForward_status, &len, &val, sizeof(val))) == -1)
-    Error_msg("ec_Inet_macosx:%d sysctl() | net.inet.ip.forwarding | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+    Error_msg("ec_inet_macosx:%d sysctl() | net.inet.ip.forwarding | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
 #ifdef DEBUG
    Debug_msg("Inet_DisableForwarding | net.inet.ip.forwarding = %d  old_value = %d\n", val, IpForward_status);
@@ -570,7 +577,7 @@ void Inet_RestoreForwarding(void)
    if (strcmp(ECThread_getname(pthread_self()), PROGRAM)) return;
 
    if( (sysctl(mib, 4, NULL, NULL, &IpForward_status, sizeof(IpForward_status))) == -1)
-      Error_msg("ec_Inet_macosx:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
 #ifdef DEBUG
    Debug_msg("Inet_RestoreForwarding | net.inet.ip.forwarding = %d\n", IpForward_status);
@@ -602,15 +609,15 @@ char *Inet_MacFromIP(unsigned long ip)
    mib[5] = RTF_LLINFO;
 
    if (sysctl(mib, 6, NULL, &len, NULL, 0) < 0)
-      Error_msg("ec_Inet_macosx:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    if ((buf = (char *)malloc(len)) == NULL)
-      Error_msg("ec_Inet_macosx:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    if (sysctl(mib, 6, buf, &len, NULL, 0) < 0)
    {
       free(buf);
-      Error_msg("ec_Inet_macosx:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_macosx:%d sysctl() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
    }
    end = buf + len;
 
