@@ -19,7 +19,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet_linux.c,v 1.5 2001/11/19 09:30:23 alor Exp $
+    $Id: ec_inet_linux.c,v 1.7 2002/02/11 00:57:25 alor Exp $
 */
 
 #include <ctype.h>
@@ -38,20 +38,20 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 
    fd = socket(AF_INET, SOCK_DGRAM, 0);
    if (fd < 0)
-      Error_msg("ec_Inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    buf_size = 8192;
 
    for (;;) {
       buf = malloc (buf_size);
       if (buf == NULL)
-         Error_msg("ec_Inet_linux:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_linux:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
       ifc.ifc_len = buf_size;
       ifc.ifc_buf = buf;
       memset (buf, 0, buf_size);
       if (ioctl(fd, SIOCGIFCONF, (char *)&ifc) < 0 && errno != EINVAL)
-         Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
       if (ifc.ifc_len < buf_size)
          break;
@@ -88,7 +88,7 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
          if (errno == ENXIO)
             continue;
 
-         Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
       }
 
 #ifdef DEBUG
@@ -99,6 +99,13 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
       if ((ifr.ifr_flags & IFF_UP) == 0 || (ifr.ifr_flags & IFF_LOOPBACK) != 0)
          continue;
 
+      if ( ioctl(fd, SIOCGIFHWADDR, &ifr) < 0 )
+         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFHWADDR) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+
+      /* Must be ethernet */
+      if ( ifr.ifr_hwaddr.sa_family != ARPHRD_ETHER )
+         continue;
+
       endcp = ifrp->ifr_name + strlen(ifrp->ifr_name);
       for (cp = ifrp->ifr_name; cp < endcp && !isdigit(*cp); ++cp)
          continue;
@@ -122,7 +129,7 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
       return -1;
    }
 
-   strcpy(iface, mp->ifr_name);
+   strlcpy(iface, mp->ifr_name, sizeof(Options.netiface));
 
    free(buf);
 
@@ -146,7 +153,7 @@ int Inet_CorrectIface(char *iface)
 
    sock = socket(AF_INET, SOCK_DGRAM, 0);
    if (sock < 0)
-      Error_msg("ec_Inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    memset(&ifr, 0, sizeof(ifr));
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
@@ -162,12 +169,30 @@ int Inet_CorrectIface(char *iface)
       return -1;
    }
 
+   if (ifr.ifr_flags & IFF_LOOPBACK )                    // check for loopback
+   {
+      Options.normal = 1;
+      Error_msg("Ettercap can't be run on loopback device");
+   }
+
    if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )             // check for alias
    {
       close(sock);
       return -1;
    }
 
+   if ( ioctl(sock, SIOCGIFHWADDR, &ifr) < 0 )
+      Error_msg("ec_inet_linux:%d ioctl(SIOCGIFHWADDR) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+
+   switch (ifr.ifr_hwaddr.sa_family)
+   {
+        case ARPHRD_ETHER:    // only ethernet is supported
+            break;
+
+        default:
+            Error_msg("Device type not supported (only ethernet)");
+   }
+
    close(sock);
 
    return 0;
@@ -202,21 +227,21 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    if (MyMAC != NULL)
    {
       if ( ioctl(sock, SIOCGIFHWADDR, &ifr) < 0 )
-         Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFHWADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFHWADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
       memcpy(MyMAC, ifr.ifr_hwaddr.sa_data, 6);
    }
 
    if (IP != NULL)
    {
       if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )
-         Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
       memcpy((char *)IP, ifr.ifr_addr.sa_data+2, 4);
    }
 
    if (NetMask != NULL)
    {
       if ( ioctl(sock, SIOCGIFNETMASK, &ifr) < 0 )
-         Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_linux:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
       memcpy((char *)NetMask, ifr.ifr_addr.sa_data+2, 4);
       if (strcmp(Options.netmask, ""))       // specified on command line
          *NetMask = inet_addr(Options.netmask);
@@ -258,7 +283,7 @@ int Inet_OpenRawSock(char *iface)
    sock = socket(PF_INET, SOCK_PACKET, htons(ETH_P_ALL));
 #endif
    if (sock < 0)
-      Error_msg("ec_Inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_linux:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
 #ifdef DEBUG
    Debug_msg("Inet_OpenRawSock %s \t fd = %d", iface, sock);
@@ -270,7 +295,7 @@ int Inet_OpenRawSock(char *iface)
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
 
    if ( ioctl(sock, SIOCGIFINDEX, &ifr) < 0)
-      Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFINDEX) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_linux:%d ioctl(SIOCGIFINDEX) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    memset(&sll, 0, sizeof(sll));
    sll.sll_family = AF_PACKET;
@@ -278,13 +303,13 @@ int Inet_OpenRawSock(char *iface)
    sll.sll_protocol = htons(ETH_P_ALL);
 
    if ( bind(sock, (struct sockaddr *) &sll, sizeof(sll)) == -1)
-      Error_msg("ec_Inet_linux:%d bind() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_linux:%d bind() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 #else
 
    memset(&sa, 0, sizeof(sa));
    strncpy(sa.sa_data, iface, sizeof(sa.sa_data));
    if ( bind(sock, &sa, sizeof(sa)) == -1)
-      Error_msg("ec_Inet_linux:%d bind() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_linux:%d bind() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
 #endif
 
@@ -356,7 +381,7 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
          strncpy(ifr.ifr_name, Options.netiface, sizeof(ifr.ifr_name));
 
          if ( ioctl(sock, SIOCGIFINDEX, &ifr) < 0)
-            Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFINDEX) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+            Error_msg("ec_inet_linux:%d ioctl(SIOCGIFINDEX) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
          dest.sll_family = AF_PACKET;
          dest.sll_ifindex = ifr.ifr_ifindex;
@@ -376,7 +401,7 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
          if (sent == len) return (sent);
       }
 
-      Error_msg("ec_Inet_linux:%d sendto() %d(%d) | ERRNO : %d | %s \n", __LINE__, len, sent, errno, strerror(errno));
+      Error_msg("ec_inet_linux:%d sendto() %d(%d) | ERRNO : %d | %s \n", __LINE__, len, sent, errno, strerror(errno));
    }
 
    return (sent);
@@ -401,7 +426,7 @@ int Inet_SetPromisc(char *iface)
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
 
    if ( ioctl(sock, SIOCGIFFLAGS, &ifr) < 0 )
-      Error_msg("ec_Inet_linux:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_linux:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    memset(&old_ifr, 0, sizeof(old_ifr));
    old_ifr.ifr_flags = ifr.ifr_flags;              //save old flags
@@ -410,7 +435,7 @@ int Inet_SetPromisc(char *iface)
    {
       ifr.ifr_flags |= IFF_PROMISC;
       if ( ioctl(sock, SIOCSIFFLAGS, &ifr) < 0 )      // promisc mode
-         Error_msg("ec_Inet_linux:%d ioctl(SIOCSIFFLAGS) | promisc on | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_linux:%d ioctl(SIOCSIFFLAGS) | promisc on | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
       atexit(Inet_Restore_ifr);
    }
 
@@ -439,7 +464,7 @@ void Inet_Restore_ifr(void)
    ifr.ifr_flags = old_ifr.ifr_flags;
 
    if ( ioctl(sock, SIOCSIFFLAGS, &ifr) < 0 )     // flag restoring
-      Error_msg("ec_Inet_linux:%d ioctl(SIOCSIFFLAGS) | flag restoring | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_linux:%d ioctl(SIOCSIFFLAGS) | flag restoring | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    Inet_CloseRawSock(sock);
 }
@@ -453,7 +478,7 @@ void Inet_DisableForwarding(void)
    if (fd < 0 )
    {
       #ifdef DEBUG
-         Debug_msg("ec_Inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
+         Debug_msg("ec_inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
       #endif
       return;
    }
@@ -471,7 +496,7 @@ void Inet_DisableForwarding(void)
    if (fd < 0 )
    {
       #ifdef DEBUG
-         Debug_msg("ec_Inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
+         Debug_msg("ec_inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
       #endif
       return;
    }
@@ -492,7 +517,7 @@ void Inet_RestoreForwarding(void)
    if (fd < 0 )
    {
       #ifdef DEBUG
-         Debug_msg("ec_Inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
+         Debug_msg("ec_inet_linux:%d fopen(/proc/sys/net/ipv4/ip_forward) | ERRNO : %d | %s \n", __LINE__, errno, sys_errlist[errno]);
       #endif
       return;
    }
@@ -628,7 +653,7 @@ void Inet_UnSetARPEntry(void)
     req.arp_flags = ATF_PERM | ATF_COM;
 
     memcpy(req.arp_ha.sa_data, SavedMAC, 6);
-    strcpy(req.arp_dev, Options.netiface);
+    strlcpy(req.arp_dev, Options.netiface, sizeof(req.arp_dev));
 
     ioctl(sockfd, SIOCDARP, &req);
 
@@ -656,7 +681,7 @@ int Inet_SetARPEntry(unsigned long IP, char MAC[6])
     req.arp_flags = ATF_PERM | ATF_COM;
 
     memcpy(req.arp_ha.sa_data, MAC, 6);
-    strcpy(req.arp_dev, Options.netiface);
+    strlcpy(req.arp_dev, Options.netiface, sizeof(req.arp_dev));
 
     retval = ioctl(sockfd, SIOCSARP, &req);
 
