@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet_solaris.c,v 1.5 2001/11/19 09:30:23 alor Exp $
+    $Id: ec_inet_solaris.c,v 1.9 2002/02/11 01:15:48 alor Exp $
 */
 
 
@@ -70,7 +70,7 @@ static int dlbindreq(int, u_int, char *);
 static int dlinfoack(int, char *, char *);
 static int dlinforeq(int, char *);
 static int dlokack(int, const char *, char *, char *);
-static int send_request(int, char *, int, char *, char *, int);
+static int send_request(int, char *, int, char *, char *);
 static int recv_ack(int, int, const char *, char *, char *);
 static int dlpromisconreq(int, u_int, char *);
 #if defined(SOLARIS) && defined(HAVE_SYS_BUFMOD_H)
@@ -82,6 +82,7 @@ static int strioctl(int, int, int, char *);
 #ifdef HAVE_DEV_DLPI
 static int get_dlpi_ppa(int, const char *, int, char *);
 #endif
+static char * split_dname(char *device, int *unitp);
 
 int fdprom;
 static u_int ctlbuf[MAXDLBUF];
@@ -109,20 +110,20 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
 
    fd = socket(AF_INET, SOCK_DGRAM, 0);
    if (fd < 0)
-      Error_msg("ec_Inet_solaris:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    buf_size = 8192;
 
    for (;;) {
       buf = malloc (buf_size);
       if (buf == NULL)
-         Error_msg("ec_Inet_solaris:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_solaris:%d malloc() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
       ifc.ifc_len = buf_size;
       ifc.ifc_buf = buf;
       memset (buf, 0, buf_size);
       if (ioctl(fd, SIOCGIFCONF, (char *)&ifc) < 0 && errno != EINVAL)
-         Error_msg("ec_Inet_solaris:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_solaris:%d ioctl(SIOCGIFCONF) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
       if (ifc.ifc_len < buf_size)
          break;
@@ -158,7 +159,7 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
       {
          if (errno == ENXIO)
             continue;
-         Error_msg("ec_Inet_solaris:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_solaris:%d ioctl(SIOCGIFFLAGS) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
       }
 
 #ifdef DEBUG
@@ -192,7 +193,7 @@ int Inet_FindIFace(char *iface)     // adapded from pcap_lookupdev
       return -1;
    }
 
-   strcpy(iface, mp->ifr_name);
+   strlcpy(iface, mp->ifr_name, sizeof(Options.netiface));
 
    free(buf);
 
@@ -216,7 +217,7 @@ int Inet_CorrectIface(char *iface)
 
    sock = socket(AF_INET, SOCK_DGRAM, 0);
    if (sock < 0)
-      Error_msg("ec_Inet_solaris:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d socket() | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
    memset(&ifr, 0, sizeof(ifr));
    strncpy(ifr.ifr_name, iface, sizeof(ifr.ifr_name));
@@ -232,6 +233,12 @@ int Inet_CorrectIface(char *iface)
       return -1;
    }
 
+   if (ifr.ifr_flags & IFF_LOOPBACK )                    // check for loopback
+   {
+      Options.normal = 1;
+      Error_msg("Ettercap can't be run on loopback device");
+   }
+
    if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )             // check for alias
    {
       close(sock);
@@ -283,11 +290,11 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
       dlp->physaddr_req.dl_primitive = DL_PHYS_ADDR_REQ;
       dlp->physaddr_req.dl_addr_type = DL_CURR_PHYS_ADDR;
 
-      if (send_request(dlpi, (char *)dlp, DL_PHYS_ADDR_REQ_SIZE, "physaddr", ebuf, 0) < 0)
-         Error_msg("ec_Inet_solaris:%d send_request(DL_PHYS_ADDR_REQ_SIZE) | %s \n", __LINE__, ebuf);
+      if (send_request(dlpi, (char *)dlp, DL_PHYS_ADDR_REQ_SIZE, "physaddr", ebuf) < 0)
+         Error_msg("ec_inet_solaris:%d send_request(DL_PHYS_ADDR_REQ_SIZE) | %s \n", __LINE__, ebuf);
 
       if (recv_ack(dlpi, DL_PHYS_ADDR_ACK_SIZE, "physaddr", (char *)dlp, ebuf) < 0)
-         Error_msg("ec_Inet_solaris:%d recv_ack(DL_PHYS_ADDR_ACK_SIZE) | %s \n", __LINE__, ebuf);
+         Error_msg("ec_inet_solaris:%d recv_ack(DL_PHYS_ADDR_ACK_SIZE) | %s \n", __LINE__, ebuf);
 
       memcpy( MyMAC,(struct ether_addr *) ((char *) dlp + dlp->physaddr_ack.dl_addr_offset), ETHER_ADDR_LEN);
 
@@ -297,14 +304,14 @@ int Inet_GetIfaceInfo(char *iface, int *MTU, char *MyMAC, unsigned long *IP, uns
    if (IP != NULL)
    {
       if ( ioctl(sock, SIOCGIFADDR, &ifr) < 0 )
-         Error_msg("ec_Inet_solaris:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_solaris:%d ioctl(SIOCGIFADDR) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
       memcpy((char *)IP, ifr.ifr_addr.sa_data+2, 4);
    }
 
    if (NetMask != NULL)
    {
       if ( ioctl(sock, SIOCGIFNETMASK, &ifr) < 0 )
-         Error_msg("ec_Inet_solaris:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_solaris:%d ioctl(SIOCGIFNETMASK) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
       memcpy((char *)NetMask, ifr.ifr_addr.sa_data+2, 4);
       if (strcmp(Options.netmask, ""))       // specified on command line
          *NetMask = inet_addr(Options.netmask);
@@ -334,9 +341,8 @@ void Inet_CloseRawSock(int sock)
 int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
 {
    register char *cp;
-   char *eos;
    int fd;
-   register int ppa;
+   int ppa;
    register dl_info_ack_t *infop;
 #ifdef HAVE_SYS_BUFMOD_H
    u_long flag, ss;
@@ -364,15 +370,13 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    /*
     * Split the name into a device type and a unit number.
     */
-   cp = strpbrk(dname, "0123456789");
+   //cp = strpbrk(dname, "0123456789");
+
+   cp = split_dname(dname, &ppa);
    if (cp == NULL)
-      Error_msg("ec_Inet_solaris:%d HAVE_DEV_DLPI: %s missing unit number\n", __LINE__, iface);
+      Error_msg("ec_inet_solaris:%d HAVE_DEV_DLPI: %s missing or bad unit number\n", __LINE__, iface);
 
-   ppa = strtol(cp, &eos, 10);
-   if (*eos != '\0')
-      Error_msg("ec_Inet_solaris:%d HAVE_DEV_DLPI: %s bad unit number\n", __LINE__, iface);
-
-   *cp = '\0';
+	*cp = '\0';
 
    /*
     * Use "/dev/dlpi" as the device.
@@ -380,7 +384,7 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
 
    cp = "/dev/dlpi";
    if ((fd = open(cp, O_RDWR)) < 0)
-      Error_msg("ec_Inet_solaris:%d open() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d open() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    /*
     * Get a table of all PPAs for that device, and search that
@@ -388,19 +392,15 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
     */
    ppa = get_dlpi_ppa(fd, dname, ppa, ebuf);
    if (ppa < 0)
-      Error_msg("ec_Inet_solaris:%d get_dlpi_ppa() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d get_dlpi_ppa() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
 #else
    /*
    ** Determine device and ppa
    */
-   cp = strpbrk(dname, "0123456789");
+   cp = split_dname(iface, &ppa);
    if (cp == NULL)
-      Error_msg("ec_Inet_solaris:%d dlpi: %s missing unit number\n", __LINE__, iface);
-
-   ppa = strtol(cp, &eos, 10);
-   if (*eos != '\0')
-      Error_msg("ec_Inet_solaris:%d dlpi: %s bad unit number\n", __LINE__, iface);
+      Error_msg("ec_inet_solaris:%d dlpi: %s missing or bad unit number\n", __LINE__, iface);
 
 
    if (*iface == '/')
@@ -415,11 +415,11 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    if ((fd = open(dname, O_RDWR)) < 0)
    {
       if (errno != ENOENT)
-         Error_msg("ec_Inet_solaris:%d open() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_solaris:%d open() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
       /* Try again with unit number */
       if ((fd = open(dname2, O_RDWR)) < 0)
-         Error_msg("ec_Inet_solaris:%d open() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+         Error_msg("ec_inet_solaris:%d open() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
       /* XXX Assume unit zero */
       ppa = 0;
@@ -430,25 +430,25 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    ** Attach if "style 2" provider
    */
    if (dlinforeq(fd, ebuf) < 0 || dlinfoack(fd, (char *)buf, ebuf) < 0)
-      Error_msg("ec_Inet_solaris:%d dlinforeq() || dlinfoack() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d dlinforeq() || dlinfoack() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    infop = &((union DL_primitives *)buf)->info_ack;
    if (infop->dl_provider_style == DL_STYLE2 && (dlattachreq(fd, ppa, ebuf) < 0 ||
        dlokack(fd, "attach", (char *)buf, ebuf) < 0))
-      Error_msg("ec_Inet_solaris:%d dlattachreq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d dlattachreq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    /*
    ** Bind
    */
    if (dlbindreq(fd, 0, ebuf) < 0 || dlbindack(fd, (char *)buf, ebuf) < 0)
-      Error_msg("ec_Inet_solaris:%d dlbindreq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d dlbindreq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
 
    /*
    ** Determine link type
    */
    if (dlinforeq(fd, ebuf) < 0 || dlinfoack(fd, (char *)buf, ebuf) < 0)
-      Error_msg("ec_Inet_solaris:%d dlinforeq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d dlinforeq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    infop = &((union DL_primitives *)buf)->info_ack;
    switch (infop->dl_mac_type)
@@ -467,7 +467,7 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    ** This is a non standard SunOS hack to get the ethernet header.
    */
    if (strioctl(fd, DLIOCRAW, 0, NULL) < 0)
-      Error_msg("ec_Inet_solaris:%d strioctl(DLIOCRAW) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d strioctl(DLIOCRAW) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
 #endif
 
@@ -476,7 +476,7 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    ** Another non standard call to get the data nicely buffered
    */
    if (ioctl(fd, I_PUSH, "bufmod") != 0)
-      Error_msg("ec_Inet_solaris:%d ioclt(I_PUSH) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d ioclt(I_PUSH) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    /*
    ** Now that the bufmod is pushed lets configure it.
@@ -499,17 +499,17 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    }
 
    if (ss > 0 && strioctl(fd, SBIOCSSNAP, sizeof(ss), (char *)&ss) != 0)
-      Error_msg("ec_Inet_solaris:%d strioctl(SBIOCSSNAP) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d strioctl(SBIOCSSNAP) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    /*
    ** Set up the bufmod flags
    */
    if (strioctl(fd, SBIOCGFLAGS, sizeof(flag), (char *)&flag) < 0)
-      Error_msg("ec_Inet_solaris:%d strioctl(SBIOCGFLAGS) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d strioctl(SBIOCGFLAGS) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    flag |= SB_NO_DROPS;
    if (strioctl(fd, SBIOCSFLAGS, sizeof(flag), (char *)&flag) != 0)
-      Error_msg("ec_Inet_solaris:%d strioctl(SBIOCSFLAGS) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d strioctl(SBIOCSFLAGS) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
 #endif
 
@@ -517,7 +517,7 @@ int Inet_OpenRawSock(char *iface)      // adapted from libpcap source code
    ** As the last operation flush the read side.
    */
    if (ioctl(fd, I_FLUSH, FLUSHR) != 0)
-      Error_msg("ec_Inet_solaris:%d ioctl(I_FLUSH) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d ioctl(I_FLUSH) | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    bufsize = MAXDLBUF * sizeof(u_int);             // global var...
 
@@ -703,7 +703,7 @@ int Inet_SendRawPacket(int sock, char *buffer, int len)
 
    c = putmsg(sock, NULL, &data, 0);
    if (c == -1)
-      Error_msg("ec_Inet_solaris:%d putmsg() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d putmsg() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    return (len);
 
@@ -720,7 +720,7 @@ int Inet_SetPromisc(char *iface)
    ** Enable promiscuous
    */
    if (dlpromisconreq(fd, DL_PROMISC_PHYS, ebuf) < 0 || dlokack(fd, "promisc_phys", (char *)buf, ebuf) < 0)
-      Error_msg("ec_Inet_solaris:%d dlpromisconreq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
+      Error_msg("ec_inet_solaris:%d dlpromisconreq() | ERRNO : %d | %s \n", __LINE__, errno, strerror(errno));
 
    return 0;
 }
@@ -763,20 +763,23 @@ char *Inet_MacFromIP(unsigned long ip)
  */
 
 static int
-send_request(int fd, char *ptr, int len, char *what, char *ebuf, int flags)
+send_request(int fd, char *ptr, int len, char *what, char *ebuf)
 {
-    struct strbuf ctl;
+   struct strbuf ctl;
+	int flags;
 
-    ctl.maxlen = 0;
-    ctl.len = len;
-    ctl.buf = ptr;
+   ctl.maxlen = 0;
+   ctl.len = len;
+   ctl.buf = ptr;
 
-    if (putmsg(fd, &ctl, (struct strbuf *) NULL, flags) < 0)
-    {
-        sprintf(ebuf, "send_request: putmsg \"%s\": %s", what, strerror(errno));
-        return (-1);
-    }
-    return (0);
+	flags = 0;
+
+   if (putmsg(fd, &ctl, (struct strbuf *) NULL, flags) < 0)
+   {
+      sprintf(ebuf, "send_request: putmsg \"%s\": %s", what, strerror(errno));
+      return (-1);
+   }
+   return (0);
 }
 
 static int
@@ -843,6 +846,7 @@ recv_ack(int fd, int size, const char *what, char *bufp, char *ebuf)
     return (ctl.len);
 }
 
+/*
 static int
 dlpromiscoffreq(int fd, u_int level, char *ebuf)
 {
@@ -851,8 +855,9 @@ dlpromiscoffreq(int fd, u_int level, char *ebuf)
     req.dl_primitive = DL_PROMISCOFF_REQ;
     req.dl_level     = level;
 
-    return (send_request(fd, (char *)&req, sizeof(req), "promiscoff", ebuf, 0));
+    return (send_request(fd, (char *)&req, sizeof(req), "promiscoff", ebuf));
 }
+*/
 
 static int
 dlpromisconreq(int fd, u_int level, char *ebuf)
@@ -862,7 +867,7 @@ dlpromisconreq(int fd, u_int level, char *ebuf)
     req.dl_primitive = DL_PROMISCON_REQ;
     req.dl_level     = level;
 
-    return (send_request(fd, (char *)&req, sizeof(req), "promiscon", ebuf, 0));
+    return (send_request(fd, (char *)&req, sizeof(req), "promiscon", ebuf));
 }
 
 
@@ -874,7 +879,7 @@ dlattachreq(int fd, u_int ppa, char *ebuf)
     req.dl_primitive = DL_ATTACH_REQ;
     req.dl_ppa       = ppa;
 
-    return (send_request(fd, (char *)&req, sizeof(req), "attach", ebuf, 0));
+    return (send_request(fd, (char *)&req, sizeof(req), "attach", ebuf));
 }
 
 static int
@@ -898,7 +903,7 @@ dlbindreq(int fd, u_int sap, char *ebuf)
     req.dl_service_mode = DL_CLDLS;
 #endif
 #endif
-    return (send_request(fd, (char *)&req, sizeof(req), "bind", ebuf, 0));
+    return (send_request(fd, (char *)&req, sizeof(req), "bind", ebuf));
 }
 
 
@@ -923,7 +928,7 @@ dlinforeq(int fd, char *ebuf)
 
     req.dl_primitive = DL_INFO_REQ;
 
-    return (send_request(fd, (char *)&req, sizeof(req), "info", ebuf, RS_HIPRI));
+    return (send_request(fd, (char *)&req, sizeof(req), "info", ebuf));
 }
 
 static int
@@ -977,5 +982,38 @@ get_release(u_int *majorp, u_int *minorp, u_int *microp)
 #endif
 
 
+static char *
+split_dname(char *device, int *unitp)
+{
+	char *cp;
+	char *eos;
+	int unit;
+
+	/*
+	 * Look for a number at the end of the device name string.
+	 */
+	cp = device + strlen(device) - 1;
+
+#ifdef DEBUG
+	Debug_msg("split_dname --> [%s] [%c]", device, *cp);
+#endif
+
+	if (*cp < '0' || *cp > '9')
+		return (NULL);
+
+
+	/* Digits at end of string are unit number */
+	while (cp-1 >= device && *(cp-1) >= '0' && *(cp-1) <= '9')
+		cp--;
+
+	unit = strtol(cp, &eos, 10);
+	if (*eos != '\0')
+		return (NULL);
+
+	*unitp = unit;
+	return (cp);
+}
+
+
 
 /* EOF */
