@@ -17,14 +17,11 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_decodedata.c,v 1.6 2001/09/13 20:15:48 alor Exp $
+    $Id: ec_decodedata.c,v 1.18 2001/12/09 20:24:51 alor Exp $
 */
 
 #include "include/ec_main.h"
 
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
 #ifdef HAVE_CTYPE_H
    #include <ctype.h>
 #endif
@@ -32,10 +29,8 @@
 #include "include/ec_inet_structures.h"
 #include "include/ec_inet.h"
 #include "include/ec_error.h"
+#include "include/ec_parser.h"
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
 
 typedef struct
 {
@@ -56,14 +51,35 @@ typedef struct
 
 os_database *os_list = NULL;
 
+
+#define HASH_SIZE 64
+
+struct conn_hash_list {
+   u_long ips;
+   u_long ipd;
+   u_short ps;
+   u_short pd;
+   char proto;
+   int index;
+   SLIST_ENTRY (conn_hash_list) next;
+};
+
+SLIST_HEAD(, conn_hash_list) conn_hash_array[HASH_SIZE];
+
+
+pthread_mutex_t passive_mutex = PTHREAD_MUTEX_INITIALIZER;
+pthread_mutex_t connection_mutex = PTHREAD_MUTEX_INITIALIZER;
+
 #ifndef HAVE_CTYPE_H
    int isprint(int c);
 #endif
-int Decodedata_MakeConnectionList(CONNECTION data);
+int Decodedata_GetArrayIndex(CONNECTION *data);
+void Decodedata_SetArrayIndex(CONNECTION *data, int index);
+int Decodedata_MakeConnectionList(CONNECTION *data);
 int Decodedata_RefreshConnectionList(void);
 void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data);
 
-int Decodedata_MakePassiveList(PASSIVE_DATA data);
+int Decodedata_MakePassiveList(PASSIVE_DATA *data);
 int Decodedata_FreePassiveList(void);
 void Decodedata_UpdatePassiveInfo(PASSIVE_DATA *ptr, PASSIVE_DATA *data);
 
@@ -71,6 +87,7 @@ int Decodedata_GetPassiveOS(char *fingerprint, char *os);
 
 char * Decodedata_GetType(char proto, int port1, int port2);
 char * Decodedata_GetAsciiData(char *buffer, int buff_len);
+char * Decodedata_GetTextData(char *buffer, int buff_len);
 char * Decodedata_GetHexData(char *buffer, int buff_len, short dimX);
 char * Decodedata_GetEnhanchedHexData(char *buffer, int buff_len, short cr);
 char * Decodedata_TCPFlags(char flags);
@@ -91,158 +108,158 @@ int Decodedata_Compare_Host(PASSIVE_DATA *h1, PASSIVE_DATA *h2);
 #endif
 
 
-int Decodedata_MakeConnectionList(CONNECTION data)
+
+int Decodedata_GetArrayIndex(CONNECTION *data)
 {
-   int num_conn = 1;
-   char filter[45];
-   char cur_conn[45];
-   char rev_cur_conn[45];
-   char found = 0;
-   CONNECTION *ptr;
+   int hash;
+   struct conn_hash_list *current;
 
-   sprintf(filter, "%c%s%d%s%d", data.proto, data.source_ip, data.source_port, data.dest_ip, data.dest_port);
+   hash = (data->fast_source_ip + data->source_port + data->fast_dest_ip + data->dest_port) % HASH_SIZE;
 
-   if (number_of_connections != 0)
+   SLIST_FOREACH(current, &conn_hash_array[hash], next)
    {
-      for(ptr=&Conn_Between_Hosts[number_of_connections-1]; num_conn <= number_of_connections; ptr--)
-      {
-         sprintf(cur_conn, "%c%s%d%s%d", ptr->proto, ptr->source_ip, ptr->source_port, ptr->dest_ip, ptr->dest_port);
-         sprintf(rev_cur_conn, "%c%s%d%s%d", ptr->proto, ptr->dest_ip, ptr->dest_port, ptr->source_ip, ptr->source_port);
-
-         num_conn++;
-
-         if (!strcmp(filter, cur_conn))
+      if ( current->proto == data->proto &&
+           ((current->ips == data->fast_source_ip && current->ipd == data->fast_dest_ip   // straight
+            && current->ps == data->source_port && current->pd == data->dest_port)
+            ||
+            (current->ipd == data->fast_source_ip && current->ips == data->fast_dest_ip   // reverse
+            && current->pd == data->source_port && current->ps == data->dest_port))
+         )
          {
-            if (ptr->proto == 'T')
-            {
-               ptr->source_seq = data.source_seq;
-               ptr->flags = data.flags;
-            }
-            found = 1;
+            return current->index;
          }
-
-         if (!strcmp(filter, rev_cur_conn))
-         {
-            if (ptr->proto == 'T')
-            {
-               ptr->dest_seq = data.dest_seq;
-               ptr->flags = data.flags;
-            }
-            found = 1;
-         }
-
-         if (found)
-         {
-            Decodedata_UpdateInfo(ptr, &data);
-
-            if (ptr->proto == 'T')
-            {
-               if (ptr->flags & TH_RST)
-                  strcpy(ptr->status,  "KILLED");
-               else if (ptr->flags & TH_SYN)
-                  strcpy(ptr->status,  "OPENING");
-               else if (ptr->flags & TH_FIN)
-                  strcpy(ptr->status,  "CLOSING");
-               else if (ptr->flags & TH_PSH)
-                  strcpy(ptr->status,  "ACTIVE");
-               else
-                  if (!strcmp(ptr->status, "CLOSING"))     // FIN ACK
-                     strcpy(ptr->status,  "CLOSED");       // ACK
-                  else if (strcmp(ptr->status, "CLOSED"))
-                     strcpy(ptr->status,  "silent");
-            }
-            else if (ptr->proto == 'U')
-            {
-               strcpy(ptr->status,  "  UDP ");
-            }
-
-            if (strcmp(data.type, ""))
-               strcpy(ptr->type, data.type);
-
-            return number_of_connections;
-
-         }
-      }
    }
 
-   if (!found)
+   return -1;
+}
+
+
+
+void Decodedata_SetArrayIndex(CONNECTION *data, int index)
+{
+   int hash;
+   struct conn_hash_list *newelem;
+
+   hash = (data->fast_source_ip + data->source_port + data->fast_dest_ip + data->dest_port) % HASH_SIZE;
+
+   newelem = (struct conn_hash_list *) calloc(1, sizeof(struct conn_hash_list));
+   if (!newelem)
+      ERROR_MSG("calloc()");
+
+   newelem->ips = data->fast_source_ip;
+   newelem->ipd = data->fast_dest_ip;
+   newelem->ps = data->source_port;
+   newelem->pd = data->dest_port;
+   newelem->proto = data->proto;
+   newelem->index = index;
+
+   SLIST_INSERT_HEAD(&conn_hash_array[hash], newelem, next);
+
+}
+
+
+
+int Decodedata_MakeConnectionList(CONNECTION *data)
+{
+   int index = -1;
+
+   pthread_mutex_lock(&connection_mutex);
+
+   index = Decodedata_GetArrayIndex(data);
+
+   if (index != -1)  // the entry already exist
    {
+      if (data->proto == 'T')
+      {
+         Conn_Between_Hosts[index].source_seq = data->source_seq;
+         Conn_Between_Hosts[index].flags = data->flags;
+      }
+
+      Decodedata_UpdateInfo(&Conn_Between_Hosts[index], data);
+
+      pthread_mutex_unlock(&connection_mutex);
+
+      return number_of_connections;
+
+   }
+   else  // create a new entry
+   {
+      if (number_of_connections <= 0)
+         number_of_connections = 1;
+      else
+         number_of_connections++;
+
       #ifdef DEBUG
-         Debug_msg("Decodedata_MakeConnectionList - new node ! %d ! %c %s:%d - %s:%d ", num_conn, data.proto, data.source_ip, data.source_port, data.dest_ip, data.dest_port);
+         Debug_msg("Decodedata_MakeConnectionList - new node ! %d ! %c %s:%d - %s:%d ", number_of_connections,
+                   data->proto, data->source_ip, data->source_port, data->dest_ip, data->dest_port);
       #endif
 
-      Conn_Between_Hosts = (CONNECTION *)realloc(Conn_Between_Hosts, num_conn*sizeof(CONNECTION));
+      Conn_Between_Hosts = (CONNECTION *)realloc(Conn_Between_Hosts, number_of_connections*sizeof(CONNECTION));
       if ( Conn_Between_Hosts == NULL )
          ERROR_MSG("realloc()");
       else
-         memset(&Conn_Between_Hosts[num_conn-1], 0, sizeof(CONNECTION));
+         memset(&Conn_Between_Hosts[number_of_connections-1], 0, sizeof(CONNECTION));
 
-      memcpy(Conn_Between_Hosts[num_conn-1].source_ip, &data.source_ip, sizeof(data.source_ip));
-      memcpy(Conn_Between_Hosts[num_conn-1].dest_ip, &data.dest_ip, sizeof(data.dest_ip));
+      Decodedata_SetArrayIndex(data, number_of_connections-1);    // save connection in the hash table
 
-      Inet_PutMACinString(Conn_Between_Hosts[num_conn-1].source_mac, data.source_mac);
-      Inet_PutMACinString(Conn_Between_Hosts[num_conn-1].dest_mac, data.dest_mac);
+      memcpy(Conn_Between_Hosts[number_of_connections-1].source_ip, &data->source_ip, sizeof(data->source_ip));
+      memcpy(Conn_Between_Hosts[number_of_connections-1].dest_ip, &data->dest_ip, sizeof(data->dest_ip));
 
-      Conn_Between_Hosts[num_conn-1].source_port = data.source_port;
-      Conn_Between_Hosts[num_conn-1].dest_port = data.dest_port;
-      Conn_Between_Hosts[num_conn-1].proto = data.proto;
+      Conn_Between_Hosts[number_of_connections-1].fast_source_ip = data->fast_source_ip;
+      Conn_Between_Hosts[number_of_connections-1].fast_dest_ip = data->fast_dest_ip;
 
-      if (Conn_Between_Hosts[num_conn-1].proto == 'T')
-      {
-         Conn_Between_Hosts[num_conn-1].source_seq = data.source_seq;
-         Conn_Between_Hosts[num_conn-1].dest_seq = data.dest_seq;
-         Conn_Between_Hosts[num_conn-1].flags = data.flags;
+      Inet_PutMACinString(Conn_Between_Hosts[number_of_connections-1].source_mac, data->source_mac);
+      Inet_PutMACinString(Conn_Between_Hosts[number_of_connections-1].dest_mac, data->dest_mac);
 
-         if (Conn_Between_Hosts[num_conn-1].flags & TH_RST)
-            strcpy(Conn_Between_Hosts[num_conn-1].status, "KILLED");
-         else if (Conn_Between_Hosts[num_conn-1].flags & TH_FIN)
-            strcpy(Conn_Between_Hosts[num_conn-1].status, "CLOSING");
-         else if (Conn_Between_Hosts[num_conn-1].flags & TH_SYN)
-            strcpy(Conn_Between_Hosts[num_conn-1].status, "OPENING");
-         else if (Conn_Between_Hosts[num_conn-1].flags & TH_PSH)
-            strcpy(Conn_Between_Hosts[num_conn-1].status, "ACTIVE");
-         else
-            strcpy(Conn_Between_Hosts[num_conn-1].status, "silent");
-      }
-      else if (Conn_Between_Hosts[num_conn-1].proto == 'U')
-         strcpy(Conn_Between_Hosts[num_conn-1].status, "  UDP ");
+      Conn_Between_Hosts[number_of_connections-1].source_port = data->source_port;
+      Conn_Between_Hosts[number_of_connections-1].dest_port = data->dest_port;
+      Conn_Between_Hosts[number_of_connections-1].proto = data->proto;
 
-
-      if (strcmp(data.type, ""))
-         strcpy(Conn_Between_Hosts[num_conn-1].type, data.type);
+      if (strcmp(data->type, ""))
+         strlcpy(Conn_Between_Hosts[number_of_connections-1].type, data->type, sizeof(Conn_Between_Hosts[number_of_connections -1].type));
       else
-         strncpy(Conn_Between_Hosts[num_conn-1].type, Decodedata_GetType(Conn_Between_Hosts[num_conn-1].proto,
-                                                                         Conn_Between_Hosts[num_conn-1].source_port,
-                                                                         Conn_Between_Hosts[num_conn-1].dest_port),
-                                                                         18);
+         strlcpy(Conn_Between_Hosts[number_of_connections-1].type,
+                 Decodedata_GetType(Conn_Between_Hosts[number_of_connections-1].proto,
+                                    Conn_Between_Hosts[number_of_connections-1].source_port,
+                                    Conn_Between_Hosts[number_of_connections-1].dest_port),
+                 sizeof(Conn_Between_Hosts[number_of_connections -1].type));
 
-      if (Conn_Between_Hosts[num_conn-1].proto == 'T')
+      if (Conn_Between_Hosts[number_of_connections-1].proto == 'T')
       {
-         if (!(Conn_Between_Hosts[num_conn-1].flags & TH_SYN) &&
-              ( data.dest_port == 23 || data.source_port == 23 ||
-                data.dest_port == 513 || data.source_port == 513) )
-                  Conn_Between_Hosts[num_conn-1].user[1] = -1;  // flag for the "waiting for syn" only for telnet and rlogin
+         if (!(Conn_Between_Hosts[number_of_connections-1].flags & TH_SYN) &&
+              ( data->dest_port == 23 || data->source_port == 23 ||
+                data->dest_port == 513 || data->source_port == 513) )
+                  Conn_Between_Hosts[number_of_connections-1].user[1] = -1;  // flag for the "waiting for syn" only for telnet and rlogin
 
-         Decodedata_UpdateInfo(&Conn_Between_Hosts[num_conn-1], &data);
+         Conn_Between_Hosts[number_of_connections-1].source_seq = data->source_seq;
+         Conn_Between_Hosts[number_of_connections-1].dest_seq = data->dest_seq;
+         Conn_Between_Hosts[number_of_connections-1].flags = data->flags;
+
+         Decodedata_UpdateInfo(&Conn_Between_Hosts[number_of_connections-1], data);
       }
-      else if (Conn_Between_Hosts[num_conn-1].proto == 'U')
+      else if (Conn_Between_Hosts[number_of_connections-1].proto == 'U')
       {
-         if (strcmp(data.user, ""))
+
+         sprintf(Conn_Between_Hosts[number_of_connections-1].status,  "  UDP ");
+
+         if (strcmp(data->user, ""))
          {
-            strtok(data.user, "\n");
-            snprintf(Conn_Between_Hosts[num_conn-1].user, 30, "USER: %s", data.user);
+            strtok(data->user, "\n");
+            snprintf(Conn_Between_Hosts[number_of_connections-1].user, 30, "USER: %s", data->user);
          }
-         if (strcmp(data.pass, ""))
+         if (strcmp(data->pass, ""))
          {
-            strtok(data.pass, "\n");
-            snprintf(Conn_Between_Hosts[num_conn-1].pass, 30, "PASS: %s", data.pass);
+            strtok(data->pass, "\n");
+            snprintf(Conn_Between_Hosts[number_of_connections-1].pass, 30, "PASS: %s", data->pass);
          }
-         if (strcmp(data.info, "")) strncpy(Conn_Between_Hosts[num_conn-1].info, data.info, 100);
+         if (strcmp(data->info, "")) strlcpy(Conn_Between_Hosts[number_of_connections-1].info, data->info, 100);
       }
 
    }
 
-   return num_conn;
+   pthread_mutex_unlock(&connection_mutex);
+
+   return number_of_connections;
 
 }
 
@@ -250,14 +267,37 @@ int Decodedata_MakeConnectionList(CONNECTION data)
 void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data)
 {
 
+   if (ptr->proto == 'T')
+   {
+      if (data->flags & TH_RST)
+         sprintf(ptr->status,  "KILLED");
+      else if (data->flags & TH_SYN)
+         sprintf(ptr->status,  "OPENING");
+      else if (data->flags & TH_FIN)
+         sprintf(ptr->status,  "CLOSING");
+      else if (data->flags & TH_PSH)
+         sprintf(ptr->status,  "ACTIVE");
+      else if (data->flags & TH_ACK)
+      {
+         if (!strcmp(ptr->status, "CLOSING"))   // FIN ACK
+            sprintf(ptr->status,  "CLOSED");          // ACK
+      }
+      ptr->timestamp = time(NULL);
+   }
+
+   if (strcmp(data->type, ""))
+      strlcpy(ptr->type, data->type, sizeof(ptr->type));
+
+
    if (ptr->user[1] != -1)    // waiting for syn for some protocols like telnet
    {
       if ( ptr->user[0] == 0 )      // the string is under construction
       {
-         strncpy(ptr->user + 1 + strlen(ptr->user+1), data->user, 29 - strlen(ptr->user+1) );
-         if (strchr(data->user, '\n'))
+         strlcpy(ptr->user + 1 + strlen(ptr->user+1), data->user, sizeof(ptr->user)-1 - strlen(ptr->user+1) );
+         ptr->user[sizeof(ptr->user)-1] = '\0';
+         if (strchr(data->user, '\n')) // the string is ultimated
          {
-            char str[30];
+            char str[sizeof(ptr->user)];
 
             ptr->user[0] = ' ';
             strtok(ptr->user, "\n");
@@ -266,33 +306,35 @@ void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data)
                  data->dest_port == 513 || data->source_port == 513 )
                data->pass[0] = 0;        // evil workaround for telnet... we assume that pass always come AFTER login
 
-            snprintf(str, 30, "USER:%s", ptr->user);
-            strcpy(ptr->user, str);
+            snprintf(str, sizeof(ptr->user), "USER:%s", ptr->user);
+            strlcpy(ptr->user, str, sizeof(ptr->user));
          }
       }
       if ( ptr->user[0] != 0 && ptr->pass[0] == 0 )      // the string is under construction
       {
-         strncpy(ptr->pass + 1 + strlen(ptr->pass+1), data->pass, 29 - strlen(ptr->pass+1) );
-         if (strchr(data->pass, '\n'))
+         strlcpy(ptr->pass + 1 + strlen(ptr->pass+1), data->pass, sizeof(ptr->pass)-1 - strlen(ptr->pass+1) );
+         ptr->pass[sizeof(ptr->pass) -1] = '\0';
+         if (strchr(data->pass, '\n')) // the string is ultimated
          {
-            char str[30];
+            char str[sizeof(ptr->pass)];
 
             ptr->pass[0] = ' ';
             strtok(ptr->pass, "\n");
-            snprintf(str, 30, "PASS:%s", ptr->pass);
-            strcpy(ptr->pass, str);
+
+            snprintf(str, sizeof(ptr->pass), "PASS:%s", ptr->pass);
+            strlcpy(ptr->pass, str,sizeof(ptr->pass));
          }
       }
 
       if (strlen(data->info) && !strchr(ptr->info, '\n'))
-         strlcat(ptr->info, data->info, 150);
+         strlcat(ptr->info, data->info, sizeof(ptr->info));
    }
    else
    {
       if ( (data->flags & TH_SYN) ||
            ( data->dest_port != 23 && data->source_port != 23 &&
              data->dest_port != 513 && data->source_port != 513) )  // telnet and rlogin are enabled only on syn
-               ptr->user[1] = 0;                                  // ok, start collecting user and pass...
+               ptr->user[1] = 0;                                    // ok, start collecting user and pass...
    }
 }
 
@@ -300,15 +342,29 @@ void Decodedata_UpdateInfo(CONNECTION *ptr, CONNECTION *data)
 
 int Decodedata_RefreshConnectionList(void)
 {
+   struct conn_hash_list *current;
+   int i;
 
 #ifdef DEBUG
    Debug_msg("Decodedata_RefreshConnectionList");
 #endif
 
+   pthread_mutex_trylock(&connection_mutex);
+
+   for (i=0; i<HASH_SIZE; i++)
+      while(!SLIST_EMPTY(&conn_hash_array[i]))
+      {
+         current = SLIST_FIRST(&conn_hash_array[i]);
+         SLIST_REMOVE_HEAD(&conn_hash_array[i], next);
+         free(current);
+      }
+
    if (Conn_Between_Hosts) free(Conn_Between_Hosts);
    Conn_Between_Hosts = NULL;
    number_of_connections = 0;
 
+   pthread_mutex_unlock(&connection_mutex);
+
    return 0;
 }
 
@@ -320,35 +376,36 @@ void Decodedata_UpdatePassiveInfo(PASSIVE_DATA *ptr, PASSIVE_DATA *data)
    char OS[60];
 
    if (!strcmp(ptr->ip, ""))
-      strcpy(ptr->ip, data->ip);
+      strlcpy(ptr->ip, data->ip, sizeof(ptr->ip));
 
    if (!strcmp(ptr->mac, "") && strcmp(data->type, "NL"))   // no mac for non local hosts
-      strcpy(ptr->mac, data->mac);
+      strlcpy(ptr->mac, data->mac, sizeof(ptr->mac));
 
    if (!strcmp(ptr->type, ""))
-      strcpy(ptr->type, data->type);
+      strlcpy(ptr->type, data->type, sizeof(ptr->type));
 
    ptr->hop = data->hop;
 
    if (strcmp(data->fingerprint, ""))
    {
       if (!strcmp(ptr->fingerprint, ""))
-         strcpy(ptr->fingerprint, data->fingerprint);
+         strlcpy(ptr->fingerprint, data->fingerprint, sizeof(ptr->fingerprint));
 
       if (!strcmp(strrchr(ptr->fingerprint, ':'), ":A") || !strcmp(ptr->os, "") )
       {
-         strcpy(ptr->fingerprint, data->fingerprint);
+         strlcpy(ptr->fingerprint, data->fingerprint, sizeof(ptr->fingerprint));
 
          #ifdef DEBUG
-            Debug_msg("Decodedata_UpdatePassiveInfo -- %s %s", data->ip, data->fingerprint);
+            Debug_msg("Decodedata_UpdatePassiveInfo -- %15s %25s", data->ip, data->fingerprint);
          #endif
 
          if (Decodedata_GetPassiveOS(data->fingerprint, OS) == 0)
-            strcpy(ptr->os, OS);
+            strlcpy(ptr->os, OS, sizeof(ptr->os));
          else
          {
             ptr->os[0] = 0;
-            strncpy(ptr->os + 1, OS, 58);
+            strlcpy(ptr->os + 1, OS, 58);
+            ptr->os[sizeof(ptr->os)-1] = '\0';
          }
       }
    }
@@ -369,7 +426,7 @@ void Decodedata_UpdatePassiveInfo(PASSIVE_DATA *ptr, PASSIVE_DATA *data)
             {
                if (current->port == data->port)
                {
-                  strncpy(current->banner, data->banner, 149);
+                  strlcpy(current->banner, data->banner, sizeof(current->banner));
                   free(newelem);
                   break;
                }
@@ -421,28 +478,35 @@ void Decodedata_UpdatePassiveInfo(PASSIVE_DATA *ptr, PASSIVE_DATA *data)
 
 
 
-int Decodedata_MakePassiveList(PASSIVE_DATA data)
+int Decodedata_MakePassiveList(PASSIVE_DATA *data)
 {
    int num_conn = 1;
    char found = 0;
    PASSIVE_DATA *ptr;
 
+   pthread_mutex_lock(&passive_mutex);
+
    if (number_of_passive_hosts != 0)
    {
       for(ptr=Passive_Host; num_conn <= number_of_passive_hosts; ptr++)
       {
          num_conn++;
 
-         if (!strcmp(data.type, "NL") && !strcmp(ptr->mac, data.mac))      // the packet is from the GW...
+         if (!strcmp(data->type, "NL") && !strcmp(ptr->mac, data->mac))      // the packet is from the GW...
          {                                                                 // search and mark it
-            strcpy(ptr->type, "GW");
-            strcpy(ptr->gwforthis, data.ip);
+            sprintf(ptr->type, "GW");
+            strlcpy(ptr->gwforthis, data->ip, sizeof(ptr->gwforthis));
          }
 
-         if (!strcmp(ptr->ip, data.ip))
+         if (!strcmp(ptr->ip, data->ip))
          {
-            Decodedata_UpdatePassiveInfo(ptr, &data);
+            Decodedata_UpdatePassiveInfo(ptr, data);
             found = 1;
+            if (strcmp(data->type, "NL"))
+            {
+               pthread_mutex_unlock(&passive_mutex);
+               return number_of_passive_hosts;
+            }
          }
       }
    }
@@ -453,7 +517,7 @@ int Decodedata_MakePassiveList(PASSIVE_DATA data)
       struct open_ports *cur;
 
       #ifdef DEBUG
-         Debug_msg("Decodedata_MakePassiveList - new node ! %d ! %s - %s", num_conn, data.ip, data.fingerprint);
+         Debug_msg("Decodedata_MakePassiveList - new node ! %d ! %s - %s", num_conn, data->ip, data->fingerprint);
       #endif
 
       Passive_Host = (PASSIVE_DATA *)realloc(Passive_Host, num_conn*sizeof(PASSIVE_DATA));
@@ -472,10 +536,12 @@ int Decodedata_MakePassiveList(PASSIVE_DATA data)
             cur->next.le_prev = &Passive_Host[j].udp_ports.lh_first;
       }
 
-      Decodedata_UpdatePassiveInfo(&Passive_Host[num_conn-1], &data);
+      Decodedata_UpdatePassiveInfo(&Passive_Host[num_conn-1], data);
+
+      number_of_passive_hosts = num_conn;
    }
-   else
-      num_conn = number_of_passive_hosts;
+
+   pthread_mutex_unlock(&passive_mutex);
 
    return num_conn;
 
@@ -491,6 +557,8 @@ int Decodedata_FreePassiveList(void)
    Debug_msg("Decodedata_FreePassiveList");
 #endif
 
+   pthread_mutex_lock(&passive_mutex);
+
    for(i=0; i<number_of_passive_hosts; i++)
    {
       while (!LIST_EMPTY(&Passive_Host[i].tcp_ports))
@@ -511,6 +579,8 @@ int Decodedata_FreePassiveList(void)
    Passive_Host = NULL;
    number_of_passive_hosts = 0;
 
+   pthread_mutex_unlock(&passive_mutex);
+
    return 0;
 }
 
@@ -561,19 +631,19 @@ char * Decodedata_GetEnhanchedHexData(char *buffer, int buff_len, short cr)
            jm = jm > cr ? cr : jm;
 
            for (j = 0; j < jm; j++) {
-                   if ((j % 2) == 1) sprintf(hexdata,"%s%02x ", hexdata, (unsigned char) buffer[i+j]);
-                   else sprintf(hexdata,"%s%02x", hexdata, (unsigned char) buffer[i+j]);
+                   if ((j % 2) == 1) sprintf(hexdata, "%s%02x ", hexdata, (unsigned char) buffer[i+j]);
+                   else sprintf(hexdata, "%s%02x", hexdata, (unsigned char) buffer[i+j]);
            }
            for (; j < cr; j++) {
-                   if ((j % 2) == 1) strcat(hexdata,"   ");
-                   else strcat(hexdata,"  ");
+                   if ((j % 2) == 1) strcat(hexdata, "   ");
+                   else strcat(hexdata, "  ");
            }
-           strcat(hexdata," ");
+           strcat(hexdata, " ");
 
            for (j = 0; j < jm; j++) {
                    c = buffer[i+j];
                    c = isprint(c) ? c : '.';
-                   sprintf(hexdata,"%s%c", hexdata, c);
+                   sprintf(hexdata, "%s%c", hexdata, c);
            }
            strcat(hexdata,"\n");
    }
@@ -595,6 +665,43 @@ char * Decodedata_GetAsciiData(char *buffer, int buff_len)
       if ( !( isprint((int)buffer[i]) || buffer[i] == '\n' || buffer[i] == '\t') )
          buffer[i] = '.';
    }
+   buffer[i] = 0;  // terminate the string
+
+   return buffer;
+}
+
+
+char * Decodedata_GetTextData(char *buffer, int buff_len)
+{
+   int i = 0;
+
+   if (buff_len == 0) return "";
+
+   while ( i < buff_len )
+   {
+      if (buffer[i] == 0x1b && buffer[i+1] == 0x5b)      //  \033[   escape sequences
+      {
+         do
+         {
+            memmove( buffer + i, buffer + i + 1, buff_len - i - 1 );
+            buff_len--;
+         } while ( !isalpha((int)buffer[i]) && buff_len > i );
+
+         if ( i < buff_len )
+         {
+            memmove( buffer + i, buffer + i + 1, buff_len - i - 1 );
+            buff_len--;
+         }
+      }
+      else if ( !( isprint((int)buffer[i]) || buffer[i] == '\n' ))
+      {
+         memmove( buffer + i, buffer + i + 1, buff_len - i - 1 );
+         buff_len--;
+      }
+      else i++;
+   }
+
+   buffer[buff_len] = '\000';
 
    return buffer;
 }
@@ -605,7 +712,7 @@ char * Decodedata_TCPFlags(char flags)
    static char string[8];
    char *p;
 
-   memset(string, 0, 8);
+   memset(string, 0, sizeof(string));
    p = string;
 
    if (flags & TH_SYN) *p++ = 'S';
@@ -654,7 +761,7 @@ char * Decodedata_GetType(char proto, int port1, int port2)
             if (strstr (stype, "tcp")) d_index->proto = 'T';
             if (strstr (stype, "udp")) d_index->proto = 'U';
 
-            strcpy (d_index->desc, desc);
+            strlcpy (d_index->desc, desc, sizeof(d_index->desc));
 
             d_index = (database *) d_index->next;
          }
@@ -669,7 +776,7 @@ char * Decodedata_GetType(char proto, int port1, int port2)
    {
       if ( d_index->proto == proto && (port1 == d_index->port || port2 == d_index->port) )
       {
-         strcpy(type, d_index->desc);
+         strlcpy(type, d_index->desc, sizeof(type));
          return type;
       }
    }
@@ -684,10 +791,6 @@ int Decodedata_GetPassiveOS(char *fingerprint, char *os)
    os_database *os_index;
    int ret = -1;
 
-//   #ifdef DEBUG
-//      Debug_msg("Decodedata_GetPassiveOS - %s", fingerprint);
-//   #endif
-
    if (!strcmp(fingerprint, "")) // no fingerprint, no os...
    {
       strcpy(os, "");
@@ -708,13 +811,13 @@ int Decodedata_GetPassiveOS(char *fingerprint, char *os)
       f_os = fopen( "./" OS_FILE, "r");
       if (f_os == NULL)
       {
-         f_os = fopen( INSTALL_PATH OS_FILE, "r");
+         f_os = fopen( DATA_PATH "/" OS_FILE, "r");
          if (f_os == NULL)
-            Error_msg("\nCan't find " OS_FILE " in ./ or " INSTALL_PATH);
+            Error_msg("\nCan't find " OS_FILE " in ./ or " DATA_PATH);
          else
          {
             #ifdef DEBUG
-               Debug_msg("Decodedata_GetPassiveOS - loading from " INSTALL_PATH OS_FILE);
+               Debug_msg("Decodedata_GetPassiveOS - loading from " DATA_PATH "/" OS_FILE);
             #endif
          }
       }
@@ -736,9 +839,8 @@ int Decodedata_GetPassiveOS(char *fingerprint, char *os)
          if ( (os_index->next = ( struct os_database *) calloc (1, sizeof(os_database))) == NULL)
             ERROR_MSG("calloc()");
 
-         strncpy(os_index->fingerprint, line, FINGER_LEN);
-         strncpy(os_index->os, line+FINGER_LEN+1, 60);
-         os_index->os[59]=0;
+         strlcpy(os_index->fingerprint, line, sizeof(os_index->fingerprint));
+         strlcpy(os_index->os,line+FINGER_LEN+1, sizeof(os_index->os));
          os_index->os[strlen(os_index->os)-1] = 0;
 
          os_index = (os_database *) os_index->next;
@@ -758,9 +860,26 @@ int Decodedata_GetPassiveOS(char *fingerprint, char *os)
          ret = 0;
          break;
       }
-      if ( strcmp(os_index->fingerprint, fingerprint) > 0)  // take the nearest entry
+      if ( strcmp(os_index->fingerprint, fingerprint) > 0)  // take the nearest entry (next in the file)
       {
-         strcpy(os, os_index->os);
+         char win[5];
+         char pattern[FINGER_LEN+1];
+
+         strcpy(os, os_index->os);  //save the nearest OLD STYLE
+
+         strlcpy(win, fingerprint, sizeof(win));
+         strlcpy(pattern, win, sizeof(pattern));
+         strlcat(pattern, ":*:", sizeof(pattern));
+         strlcat(pattern, fingerprint + 10, sizeof(pattern));
+
+         while (!strncmp(os_index->fingerprint, win, 4))
+         {
+            if (match_pattern(os_index->fingerprint, pattern))
+            {
+               strcpy(os, os_index->os);  //save the nearest NEW STYLE (bypassing the MSS)
+            }
+            os_index = (os_database *)os_index->next;
+         }
          ret = 1;
          break;
       }
@@ -785,6 +904,8 @@ void Decodedata_ConvertPassiveToHost(void)
    Debug_msg("Decodedata_ConvertPassiveToHost -- %d", number_of_hosts_in_lan);
 #endif
 
+   pthread_mutex_lock(&passive_mutex);
+
    if (number_of_hosts_in_lan > 1) number_of_hosts_in_lan = 1;
 
    if (number_of_passive_hosts != 0)
@@ -804,9 +925,13 @@ void Decodedata_ConvertPassiveToHost(void)
 
             strcpy(Host_In_LAN[number_of_hosts_in_lan-1].ip, ptr->ip);
             strcpy(Host_In_LAN[number_of_hosts_in_lan-1].mac, ptr->mac);
+            strcpy(Host_In_LAN[number_of_hosts_in_lan-1].name, "unknown");
          }
       }
    }
+
+   pthread_mutex_unlock(&passive_mutex);
+
 #ifdef DEBUG
    Debug_msg("Decodedata_ConvertPassiveToHost -- %d host(s) converted ", number_of_hosts_in_lan );
 #endif
@@ -838,6 +963,8 @@ void Decodedata_Passive_SortList(void)
    Debug_msg("Decodedata_Passive_SortList");
 #endif
 
+   pthread_mutex_lock(&passive_mutex);
+
    qsort(Passive_Host, number_of_passive_hosts, sizeof(PASSIVE_DATA), (int (*)(const void *, const void *))Decodedata_Compare_Host);
 
    for (i=0; i<number_of_passive_hosts; i++)    // do a consistency check on the list
@@ -850,6 +977,7 @@ void Decodedata_Passive_SortList(void)
          cur->next.le_prev = &Passive_Host[i].udp_ports.lh_first;
    }
 
+   pthread_mutex_unlock(&passive_mutex);
 }
 
 
