@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector.c,v 1.10 2001/12/08 11:22:20 alor Exp $
+    $Id: ec_dissector.c,v 1.12 2002/01/22 21:23:01 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -27,6 +27,8 @@
 #include "include/ec_decodedata.h"
 #include "include/ec_error.h"
 
+#define ALL_P 0
+
 
 struct state_machine   // state machine double linked list for some protocol dissector
 {
@@ -34,8 +36,8 @@ struct state_machine   // state machine double linked list for some protocol dis
    time_t timeout;
    long source_ip;
    long dest_ip;
-   short source_port;
-   short dest_port;
+   u_short source_port;
+   u_short dest_port;
    char proto;
    char state;
    char info[20];
@@ -101,6 +103,7 @@ DISSECTOR Available_Dissectors[] = {
    {MACBASED,  IPPROTO_TCP,  8888, &Dissector_napster,   1, "NAPSTER"},
    {MACBASED,  IPPROTO_UDP, 27015, &Dissector_hl_rcon,   1, "HL-RCON"},
    {MACBASED,  IPPROTO_TCP, 65301, &Dissector_pcanywhere,1, "PCANYWHERE"},
+   {MACBASED,  IPPROTO_UDP, ALL_P, &Dissector_icq,       1, "ICQ"},
    {       0,            0,     0,                 NULL, 0, ""}
 };
 
@@ -138,9 +141,10 @@ int Dissector_Connections( char mode, short proto, u_char *data, CONNECTION *dat
       case IPPROTO_TCP:
                         tcp = (TCP_header *) data;
 
-                        for( ds = Available_Dissectors; ds->port != 0; ds++)
+                        for( ds = Available_Dissectors; ds->dissector != NULL; ds++)
                         {
-                           if ( ds->active && (ntohs(tcp->source) == ds->port || ntohs(tcp->dest) == ds->port) && ds->proto == IPPROTO_TCP && mode <= ds->mode  )
+                           if ( ds->active && (ntohs(tcp->source) == ds->port || ntohs(tcp->dest) == ds->port || ds->port == ALL_P)
+                             && ds->proto == IPPROTO_TCP && mode <= ds->mode  )
                            {
                               if (ds->mode <= PUBLICARP)
                               {
@@ -175,9 +179,10 @@ int Dissector_Connections( char mode, short proto, u_char *data, CONNECTION *dat
       case IPPROTO_UDP:
                         udp = (UDP_header *) data;
 
-                        for( ds = Available_Dissectors; ds->port != 0; ds++)
+                        for( ds = Available_Dissectors; ds->dissector != NULL; ds++)
                         {
-                           if ( ds->active && (ntohs(udp->source) == ds->port || ntohs(udp->dest) == ds->port) && ds->proto == IPPROTO_UDP && mode <= ds->mode  )
+                           if ( ds->active && (ntohs(udp->source) == ds->port || ntohs(udp->dest) == ds->port || ds->port == ALL_P)
+                             && ds->proto == IPPROTO_UDP && mode <= ds->mode  )
                            {
                               if (ds->mode <= PUBLICARP)
                               {
