@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_bgp.c,v 1.6 2001/12/13 17:05:20 alor Exp $
+    $Id: ec_dissector_bgp.c,v 1.7 2001/12/20 20:09:45 alor Exp $
 */
 
 /*
@@ -151,11 +151,11 @@ FUNC_DISSECTOR(Dissector_bgp)
          sprintf(data_to_ettercap->user, "\n");
          snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "AUTH TYPE 0x%02x\n", parameters[i+2]);
          strlcpy(data_to_ettercap->pass, parameters + i + 3, (len>28) ? 28 : (len+1));
-         strcat(data_to_ettercap->pass, "\n");
+         strlcat(data_to_ettercap->pass, "\n", sizeof(data_to_ettercap->pass));
+         return 0;
       }
    }
 
-
    return 0;
 }
 
