@@ -17,24 +17,17 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_http.c,v 1.2 2001/09/06 20:07:42 alor Exp $
+    $Id: ec_dissector_http.c,v 1.11 2001/12/13 17:05:20 alor Exp $
 */
 
 #include "include/ec_main.h"
 
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <ctype.h>
 
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_error.h"
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
 
 #define USER 1
 #define PASS 2
@@ -53,7 +46,7 @@ FUNC_DISSECTOR(Dissector_http)
    TCP_header *tcp;
    u_char *payload;
    char *fromhere = NULL;
-   char collector[MAX_DATA];
+   char collector[MAX_DATA*5];
    ONLY_CONNECTION;
 
    tcp = (TCP_header *) data;
@@ -63,7 +56,7 @@ FUNC_DISSECTOR(Dissector_http)
 
    payload = (char *)((int)tcp + tcp->doff * 4);
 
-   memset(collector, 0, MAX_DATA);
+   memset(collector, 0, sizeof(collector));
    memcpy(collector, payload, data_to_ettercap->datalen);
 
    /*
@@ -80,6 +73,7 @@ FUNC_DISSECTOR(Dissector_http)
       char *q;
       char user[25];
       char pass[25];
+      size_t len;
 
       #ifdef DEBUG
          Debug_msg("\tDissector_HTTP %d -- method GET -- \n\n%s\n\n", SERV_PORT, collector);
@@ -94,9 +88,9 @@ FUNC_DISSECTOR(Dissector_http)
       if (parse_form(to_parse, user, USER) && parse_form(to_parse, pass, PASS))
       {
          decode_url(user);
-         strlcat(data_to_ettercap->user, user, 25);
+         strlcpy(data_to_ettercap->user, user, sizeof(data_to_ettercap->user));
          decode_url(pass);
-         strlcat(data_to_ettercap->pass, pass, 25);
+         strlcpy(data_to_ettercap->pass, pass, sizeof(data_to_ettercap->pass));
 
          if ((fromhere = strstr(collector, "Referer:")))    // if exist the referer
          {
@@ -113,19 +107,23 @@ FUNC_DISSECTOR(Dissector_http)
                page = strdup( fromhere + strlen("GET ") );
                strtok(page, " HTTP");
             }
-            else page = strdup("/unknown");
+            else
+               page = strdup("/unknown");
 
             if ((fromhere = strstr(collector, "Host:")))
             {
                host = strdup( fromhere + strlen("Host: ") );
                strtok(host, "\r\n");
             }
-            else host = strdup("http://unknown");
+            else
+               host = strdup("http://unknown");
 
-            url = realloc(url, strlen(page)+strlen(host)+2);
+            len = strlen(page)+strlen(host)+2;
+            url = realloc(url, len);
             if (url == NULL)
                ERROR_MSG("realloc()");
-            sprintf(url, "%s%s", host, page);
+            url[len-1]='\0';
+            snprintf(url, len, "%s%s", host, page);
 
             free(page);
             free(host);
@@ -139,7 +137,7 @@ FUNC_DISSECTOR(Dissector_http)
          #endif
 
          decode_url(url);
-         snprintf(data_to_ettercap->info, 145, "%s\n", url);
+         snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "%s\n", url);
          free(url);
       }
       free(to_parse);
@@ -156,6 +154,7 @@ FUNC_DISSECTOR(Dissector_http)
       char *url = NULL;
       char user[25];
       char pass[25];
+      size_t len;
 
       #ifdef DEBUG
          Debug_msg("\tDissector_HTTP %d -- method POST -- \n\n%s\n\n", SERV_PORT, collector);
@@ -185,11 +184,12 @@ FUNC_DISSECTOR(Dissector_http)
          }
          else host = strdup("http://unknown");
 
-         url = realloc(url, strlen(page)+strlen(host)+2);
+         len = strlen(page)+strlen(host)+2;
+         url = realloc(url, len);
          if (url == NULL)
            ERROR_MSG("realloc()");
-
-         sprintf(url, "%s%s", host, page);
+         url[len-1] = '\0';
+         snprintf(url, len, "%s%s", host, page);
          free(page);
          free(host);
          #ifdef DEBUG
@@ -201,14 +201,15 @@ FUNC_DISSECTOR(Dissector_http)
          Debug_msg("\tDissector_HTTP -- after page [%s]", url);
       #endif
 
-      if (strstr(collector, "User-Agent: Mozilla") && !strstr(collector, "MSIE"))   // if user-agent is Netscape
+      if (strstr(collector, "User-Agent: Mozilla") && !strstr(collector, "MSIE")
+          && !strstr(collector,"Opera"))                                            // if user-agent is Netscape
       {                                                                             // it posts the data in the
          #ifdef DEBUG                                                               // second packet, so we set
             Debug_msg("\tDissector_HTTP -- method POST -- mozilla");                // the state to catch them
          #endif                                                                     // later
          Dissector_StateMachine_SetStatus(data_to_ettercap, 1, NULL);
          decode_url(url);
-         snprintf(data_to_ettercap->info, 145, "%s\n", url);
+         snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "%s\n", url);
          free(url);
          return 0;
       }
@@ -233,12 +234,12 @@ FUNC_DISSECTOR(Dissector_http)
       if (parse_form(to_parse, user, USER) && parse_form(to_parse, pass, PASS))
       {
          decode_url(user);
-         strlcat(data_to_ettercap->user, user, 25);
+         strlcpy(data_to_ettercap->user, user, sizeof(data_to_ettercap->user));
          decode_url(pass);
-         strlcat(data_to_ettercap->pass, pass, 25);
+         strlcpy(data_to_ettercap->pass, pass, sizeof(data_to_ettercap->pass));
          decode_url(url);
-         snprintf(data_to_ettercap->info, 145, "%s\n", url);
-         free(page);
+         snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "%s\n", url);
+         free(url);
       }
       return 0;
    }
@@ -278,9 +279,9 @@ FUNC_DISSECTOR(Dissector_http)
       if (parse_form(to_parse, user, USER) && parse_form(to_parse, pass, PASS))
       {
          decode_url(user);
-         strlcat(data_to_ettercap->user, user, 25);
+         strlcat(data_to_ettercap->user, user, sizeof(data_to_ettercap->user));
          decode_url(pass);
-         strlcat(data_to_ettercap->pass, pass, 25);
+         strlcat(data_to_ettercap->pass, pass, sizeof(data_to_ettercap->pass));
          Dissector_StateMachine_SetStatus(data_to_ettercap, 0, NULL);
       }
       return 0;
@@ -294,15 +295,16 @@ FUNC_DISSECTOR(Dissector_http)
 
    if ( (fromhere = strstr(collector, "Authorization: Basic")) || (fromhere = strstr(collector, "Proxy-authorization: Basic")) )
    {
-      char user[25];
-      char pass[25];
+      char user[25] = "";
+      char pass[25] = "";
       char *decoded;
       char *to_be_decoded;
+      char *token;
       char *page = NULL;
       char *host = NULL;
 
       #ifdef DEBUG
-         Debug_msg("\tDissector_HTTP -- Authorization");
+         Debug_msg("\tDissector_HTTP -- Authorization -- %s", fromhere);
       #endif
 
       if (strstr(collector, "GET"))
@@ -334,18 +336,31 @@ FUNC_DISSECTOR(Dissector_http)
       decoded = strdup(to_be_decoded); // allocate the memory...
 
       Dissector_base64decode(decoded, to_be_decoded);
-      strncpy(user, strtok(decoded, ":"), 20);  strcat(user, "\n");
-      strncpy(pass, strtok(NULL, ":"), 20);     strcat(pass, "\n");
 
-      decode_url(user);
-      strlcat(data_to_ettercap->user, user, 25);
-      decode_url(pass);
-      strlcat(data_to_ettercap->pass, pass, 25);
-      snprintf(data_to_ettercap->info, 145, "http://%s%s\n", host, page);
+      #ifdef DEBUG
+         Debug_msg("\tDissector_HTTP - decoding - [%s] [%s]", to_be_decoded, decoded);
+      #endif
+
+      if ( (token = strsep(&decoded, ":")) != NULL)
+      {
+         strlcpy(user, token, 20);
+         strcat(user, "\n");
+         decode_url(user);
+         strlcat(data_to_ettercap->user, user, sizeof(data_to_ettercap->user));
+
+         if ( (token = strsep(&decoded, ":")) != NULL)
+         {
+            strlcpy(pass, token, 20);
+            strcat(pass, "\n");
+            decode_url(pass);
+            strlcat(data_to_ettercap->pass, pass, sizeof(data_to_ettercap->pass));
+         }
+      }
+
+      snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "http://%s%s\n", host, page);
 
       #ifdef DEBUG
          Debug_msg("\tDissector_HTTP -- [%s][%s]", host, page);
-         Debug_msg("\tDissector_HTTP -- [%s]", to_be_decoded);
       #endif
 
       free(page);
@@ -379,6 +394,8 @@ int parse_form(char *to_parse, char *ret, char mode)
    char *var = NULL;
    char *q = tmp;
 
+   decode_url(to_parse);
+
    if (to_parse[0] == '?') to_parse++;    // strip the '?' from a GET method
 
    tmp = strdup(to_parse);
@@ -425,12 +442,14 @@ void decode_url(char *src)
    char t[3];
    int i, j, ch;
 
+   memset(t, 0, sizeof(t));
+
    for (i = 0, j = 0; src[i] != '\0'; i++, j++)
    {
       ch = src[i];
       if (ch == '%' && isxdigit((int)src[i + 1]) && isxdigit((int)src[i + 2]))
       {
-         strncpy(t, src+i+1, 2);
+         strlcpy(t, src+i+1, 3);
          ch = strtoul(t, NULL, 16);
          i += 2;
       }
