@@ -19,7 +19,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_icq.c,v 1.7 2001/12/13 17:05:20 alor Exp $
+    $Id: ec_dissector_icq.c,v 1.8 2001/12/20 20:09:45 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -133,7 +133,7 @@ FUNC_DISSECTOR(Dissector_icq)
 
    payload = (char *) (int)udp + UDP_HEADER;
 
-   if (ntohs(udp->source) == SERV_PORT) return 0;  // Skip server messages...
+   //if (ntohs(udp->source) == SERV_PORT) return 0;  // Skip server messages...
    if (data_to_ettercap->datalen == 0) return 0;   // No data...
 
    memset(collector, 0, MAX_DATA);
