@@ -17,23 +17,15 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_imap.c,v 1.1.1.1 2001/08/27 19:26:01 alor Exp $
+    $Id: ec_dissector_imap.c,v 1.5 2001/12/09 20:24:51 alor Exp $
 */
 
 #include "include/ec_main.h"
 
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
-
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_error.h"
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
 // protos
 
 FUNC_DISSECTOR(Dissector_imap);
@@ -51,7 +43,8 @@ FUNC_DISSECTOR(Dissector_imap)
 
    tcp = (TCP_header *) data;
 
-   if (ntohs(tcp->source) == SERV_PORT) return 0;           // skip server messages...
+   if (ntohs(tcp->source) == SERV_PORT) return 0;     // skip server messages...
+   if (data_to_ettercap->datalen == 0) return 0;      // no data...
 
    payload = (char *)((int)tcp + tcp->doff * 4);
 
@@ -64,13 +57,16 @@ FUNC_DISSECTOR(Dissector_imap)
          Debug_msg("\tDissector_IMAP LOGIN ");
       #endif
 
-      strncpy(collector, fromhere + strlen("LOGIN ") , 80 );
+      strlcpy(collector, fromhere + strlen("LOGIN "), sizeof(collector) );
       p = strtok(collector, " ");
       if (p)
       {
          snprintf(data_to_ettercap->user, 25, "%s\n", p);
          p = strtok(NULL, " ");
-         if (p) snprintf(data_to_ettercap->pass, 25, "%s\n", p);
+         if (p)
+            snprintf(data_to_ettercap->pass, 25, "%s\n", p);
+         else
+            sprintf(data_to_ettercap->pass, "\n");
       }
 
       return 0;
@@ -87,7 +83,7 @@ FUNC_DISSECTOR(Dissector_imap)
                      Debug_msg("\tDissector_IMAP %s", payload);
                   #endif
 
-                  strncpy(collector, fromhere + strlen("AUTHENTICATE ") , 80 );
+                  strlcpy(collector, fromhere + strlen("AUTHENTICATE "), sizeof(collector) );
 
                   if (!strncasecmp(collector, "LOGIN", 5))
                   {
@@ -99,9 +95,9 @@ FUNC_DISSECTOR(Dissector_imap)
                   }
                   else
                   {
-                     snprintf(data_to_ettercap->user, 25, "\n");
-                     snprintf(data_to_ettercap->pass, 25, "\n");
-                     snprintf(data_to_ettercap->info, 80, "Authenticated with %s\n", collector);
+                     sprintf(data_to_ettercap->user, "\n");
+                     sprintf(data_to_ettercap->pass, "\n");
+                     snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "Authenticated with %s\n", collector);
                   }
                }
                break;
@@ -124,7 +120,7 @@ FUNC_DISSECTOR(Dissector_imap)
                   #endif
                   Dissector_base64decode(collector, payload);
                   snprintf(data_to_ettercap->pass, 25, "%s\n", collector);
-                  snprintf(data_to_ettercap->info, 80, "Authenticated LOGIN\n");
+                  snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "Authenticated LOGIN\n");
                   Dissector_StateMachine_SetStatus(data_to_ettercap, 0, NULL);
                }
                break;
@@ -136,8 +132,8 @@ FUNC_DISSECTOR(Dissector_imap)
                   #endif
                   Dissector_base64decode(collector, payload);
                   snprintf(data_to_ettercap->user, 25, "%s\n", collector);
-                  snprintf(data_to_ettercap->pass, 25, "\n");
-                  snprintf(data_to_ettercap->info, 80, "Authenticated with %s\n", collector);
+                  sprintf(data_to_ettercap->pass, "\n");
+                  snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "Authenticated with %s\n", collector);
                   Dissector_StateMachine_SetStatus(data_to_ettercap, 0, NULL);
                }
                break;
