@@ -17,23 +17,15 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_nntp.c,v 1.1.1.1 2001/08/27 19:25:46 alor Exp $
+    $Id: ec_dissector_nntp.c,v 1.4 2001/12/09 20:24:51 alor Exp $
 */
 
 #include "include/ec_main.h"
 
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
-
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_error.h"
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
 // protos
 
 FUNC_DISSECTOR(Dissector_nntp);
@@ -50,28 +42,25 @@ FUNC_DISSECTOR(Dissector_nntp)
 
    tcp = (TCP_header *) data;
 
-   if (ntohs(tcp->source) == SERV_PORT) return 0;            // skip server messages...
+   if (ntohs(tcp->source) == SERV_PORT) return 0;     // skip server messages...
+   if (data_to_ettercap->datalen == 0) return 0;      // no data...
 
    payload = (char *)((int)tcp + tcp->doff * 4);
 
    if ( !strncasecmp(payload, "AUTHINFO USER", 13) )
    {
-      char user[25];
       #ifdef DEBUG
          Debug_msg("\tDissector_NNTP USER");
       #endif
-      strncpy(user, payload + 14 , 25 );
-      strcat(data_to_ettercap->user, user);
+      snprintf(data_to_ettercap->user, sizeof(data_to_ettercap->user), "%s\n", payload + 14);
    }
 
    if ( !strncasecmp(payload, "AUTHINFO PASS", 13) )
    {
-      char pass[25];
       #ifdef DEBUG
          Debug_msg("\tDissector_NNTP PASS");
       #endif
-      strncpy(pass, payload + 14 , 25 );
-      strcat(data_to_ettercap->pass, pass);
+      snprintf(data_to_ettercap->pass, sizeof(data_to_ettercap->pass), "%s\n", payload + 14);
    }
 
    return 0;
