@@ -17,23 +17,15 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_pop.c,v 1.1.1.1 2001/08/27 19:25:35 alor Exp $
+    $Id: ec_dissector_pop.c,v 1.5 2001/12/09 20:24:51 alor Exp $
 */
 
 #include "include/ec_main.h"
 
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
-
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_error.h"
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
 // protos
 
 FUNC_DISSECTOR(Dissector_pop);
@@ -50,43 +42,42 @@ FUNC_DISSECTOR(Dissector_pop)
 
    tcp = (TCP_header *) data;
 
-   if (ntohs(tcp->source) == SERV_PORT) return 0;           // skip server messages...
+   if (ntohs(tcp->source) == SERV_PORT) return 0;     // skip server messages...
+   if (data_to_ettercap->datalen == 0) return 0;      // no data...
 
    payload = (char *)((int)tcp + tcp->doff * 4);
 
    if ( !strncasecmp(payload, "USER", 4) )
    {
-      char user[25];
       #ifdef DEBUG
          Debug_msg("\tDissector_POP USER");
       #endif
-      strncpy(user, payload + strlen("USER ") , 25 );
-      strcpy(data_to_ettercap->user, user);
+      strlcpy(data_to_ettercap->user, payload + strlen("USER "), sizeof(data_to_ettercap->user));
    }
 
    if ( !strncasecmp(payload, "PASS", 4) )
    {
-      char pass[25];
       #ifdef DEBUG
          Debug_msg("\tDissector_POP PASS");
       #endif
-      strncpy(pass, payload + strlen("PASS ") , 25 );
-      strcpy(data_to_ettercap->pass, pass);
+      strlcpy(data_to_ettercap->pass, payload + strlen("PASS "), sizeof(data_to_ettercap->pass));
    }
 
    if ( !strncasecmp(payload, "APOP", 4) )
    {
-      char user[25];
       char *p;
       #ifdef DEBUG
          Debug_msg("\tDissector_POP APOP");
       #endif
 
-      strncpy(user, strtok(payload + strlen("APOP "), " ") , 25 );
-      sprintf(data_to_ettercap->user, "%s\n", user);
-      strcpy(data_to_ettercap->pass, "\n");
-      p = strtok(NULL, " ");
-      sprintf(data_to_ettercap->info, "Authenticated with APOP %s\n", (p) ? p : "");
+      p = strtok(payload + strlen("APOP "), " ");
+      if (p)
+      {
+         snprintf(data_to_ettercap->user, sizeof(data_to_ettercap->user), "%s\n", p);
+         sprintf(data_to_ettercap->pass, "\n");
+         p = strtok(NULL, " ");
+         snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "Authenticated with APOP %s\n", (p) ? p : "");
+      }
    }
 
    return 0;
