@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_rip.c,v 1.1.1.1 2001/08/27 19:25:57 alor Exp $
+    $Id: ec_dissector_rip.c,v 1.3 2001/12/06 17:53:01 alor Exp $
 */
 
 /*
@@ -54,18 +54,10 @@
 
 #include "include/ec_main.h"
 
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
-
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_error.h"
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
 // protos
 
 FUNC_DISSECTOR(Dissector_rip);
@@ -97,9 +89,9 @@ FUNC_DISSECTOR(Dissector_rip)
                   #ifdef DEBUG
                      Debug_msg("\tDissector_RIP version 2 simple AUTH");
                   #endif
-                  strcat(data_to_ettercap->user, "RIP version 2\n");
-                  strncpy(data_to_ettercap->pass, payload+8, 16);
-                  strcat(data_to_ettercap->pass, "\n");
+                  sprintf(data_to_ettercap->user, "RIP version 2\n");
+                  strlcpy(data_to_ettercap->pass, payload+8, sizeof(data_to_ettercap->pass)-1);
+                  strlcat(data_to_ettercap->pass, "\n", sizeof(data_to_ettercap->pass));
                }
                break;
       case 4:           // TODO RIP v4
