@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_smb.c,v 1.1.1.1 2001/08/27 19:25:13 alor Exp $
+    $Id: ec_dissector_smb.c,v 1.6 2001/12/09 20:24:51 alor Exp $
 */
 
 /*
@@ -49,19 +49,12 @@
 
 #include "include/ec_main.h"
 
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
 #include <errno.h>
 
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_error.h"
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
 #define LM_PROT 0x0D
 #define NT_PROT 0x11
 #define PLAIN_TEXT 0
@@ -131,21 +124,38 @@ FUNC_DISSECTOR(Dissector_smb)
          ptr += 2;
          unilen = ptohs(ptr);       // UNICODE password len
 
+         memset(pass, 0, sizeof(pass));
+         if (pwlen > 24 || unilen > 24) return (0);
+
          #ifdef DEBUG
             Debug_msg("\tDissector_SMB NT LM 0.12 LEN [%d]-[%d]", pwlen, unilen);
          #endif
 
          if (pwlen > 0 && Dissector_StateMachine_GetStatus(data_to_ettercap, NULL) == PLAIN_TEXT)
-            strncpy(pass, ptr + 12, 25);
+            strlcpy(pass, ptr + 12, sizeof(pass)-2);
 
          user = ptr + 12 + pwlen + unilen;
 
          if ( strlen(user) == 0 && strlen(pass) == 0) return 0; // skip this...
 
-         snprintf(data_to_ettercap->user, 25, "%s\n", user);
-         strcat(data_to_ettercap->pass, pass);
-         if (pass[0]!=0)
-             strcat(data_to_ettercap->pass, "\n");  // don't forget it !!   datadecode needs it !!
+         if (user[2]==0) // Does anyone uses 2 chars users?
+         {               // think it's unicode
+            int i=0;
+            data_to_ettercap->user[0] = 0;
+
+            for(user++; *user!=0 && i<22 && user[1]==0; user+=2)
+            {
+               i++;
+               strlcat(data_to_ettercap->user, user, sizeof(data_to_ettercap->user)-1);
+            }
+            strlcat(data_to_ettercap->user, "\n", sizeof(data_to_ettercap->user));
+         }
+         else
+            snprintf(data_to_ettercap->user, sizeof(data_to_ettercap->user), "%s\n", user);
+
+         strlcat(data_to_ettercap->pass, pass, sizeof(data_to_ettercap->pass)-1);
+         if (pass[0] != 0)
+            strcat(data_to_ettercap->pass, "\n");  // don't forget it !!   datadecode needs it !!
 
          #ifdef DEBUG
             Debug_msg("\tDissector_SMB NT LM 0.12 USER & PASS");
@@ -165,17 +175,35 @@ FUNC_DISSECTOR(Dissector_smb)
          pwlen = ptohs(ptr);     // ANSI password len
          ptr += 2;
 
+
+         memset(pass, 0, sizeof(pass));
+         if (pwlen > 24) return (0);
+
          if (pwlen > 0 && Dissector_StateMachine_GetStatus(data_to_ettercap, NULL) == PLAIN_TEXT)
-            strncpy(pass, ptr + 6, 25);
+            strlcpy(pass, ptr + 6, sizeof(pass));
 
          user = ptr + 6 + pwlen;
 
          if ( strlen(user) == 0 && strlen(pass) == 0) return 0; // skip this...
 
-         snprintf(data_to_ettercap->user, 25, "%s\n", user);
-         strcat(data_to_ettercap->pass, pass);
-         if (pass[0]!=0)
-             strcat(data_to_ettercap->pass, "\n");  // don't forget it !!   datadecode needs it !!
+         if (user[2]==0) // Does anyone uses 2 chars users?
+         {               // think it's unicode
+            int i=0;
+            data_to_ettercap->user[0]=0;
+
+            for(user++; *user!=0 && i<22 && user[1]==0; user+=2)
+            {
+               i++;
+               strlcat(data_to_ettercap->user, user, sizeof(data_to_ettercap->user)-1);
+            }
+            strlcat(data_to_ettercap->user, "\n", sizeof(data_to_ettercap->user));
+         }
+         else
+            snprintf(data_to_ettercap->user, sizeof(data_to_ettercap->user), "%s\n", user);
+
+         strlcat(data_to_ettercap->pass, pass, sizeof(data_to_ettercap->pass)-1);
+         if (pass[0] != 0)
+            strcat(data_to_ettercap->pass, "\n");  // don't forget it !!   datadecode needs it !!
 
       }
 
@@ -203,13 +231,13 @@ FUNC_DISSECTOR(Dissector_smb)
             memcpy (pcs+j, (payload + (pw_offset[i] + j*4)), 4);
             pcs[j]=ntohl(pcs[j]);
          }
-         sprintf (lmhash, "%.8x%.8x%.8x%.8x%.8x%.8x", pcs[0], pcs[1], pcs[2], pcs[3], pcs[4], pcs[5]);
+         snprintf (lmhash, sizeof(lmhash), "%.8x%.8x%.8x%.8x%.8x%.8x", pcs[0], pcs[1], pcs[2], pcs[3], pcs[4], pcs[5]);
 
-         strcat (data_to_ettercap->info,lmhash);
-         if (!i) strcat(data_to_ettercap->info,":");
+         strlcat (data_to_ettercap->info, lmhash, sizeof(data_to_ettercap->info));
+         if (!i) strlcat(data_to_ettercap->info, ":", sizeof(data_to_ettercap->info));
       }
-      strcat (data_to_ettercap->pass,"\n");
-      strcat (data_to_ettercap->info,"\n");
+      strlcat (data_to_ettercap->pass, "\n", sizeof(data_to_ettercap->pass));
+      strlcat (data_to_ettercap->info, "\n", sizeof(data_to_ettercap->info));
       Dissector_StateMachine_SetStatus(data_to_ettercap, 0, NULL);
    }
    else if (smb->cmd == 0x72 && data_to_ettercap->source_port == SERV_PORT)
@@ -222,13 +250,13 @@ FUNC_DISSECTOR(Dissector_smb)
 
       Dissector_StateMachine_SetStatus(data_to_ettercap, payload[36], NULL);
 
-		if (!(payload[39] & 2))		// ...010 (crypyed)  ...000 (plaintext)
-		{
-			#ifdef DEBUG
-        		Debug_msg("\tDissector_SMB -- PLAIN TEXT PASSWORD");
-      	#endif
-			Dissector_StateMachine_SetStatus(data_to_ettercap, PLAIN_TEXT, NULL);
-		}
+      if (!(payload[39] & 2))    // ...010 (crypyed)  ...000 (plaintext)
+      {
+         #ifdef DEBUG
+            Debug_msg("\tDissector_SMB -- PLAIN TEXT PASSWORD");
+         #endif
+         Dissector_StateMachine_SetStatus(data_to_ettercap, PLAIN_TEXT, NULL);
+      }
 
       if (Dissector_StateMachine_GetStatus(data_to_ettercap, NULL) == LM_PROT) sk_offset = SK_OFFSET_LM2;
       else if (Dissector_StateMachine_GetStatus(data_to_ettercap, NULL) == NT_PROT) sk_offset = SK_OFFSET_NT12;
@@ -242,7 +270,7 @@ FUNC_DISSECTOR(Dissector_smb)
       }
       pcs[0]=(pcs[0]<<8)>>8;
       pcs[2]=((u_long)pcs[2])>>24;
-      sprintf(data_to_ettercap->info,"LC 2.5 FORMAT: \"USER\":3:%.6x%.8x%.2x:",pcs[0],pcs[1],pcs[2]);
+      snprintf(data_to_ettercap->info, sizeof(data_to_ettercap->info), "LC 2.5 FORMAT: \"USER\":3:%.6x%.8x%.2x:",pcs[0],pcs[1],pcs[2]);
    }
    return 0;
 }
