@@ -17,23 +17,15 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_socks.c,v 1.1.1.1 2001/08/27 19:25:56 alor Exp $
+    $Id: ec_dissector_socks.c,v 1.5 2001/12/13 17:05:20 alor Exp $
 */
 
 #include "include/ec_main.h"
 
-#include <string.h>
-#include <stdio.h>
-#include <stdlib.h>
-
 #include "include/ec_dissector.h"
 #include "include/ec_inet_structures.h"
 #include "include/ec_error.h"
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
 // protos
 
 FUNC_DISSECTOR(Dissector_socks);
@@ -66,15 +58,14 @@ FUNC_DISSECTOR(Dissector_socks)
    if (Dissector_StateMachine_GetStatus(data_to_ettercap, NULL) == 1 && ntohs(tcp->dest) == SERV_PORT)
    {
       len = *++payload;
-      if (len>23) len = 23;		// adapted to fit in our buffer...
+      if (len>23) len = 23;      // adapted to fit in our buffer...
 
       #ifdef DEBUG
          Debug_msg("\tDissector_SOCKS 5 -- USER len %d", len);
       #endif
 
-      strncpy(data_to_ettercap->user, ++payload, len);
-      data_to_ettercap->user[len] = 0;
-      strcat(data_to_ettercap->user, "\n");
+      strlcpy(data_to_ettercap->user, ++payload, len+1);
+      sprintf(data_to_ettercap->user, "\n");
 
       payload += len;
       len = *payload;
@@ -84,9 +75,8 @@ FUNC_DISSECTOR(Dissector_socks)
          Debug_msg("\tDissector_SOCKS 5 -- PASS len %d", len);
       #endif
 
-      strncpy(data_to_ettercap->pass, ++payload, len);
-      data_to_ettercap->pass[len] = 0;
-      strcat(data_to_ettercap->pass, "\n");
+      strlcpy(data_to_ettercap->pass, ++payload, len+1);
+      sprintf(data_to_ettercap->pass, "\n");
 
       Dissector_StateMachine_SetStatus(data_to_ettercap, 0, NULL);
    }
