@@ -17,25 +17,19 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_error.c,v 1.2 2001/09/06 20:07:42 alor Exp $
+    $Id: ec_error.c,v 1.6 2001/12/08 11:22:20 alor Exp $
 */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <stdarg.h>
-#include <errno.h>
-
 #include "include/ec_main.h"
 
+#include <stdarg.h>
+#include <errno.h>
+
+
 #ifdef HAVE_NCURSES
     #include "include/ec_interface.h"
 #endif
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
 // protos
 
 void Error_msg(char *message, ...);
@@ -46,18 +40,18 @@ void Error_critical_msg(char *file, char *function, int line, char *message);
 void Error_msg(char *message, ...)
 {
    va_list ap;
-   char errmsg[150];    // should be enough
+   char errmsg[201];    // should be enough
 
    va_start(ap, message);
-   vsnprintf(errmsg, 150, message, ap);
+   vsnprintf(errmsg, 200, message, ap);
    va_end(ap);
 
 #ifdef DEBUG
-      Debug_msg("Error_msg -- %s", errmsg);
+   Debug_msg("Error_msg -- %s", errmsg);
 #endif
 
 #ifdef HAVE_NCURSES
-   if (!Options.normal && !strcmp(program_argv0, PROGRAM))
+   if (!Options.normal)
       Interface_WExit(errmsg);
 #endif
 
@@ -68,16 +62,17 @@ void Error_msg(char *message, ...)
 
 void Error_critical_msg(char *file, char *function, int line, char *message)
 {
-   char err[200];
+   char err[201];
 
    snprintf(err, 200, "[%s:%s:%d] %s | ERRNO %d | %s", file, function, line, message, errno, strerror(errno));
+   err[200] = 0;
 
 #ifdef DEBUG
       Debug_msg("Error_msg -- %s",  err);
 #endif
 
 #ifdef HAVE_NCURSES
-   if (!Options.normal && !strcmp(program_argv0, PROGRAM))
+   if (!Options.normal)
       Interface_WExit(err);
 #endif
 
