@@ -17,19 +17,12 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_filterdrop.c,v 1.2 2001/09/06 20:07:42 alor Exp $
+    $Id: ec_filterdrop.c,v 1.5 2001/12/06 17:53:01 alor Exp $
 */
 
 #include "include/ec_main.h"
 
-#include <stdio.h>
-#include <unistd.h>
-#include <stdlib.h>
 #include <errno.h>
-#if defined (LINUX) && !defined (__USE_GNU)  // for memmem()
-   #define __USE_GNU
-#endif
-#include <string.h>
 #include <sys/types.h>
 #ifdef HAVE_CTYPE_H
    #include <ctype.h>
@@ -40,15 +33,13 @@
 #include "include/ec_logtofile.h"
 #include "include/ec_error.h"
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
 #define MOD_LOG      3
 #define MOD_DROP     2
 #define MOD_REPLACED 1
 #define MOD_ORIG     0
 
+pthread_mutex_t filter_mutex = PTHREAD_MUTEX_INITIALIZER;
+
 DROP_FILTER *Filter_Array_Source;   // ec_main.h
 DROP_FILTER *Filter_Array_Dest;
 int Filter_Source;
@@ -69,7 +60,7 @@ void FilterDrop_DelFilter(DROP_FILTER *ptr, int i);
 void FilterDrop_SaveFilter(void);
 int FilterDrop_CheckMode(DROP_FILTER *ptr, short mode);
 int FilterDrop_MatchPorts(char p, char fp, int s, int fs, int d, int fd);
-int FilterDrop_ParseWildcard(char *dst, char *src);
+int FilterDrop_ParseWildcard(char *dst, char *src, size_t siz);
 int FilterDrop_Validation(DROP_FILTER *ptr);
 int Filter_DoValidate(DROP_FILTER *ptr, short i);
 
@@ -94,6 +85,8 @@ int FilterDrop_MakefilterTCP(u_char *buf_ip, int *buflen, short maxlen, DROP_FIL
    *mod = MOD_ORIG;  // no modification
    if (!filters) return 0;  // no filters... no action...
 
+   pthread_mutex_lock(&filter_mutex);
+
    do
    {
       if ( !FilterDrop_MatchPorts('T', filters[i].proto, ntohs(tcp->source), filters[i].source, ntohs(tcp->dest), filters[i].dest))
@@ -102,7 +95,7 @@ int FilterDrop_MakefilterTCP(u_char *buf_ip, int *buflen, short maxlen, DROP_FIL
       }
       else
       {
-         ret = FilterDrop_DoFilter(data, &datalen, maxlen, &filters[i], &next_filter, mod);
+         ret = FilterDrop_DoFilter(data, &datalen, maxlen*2, &filters[i], &next_filter, mod);
 
          if (*mod == MOD_LOG)    // log the packet
             LogToFile_FilteredData(buf_ip);
@@ -123,6 +116,8 @@ int FilterDrop_MakefilterTCP(u_char *buf_ip, int *buflen, short maxlen, DROP_FIL
 
    *buflen += delta;
 
+   pthread_mutex_unlock(&filter_mutex);
+
    return delta;
 }
 
@@ -145,6 +140,8 @@ int FilterDrop_MakefilterUDP(u_char *buf_ip, int *buflen, short maxlen, DROP_FIL
    *mod = MOD_ORIG;  // no modification
    if (!filters) return 0;  // no filters... no action...
 
+   pthread_mutex_lock(&filter_mutex);
+
    do
    {
       if ( !FilterDrop_MatchPorts('U', filters[i].proto, ntohs(udp->source), filters[i].source, ntohs(udp->dest), filters[i].dest))
@@ -173,6 +170,9 @@ int FilterDrop_MakefilterUDP(u_char *buf_ip, int *buflen, short maxlen, DROP_FIL
    udp->len = htons(ntohs(udp->len) + delta);
 
    *buflen += delta;
+
+   pthread_mutex_unlock(&filter_mutex);
+
    return delta;
 
 }
@@ -312,12 +312,12 @@ int FilterDrop_CheckMode(DROP_FILTER *ptr, short mode)
 
 
 
-int FilterDrop_ParseWildcard(char *dst, char *src)
+int FilterDrop_ParseWildcard(char *dst, char *src, size_t size)
 {
    int j=0, k=0;
    char *p, *q;
 
-   strcpy(dst, src);
+   strlcpy(dst, src, size);
    p = dst;
 
    if ( (q = strstr(p, "*]")) )
@@ -417,6 +417,8 @@ void FilterDrop_AddFilter(DROP_FILTER *ptr)
    Debug_msg("FilterDrop_AddFilter");
 #endif
 
+   pthread_mutex_lock(&filter_mutex);
+
    memset(&newfilter, 0, sizeof(DROP_FILTER));
    newfilter.go_to = -1;
    newfilter.else_go_to = -1;
@@ -435,6 +437,7 @@ void FilterDrop_AddFilter(DROP_FILTER *ptr)
       memcpy(&Filter_Array_Dest[Filter_Dest-1], &newfilter, sizeof(DROP_FILTER));
    }
 
+   pthread_mutex_unlock(&filter_mutex);
 }
 
 
@@ -447,6 +450,8 @@ void FilterDrop_DelFilter(DROP_FILTER *ptr, int i)
    Debug_msg("FilterDrop_DelFilter -- %d", i);
 #endif
 
+   pthread_mutex_lock(&filter_mutex);
+
    if (ptr == Filter_Array_Source)
    {
       num_filter = Filter_Source;
@@ -478,6 +483,8 @@ void FilterDrop_DelFilter(DROP_FILTER *ptr, int i)
       }
    }
 
+   pthread_mutex_unlock(&filter_mutex);
+
 }
 
 
