@@ -17,12 +17,11 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_illithid.c,v 1.15 2001/12/13 18:58:24 alor Exp $
+    $Id: ec_illithid.c,v 1.17 2002/02/11 00:58:17 alor Exp $
 */
 
 #include "include/ec_main.h"
 
-#include <sys/time.h>
 #include <fcntl.h>
 #include <signal.h>
 
@@ -235,7 +234,11 @@ void * Illithid_GetConnections(void *param)
 
    exit_func(Illithid_Reset_Conn);
 
+#ifdef CYGWIN
+   if (illithid_buffer == -1) illithid_buffer = Buffer_Create(5.0e5);   // 500 Kb
+#else
    if (illithid_buffer == -1) illithid_buffer = Buffer_Create(5.0e4);   // 50 Kb
+#endif
    decoder_pid = ECThread_create("decoder", &Illithid_Decoder, NULL);
 
    if (inet_aton(((illithid_param *)param)->IP1p,&addr))
@@ -275,15 +278,22 @@ void * Illithid_GetConnections(void *param)
 
       len = Inet_GetRawPacket(sock, buffer, MTU, &pkttype);
 
+#ifdef PERMIT_PLUGINS
+      if (len > 0) {
+         RAW_PACKET praw;
+
+         praw.buffer = buffer;
+         praw.len = &len;     // the plugin can modify the len of the packet
+
+         Plugin_HookPoint(PCK_RECEIVED_RAW, &praw);     // HOOK POINT: PCK_RECEIVED_RAW
+      }
+#endif
+
       if (len > 0 && ( ((illithid_param *)param)->mode > PUBLICARP || pkttype == PACKET_HOST))
       {
          char PckDir = PCK_DROP;
          int dontforward = 0;
 
-#ifdef PERMIT_PLUGINS
-         Plugin_HookPoint(PCK_RECEIVED_RAW, buffer);     // HOOK POINT: PCK_RECEIVED_RAW
-#endif
-
          memset(&data_to_ettercap, 0, sizeof(CONNECTION));
          memset(&sniff_data_to_ettercap, 0, sizeof(SNIFFED_DATA));
          Act_Connection_Mode = Connection_Mode;
@@ -413,6 +423,8 @@ void * Illithid_GetConnections(void *param)
 
                   if (tcp_datalen < 0 || ntohs(ip->t_len) > len) goto send;
 
+						tcp_datalen = (tcp_datalen > MAX_DATA) ? MAX_DATA : tcp_datalen;  // don't accept bogus sized packets
+
                   data_to_ettercap.source_port = ntohs(tcp->source);
                   data_to_ettercap.dest_port = ntohs(tcp->dest);
                   data_to_ettercap.source_seq = ntohl(tcp->seq) + tcp_datalen;
@@ -429,7 +441,6 @@ void * Illithid_GetConnections(void *param)
                      sniff_data_to_ettercap.ack_seq = ntohl(tcp->ack_seq);
                      sniff_data_to_ettercap.flags = tcp->flags;
                      sniff_data_to_ettercap.proto = 'T';
-                     tcp_datalen = (tcp_datalen > MAX_DATA) ? MAX_DATA : tcp_datalen;
                      sniff_data_to_ettercap.datasize = tcp_datalen;
                      memset(&sniff_data_to_ettercap.data, 0, sizeof(sniff_data_to_ettercap.data));
                      memcpy(&sniff_data_to_ettercap.data, tcp_data, tcp_datalen);
@@ -473,6 +484,8 @@ void * Illithid_GetConnections(void *param)
 
                   if (udp_datalen < 0 || udp_datalen > len) goto send;
 
+						udp_datalen = (udp_datalen > MAX_DATA) ? MAX_DATA : udp_datalen;   // don't accept bogus sized packets
+
                   data_to_ettercap.source_port = ntohs(udp->source);
                   data_to_ettercap.dest_port = ntohs(udp->dest);
                   data_to_ettercap.proto = 'U';
@@ -483,7 +496,6 @@ void * Illithid_GetConnections(void *param)
                      sniff_data_to_ettercap.source_port = ntohs(udp->source);
                      sniff_data_to_ettercap.dest_port = ntohs(udp->dest);
                      sniff_data_to_ettercap.proto = 'U';
-                     udp_datalen = (udp_datalen > MAX_DATA) ? MAX_DATA : udp_datalen;
                      sniff_data_to_ettercap.datasize = udp_datalen;
                      memset(&sniff_data_to_ettercap.data, 0, sizeof(sniff_data_to_ettercap.data));
                      memcpy(&sniff_data_to_ettercap.data, udp_data, udp_datalen);
