@@ -17,16 +17,23 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet.c,v 1.15 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_inet.c,v 1.17 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
 
-#include <sys/time.h>
+#ifdef CYGWIN
+   #define _SYS_TIME_H_    // windows voodoo  (C) Gigi Sullivan
+#endif
+#include <sys/wait.h>
+#ifdef CYGWIN
+   #undef _SYS_TIME_H_
+#endif
+
 #include <sys/ioctl.h>
 #include <fcntl.h>
 #include <signal.h>
-#include <sys/wait.h>
+
 
 #ifndef WAIT_ANY
    #define WAIT_ANY       (-1)    /* Any process.  */
@@ -48,13 +55,22 @@ typedef struct {
    struct host_list *next;
 } host_list;
 
-struct ifreq old_ifr;         // old iface flags
 #ifdef LINUX
+   struct ifreq old_ifr;      // old iface flags
    char IpForward_status;     // old ipforward status
 #else
    int IpForward_status;      // old ipforward status
 #endif
 
+#ifdef CYGWIN
+typedef struct sh {
+   SOCKET fd;
+   struct sockaddr_in sin;
+} socket_handle;
+#else
+typedef int socket_handle;
+#endif
+
 // protos...
 
 char * Inet_HostName(char *ip);
@@ -65,19 +81,22 @@ char * Inet_MyMACAddress(void);
 char * Inet_MySubnet(void);
 int Inet_HostInLAN(void);
 void Inet_Free_list(host_list *head);
-host_list *Inet_Host_in_LAN_list(char *interface);
+host_list *Inet_Host_in_LAN_list(char *iface);
 SniffingHost *Inet_NoSniff(void);
 void Inet_PutMACinString(char *mac_string, unsigned char *MAC);
 int Inet_GetMACfromString(char *mac_string, unsigned char *MAC);
 int Inet_Fake_Host(void);
 int Inet_CheckSwitch(void);
-int Inet_OpenSocket(char *host, short port);
-int Inet_Http_Send(int s, char *payload);
-int Inet_Http_Receive(int s, char *payload, size_t size);
 int Inet_SendLargeTCPPacket(int sock, char *buffer, int len, int MTU);
 int Inet_Load_Host_List(void);
 char * Inet_Save_Host_List(void);
 
+socket_handle Inet_OpenSocket(char *host, short port);
+int Inet_CloseSocket(socket_handle sh);
+int Inet_Http_Send(socket_handle sh, char *payload);
+int Inet_Http_Receive(socket_handle sh, char *payload, size_t size);
+
+
 // Following are architecture dependent !! implementations are in ./src/`uname`/ec_inet_`uname`.c
 int Inet_FindIFace(char *iface);
 int Inet_CorrectIface(char *iface);
@@ -102,7 +121,7 @@ char *Inet_MacFromIP(unsigned long ip);
 // Architecture dependent implemetation of Inet functions...
 
 #ifdef LINUX
-	#include "OS/linux/ec_inet_linux.c"
+   #include "OS/linux/ec_inet_linux.c"
 #endif
 #if defined (FREEBSD) || defined (OPENBSD) || defined (NETBSD)
    #include "OS/BSD/ec_inet_BSD.c"
@@ -113,6 +132,9 @@ char *Inet_MacFromIP(unsigned long ip);
 #ifdef SOLARIS
    #include "OS/solaris/ec_inet_solaris.c"
 #endif
+#ifdef CYGWIN
+   #include "OS/windows/ec_inet_cygwin.c"
+#endif
 
 // ----------------------------------------
 
@@ -142,15 +164,23 @@ char * Inet_HostName(char *ip)   // returns hostname from ip
 char * Inet_NameToIp(char *name) // returns ip from hostname
 {
    struct hostent *host;
+   struct in_addr addr;
    static char ip[16];
 
-   host = gethostbyname(name);
-	memset(ip, 0, sizeof(ip));
+   memset(ip, 0, sizeof(ip));
 
-   if (host != NULL)
-      strlcpy(ip, inet_ntoa( *(struct in_addr *) *host->h_addr_list), 16);
-   else
-      Error_msg("Invalid host address %s !!", name);
+   if ((addr.s_addr = inet_addr(name)) == -1) {
+      host = gethostbyname(name);
+
+      if (host != NULL) {
+         strlcpy(ip, inet_ntoa( *(struct in_addr *) *host->h_addr_list), 16);
+         return ip;
+      }
+      else
+         Error_msg("Invalid host address %s !!", name);
+   }
+
+   strlcpy(ip, inet_ntoa( addr ), 16);
 
    return ip;
 }
@@ -363,7 +393,7 @@ void Inet_Free_list(host_list *head)
 
 
 
-host_list *Inet_Host_in_LAN_list(char *interface)
+host_list *Inet_Host_in_LAN_list(char *iface)
 {
    int sock, N_hosts, i, MTU;
    u_long NetMask, BroadAdd, IP_to_use;
@@ -382,9 +412,9 @@ host_list *Inet_Host_in_LAN_list(char *interface)
 
    head->next = NULL;
 
-   sock = Inet_OpenRawSock(interface);
+   sock = Inet_OpenRawSock(iface);
 
-   Inet_GetIfaceInfo(interface, &MTU, head->MAC_Add, &head->IP_Add, &NetMask);
+   Inet_GetIfaceInfo(iface, &MTU, head->MAC_Add, &head->IP_Add, &NetMask);
 
    if (Options.silent)
    {
@@ -933,53 +963,96 @@ void Inet_PutMACinString(char *mac_string, unsigned char *MAC)
 }
 
 
-int Inet_OpenSocket(char *host, short port)
+socket_handle Inet_OpenSocket(char *host, short port)
 {
    struct hostent *infh;
    struct sockaddr_in sa_in;
-   int s;
+   socket_handle sh;
+#ifdef CYGWIN
+   WSADATA wsdata;
+#endif
 
 #ifdef DEBUG
    Debug_msg("Inet_OpenSocket -- host [%s] port [%d]", host, port);
 #endif
 
+#ifdef CYGWIN
+   if ( WSAStartup(MAKEWORD(2, 2), &wsdata) != 0)
+      ERROR_MSG("Cannot inizialize winsock WSAStartup()");
+#endif
+
    bzero((char*)&sa_in, sizeof(sa_in));
    sa_in.sin_family = AF_INET;
-   sa_in.sin_port=htons(port);
+   sa_in.sin_port = htons(port);
 
    if( (infh = gethostbyname(host)) )
       bcopy(infh->h_addr, (char*)&sa_in.sin_addr, infh->h_length);
    else
    {
       if ( (sa_in.sin_addr.s_addr = inet_addr(host)) == -1 )
-         return -1;
+         ERROR_MSG("Addresses doesn't mach");
    }
 
-   if ( (s = socket(AF_INET, SOCK_STREAM, 0)) < 0)
+#ifdef CYGWIN
+   if ( (sh.fd = socket(AF_INET, SOCK_STREAM, 0)) < 0)
+#else
+   if ( (sh = socket(AF_INET, SOCK_STREAM, 0)) < 0)
+#endif
       ERROR_MSG("socket()");
    else
    {
-      if ( connect(s, (struct sockaddr *)&sa_in, sizeof(sa_in)) < 0)
+#ifdef CYGWIN
+      if ( connect(sh.fd, (struct sockaddr *)&sa_in, sizeof(sa_in)) < 0)
+#else
+      if ( connect(sh, (struct sockaddr *)&sa_in, sizeof(sa_in)) < 0)
+#endif
          Error_msg("Can't connect to %s on port %d | %s\n\n", host, port, strerror(errno));
    }
-   return s;
+
+#ifdef CYGWIN
+   sh.sin = sa_in;
+#endif
+
+   return sh;
+}
+
+
+int Inet_CloseSocket(socket_handle sh)
+{
+#ifdef DEBUG
+   Debug_msg("Inet_CloseSocket");
+#endif
+
+#ifdef CYGWIN
+   WSACleanup();
+   return closesocket(sh.fd);
+#else
+   return close(sh);
+#endif
+
+}
+
+
+int Inet_Http_Send(socket_handle sh, char *payload)
+{
+#ifdef CYGWIN
+   return sendto(sh.fd, (const char *)payload, strlen(payload), 0, (struct sockaddr *)&sh.sin, sizeof(sh.sin));
+#else
+   return write(sh, payload, strlen(payload));
+#endif
 }
 
 
 
-int Inet_Http_Send(int s, char *payload)
+int Inet_Http_Receive(socket_handle sh, char *payload, size_t size)
 {
-   return write(s, payload, strlen(payload));
-}
-
-
-
-int Inet_Http_Receive(int s, char *payload, size_t size)
-{
-   int i=0;
-
-   while( i < size && read(s, payload + i++, 1) );
-
+   int i = 0;
+#ifdef CYGWIN
+   int foo;
+   while( i < size && recvfrom(sh.fd, payload + i++, 1, 0, (struct sockaddr *)&sh.sin, &foo) );
+#else
+   while( i < size && read(sh, payload + i++, 1) );
+#endif
    return i;
 }
 
