@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_inet_forge.c,v 1.3 2001/11/19 09:30:23 alor Exp $
+    $Id: ec_inet_forge.c,v 1.4 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -112,7 +112,7 @@ int Inet_Forge_ip( u_char *buf, u_long src, u_long dst, u_short len, u_short ide
 
    ip.h_len           = 5;                             // 20 byte header
    ip.version         = 4;                             // version 4
-   ip.tos             = 0;                             // IP tos
+   ip.tos             = 7;                             // IP tos     // we need 7 to enable GRE sniffing/injecting
    ip.t_len           = htons(IP_HEADER + len);        // total length
    ip.ident           = htons(ident);                  // IP ident
    ip.frag_and_flags  = htons(f_f);                    // fragmentation flags
