@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface.c,v 1.10 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_interface.c,v 1.11 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -32,7 +32,7 @@
 
 #include <stdarg.h>
 
-#ifdef HAVE_TERMIOS_H
+#if defined (HAVE_TERMIOS_H) && !defined(CYGWIN)
    #include <termios.h>
    struct termios original_term_info;
 #endif
@@ -281,7 +281,7 @@ void Interface_InitScreen(void)
    Debug_msg("Interface_InitScreen");
 #endif
 
-#ifdef HAVE_TERMIOS_H
+#if defined (HAVE_TERMIOS_H) && !defined(CYGWIN)
    tcgetattr(0, &original_term_info);
 #endif
 
@@ -289,6 +289,15 @@ void Interface_InitScreen(void)
    cbreak();
    noecho();
 
+#ifdef CYGWIN
+   LINES = 25;
+   COLS = 80;
+#endif
+
+#ifdef DEBUG
+   Debug_msg("Interface_InitScreen -- screen size %dx%d", LINES, COLS);
+#endif
+
    ScreenMode = 1;
 
    Interface_GetWindowSize();
@@ -329,12 +338,19 @@ void Interface_InitScreen(void)
    werase(bottom_window);
    werase(main_window);
 
+#ifndef CYGWIN
    wattrset(bottom_window, A_BOLD);
+#endif
 
    keypad(main_window,1);
 
+#ifdef DEBUG
+   Debug_msg("Interface_InitScreen -- INIZIALIZED");
+#endif
+
    Interface_Redraw();     // touch the screen and call doupdate()
    Interface_InitList();
+
 }
 
 
@@ -1082,16 +1098,25 @@ void Interface_Run(void)
 
          case 'A':
          case 'a':
+                  Options.arpsniff = 1;
+                  Options.sniff = 0;
+                  Options.macsniff = 0;
                   Interface_Connect();
                   break;
 
          case 'S':
          case 's':
+                  Options.arpsniff = 0;
+                  Options.sniff = 1;
+                  Options.macsniff = 0;
                   Interface_OldStyleSniff(0);
                   break;
 
          case 'M':
          case 'm':
+                  Options.arpsniff = 0;
+                  Options.sniff = 0;
+                  Options.macsniff = 1;
                   Interface_OldStyleSniff(1);
                   break;
 
@@ -1229,7 +1254,7 @@ void Interface_CloseScreen(void)
    refresh();
    endwin();
 
-#ifdef HAVE_TERMIOS_H
+#if defined (HAVE_TERMIOS_H) && !defined(CYGWIN)
    tcsetattr(0, TCSANOW, &original_term_info);
 #endif
 
