@@ -17,21 +17,18 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_factory.c,v 1.2 2001/08/30 10:05:19 alor Exp $
+    $Id: ec_interface_factory.c,v 1.6 2001/12/09 20:24:51 alor Exp $
 */
 
 #include "include/ec_main.h"
 
 #ifdef HAVE_NCURSES  // don't compile if ncurses interface is not supported
 
-#include <string.h>
 #ifdef HAVE_NCURSES_H
    #include <ncurses.h>
 #else
    #include <curses.h>
 #endif
-#include <stdlib.h>
-#include <unistd.h>
 #ifdef HAVE_CTYPE_H
    #include <ctype.h>
 #endif
@@ -39,8 +36,6 @@
    #include <form.h>
 #endif
 
-
-
 #include "include/ec_interface.h"
 #include "include/ec_error.h"
 #include "include/ec_inet_forge.h"
@@ -50,10 +45,6 @@
 #ifdef HAVE_FORM
    #include "include/ec_interface_form.h"
 #endif
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
 
 #define BOTTOM_COLOR 1        // color schemes
 #define TITLE_COLOR  2
@@ -324,21 +315,21 @@ int Interface_Factory_TCP(u_char *buf)
    if (!Conn_Between_Hosts)
    {
       char port[5];
-      sprintf(port, "%d", Host_Source.port);
+      snprintf(port, sizeof(port), "%d", Host_Source.port);
       set_field_buffer(tcp_form[3], 0, port);
-      sprintf(port, "%d", Host_Dest.port);
+      snprintf(port, sizeof(port), "%d", Host_Dest.port);
       set_field_buffer(tcp_form[5], 0, port);
    }
    else
    {
       char tmp[10];
-      sprintf(tmp, "%d", Conn_Between_Hosts[Conn_Pointer].source_port);
+      snprintf(tmp, sizeof(tmp), "%d", Conn_Between_Hosts[Conn_Pointer].source_port);
       set_field_buffer(tcp_form[3], 0, tmp);
-      sprintf(tmp, "%d", Conn_Between_Hosts[Conn_Pointer].dest_port);
+      snprintf(tmp, sizeof(tmp), "%d", Conn_Between_Hosts[Conn_Pointer].dest_port);
       set_field_buffer(tcp_form[5], 0, tmp);
-      sprintf(tmp, "%lx", Conn_Between_Hosts[Conn_Pointer].source_seq);
+      snprintf(tmp, sizeof(tmp), "%lx", Conn_Between_Hosts[Conn_Pointer].source_seq);
       set_field_buffer(tcp_form[7], 0, tmp);
-      sprintf(tmp, "%lx", Conn_Between_Hosts[Conn_Pointer].dest_seq);
+      snprintf(tmp, sizeof(tmp), "%lx", Conn_Between_Hosts[Conn_Pointer].dest_seq);
       set_field_buffer(tcp_form[9], 0, tmp);
    }
 
@@ -362,7 +353,7 @@ int Interface_Factory_TCP(u_char *buf)
       ip = (IP_header *) (buf - IP_HEADER);     // we assume no IP Options !!
       tcp = (TCP_header *) buf;
 
-      memset(tmp, 0, 8*50 + 5);
+      memset(tmp, 0, sizeof(tmp));
       memcpy(tmp, field_buffer(tcp_form[19], 0), 50);
       trim_buffer(tmp, ' ');
       if (strlen(tmp) != 0)   // load from file
@@ -389,7 +380,7 @@ int Interface_Factory_TCP(u_char *buf)
       }
       else
       {
-         memset(tmp, 0, 8*50 + 5);
+         memset(tmp, 0, sizeof(tmp));
          memcpy(tmp, field_buffer(tcp_form[17], 0), 8*50);
          trim_buffer(tmp, ' ');
          datalen = FilterDrop_strescape(payload, tmp);
@@ -500,17 +491,17 @@ int Interface_Factory_UDP(u_char *buf)
    if (!Conn_Between_Hosts)
    {
       char port[5];
-      sprintf(port, "%d", Host_Source.port);
+      snprintf(port, sizeof(port), "%d", Host_Source.port);
       set_field_buffer(udp_form[3], 0, port);
-      sprintf(port, "%d", Host_Dest.port);
+      snprintf(port, sizeof(port), "%d", Host_Dest.port);
       set_field_buffer(udp_form[5], 0, port);
    }
    else
    {
       char tmp[10];
-      sprintf(tmp, "%d", Conn_Between_Hosts[Conn_Pointer].source_port);
+      snprintf(tmp, sizeof(tmp), "%d", Conn_Between_Hosts[Conn_Pointer].source_port);
       set_field_buffer(udp_form[3], 0, tmp);
-      sprintf(tmp, "%d", Conn_Between_Hosts[Conn_Pointer].dest_port);
+      snprintf(tmp, sizeof(tmp), "%d", Conn_Between_Hosts[Conn_Pointer].dest_port);
       set_field_buffer(udp_form[5], 0, tmp);
    }
 
@@ -533,7 +524,7 @@ int Interface_Factory_UDP(u_char *buf)
       ip = (IP_header *) (buf - IP_HEADER);     // we assume no IP Options !!
       udp = (UDP_header *) buf;
 
-      memset(tmp, 0, 8*50 + 5);
+      memset(tmp, 0, sizeof(tmp));
       memcpy(tmp, field_buffer(udp_form[12], 0), 50);
       trim_buffer(tmp, ' ');
       if (strlen(tmp) != 0)   // load from file
@@ -560,7 +551,7 @@ int Interface_Factory_UDP(u_char *buf)
       }
       else
       {
-         memset(tmp, 0, 8*50 + 5);
+         memset(tmp, 0, sizeof(tmp));
          memcpy(tmp, field_buffer(udp_form[10], 0), 8*50);
          trim_buffer(tmp, ' ');
          datalen = FilterDrop_strescape(payload, tmp);
@@ -644,7 +635,7 @@ int Interface_Factory_RAW(u_char *buf)
 
       ip = (IP_header *) (buf - IP_HEADER);     // we assume no IP Options !!
 
-      memset(tmp, 0, 8*50 + 5);
+      memset(tmp, 0, sizeof(tmp));
       memcpy(tmp, field_buffer(raw_form[5], 0), 50);
       trim_buffer(tmp, ' ');
       if (strlen(tmp) != 0)   // load from file
@@ -671,7 +662,7 @@ int Interface_Factory_RAW(u_char *buf)
       }
       else
       {
-         memset(tmp, 0, 14*50 + 5);
+         memset(tmp, 0, sizeof(tmp));
          memcpy(tmp, field_buffer(raw_form[3], 0), 14*50);
          trim_buffer(tmp, ' ');
          datalen = FilterDrop_strescape(payload, tmp);
@@ -731,13 +722,13 @@ int Interface_Factory_ETH(u_char *buf)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, MACS, 17);
+   wgetnstr(w_factory, MACS, sizeof(MACS)-1);
 
    wprintw(w_factory, "\nDest MAC   : ");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, MACD, 17);
+   wgetnstr(w_factory, MACD, sizeof(MACD)-1);
 
    if ( MACS[0] == 'q' || MACD[0] == 'q')
    {
@@ -816,7 +807,7 @@ int Interface_Factory_IP(u_char *buf, short *proto)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, IPS, 16);
+   wgetnstr(w_factory, IPS, sizeof(IPS)-1);
 
    if ( IPS[0] == 'q' || IPS[0] == 'Q')
    {
@@ -828,7 +819,7 @@ int Interface_Factory_IP(u_char *buf, short *proto)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, IPD, 16);
+   wgetnstr(w_factory, IPD, sizeof(IPD)-1);
 
    if ( IPD[0] == 'q' || IPD[0] == 'Q')
    {
@@ -840,25 +831,25 @@ int Interface_Factory_IP(u_char *buf, short *proto)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, ident, 4);
+   wgetnstr(w_factory, ident, sizeof(ident)-1);
 
    wprintw(w_factory, "\nTTL   : 0x");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, TTL, 2);
+   wgetnstr(w_factory, TTL, sizeof(TTL)-1);
 
    wprintw(w_factory, "\nProto (06 = TCP, 11 = UDP) : 0x");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, protocol, 2);
+   wgetnstr(w_factory, protocol, sizeof(protocol)-1);
 
    wprintw(w_factory, "\nChecksum (leave blank for auto) : 0x");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, checksum, 4);
+   wgetnstr(w_factory, checksum, sizeof(checksum)-1);
 
       ip = (IP_header *) buf;
 
@@ -937,7 +928,7 @@ int Interface_Factory_TCP(u_char *buf)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, S, 5);
+   wgetnstr(w_factory, S, sizeof(S)-1);
 
    if ( S[0] == 'q' || S[0] == 'Q')
    {
@@ -949,7 +940,7 @@ int Interface_Factory_TCP(u_char *buf)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, D, 5);
+   wgetnstr(w_factory, D, sizeof(D)-1);
 
    if ( D[0] == 'q' || D[0] == 'Q')
    {
@@ -961,43 +952,43 @@ int Interface_Factory_TCP(u_char *buf)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, seq, 8);
+   wgetnstr(w_factory, seq, sizeof(seq)-1);
 
    wprintw(w_factory, "\nAcknowledgement Number : 0x");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, ack, 8);
+   wgetnstr(w_factory, ack, sizeof(ack)-1);
 
    wprintw(w_factory, "\nFlags (S/A/P/F/R) : ");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, cflags, 5);
+   wgetnstr(w_factory, cflags, sizeof(cflags)-1);
 
    wprintw(w_factory, "\nChecksum (leave blank for auto) : 0x");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, checksum, 4);
+   wgetnstr(w_factory, checksum, sizeof(checksum)-1);
 
    wprintw(w_factory, "\nPayload : ");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, payload, 8*50);
+   wgetnstr(w_factory, payload, sizeof(payload));
 
    wprintw(w_factory, "\nOr load Payload from file : ");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, file, 50);
+   wgetnstr(w_factory, file, sizeof(file)-1);
 
       ip = (IP_header *) (buf - IP_HEADER);     // we assume no IP Options !!
       tcp = (TCP_header *) buf;
 
-      memset(tmp, 0, 8*50 + 5);
-      memcpy(tmp, file, 8*50);
+      memset(tmp, 0, sizeof(tmp));
+      memcpy(tmp, file, sizeof(file));
       if (strlen(tmp) != 0)   // load from file
       {
          FILE *fts;
@@ -1022,7 +1013,7 @@ int Interface_Factory_TCP(u_char *buf)
       }
       else
       {
-         memset(tmp, 0, 8*50 + 5);
+         memset(tmp, 0, sizeof(tmp));
          memcpy(tmp, payload, 8*50);
          datalen = FilterDrop_strescape(payload, tmp);
       }
@@ -1130,7 +1121,7 @@ int Interface_Factory_UDP(u_char *buf)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, S, 5);
+   wgetnstr(w_factory, S, sizeof(S)-1);
 
    if ( S[0] == 'q' || S[0] == 'Q')
    {
@@ -1142,7 +1133,7 @@ int Interface_Factory_UDP(u_char *buf)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, D, 5);
+   wgetnstr(w_factory, D, sizeof(D)-1);
 
    if ( D[0] == 'q' || D[0] == 'Q')
    {
@@ -1155,25 +1146,25 @@ int Interface_Factory_UDP(u_char *buf)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, checksum, 4);
+   wgetnstr(w_factory, checksum, sizeof(checksum)-1);
 
    wprintw(w_factory, "\nPayload : ");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, payload, 8*50);
+   wgetnstr(w_factory, payload, sizeof(payload));
 
    wprintw(w_factory, "\nOr load Payload from file : ");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, file, 50);
+   wgetnstr(w_factory, file, sizeof(file)-1);
 
       ip = (IP_header *) (buf - IP_HEADER);     // we assume no IP Options !!
       udp = (UDP_header *) buf;
 
-      memset(tmp, 0, 8*50 + 5);
-      memcpy(tmp, file, 8*50);
+      memset(tmp, 0, sizeof(tmp));
+      memcpy(tmp, file, sizeof(file));
       if (strlen(tmp) != 0)   // load from file
       {
          FILE *fts;
@@ -1198,7 +1189,7 @@ int Interface_Factory_UDP(u_char *buf)
       }
       else
       {
-         memset(tmp, 0, 8*50 + 5);
+         memset(tmp, 0, sizeof(tmp));
          memcpy(tmp, payload, 8*50);
          datalen = FilterDrop_strescape(payload, tmp);
       }
@@ -1269,18 +1260,18 @@ int Interface_Factory_RAW(u_char *buf)
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, payload, 14*50);
+   wgetnstr(w_factory, payload, sizeof(payload));
 
    wprintw(w_factory, "\nOr load Payload from file : ");
       wnoutrefresh(f_win);
       wnoutrefresh(w_factory);
       doupdate();
-   wgetnstr(w_factory, file, 14*50);
+   wgetnstr(w_factory, file, sizeof(file)-1);
 
       ip = (IP_header *) (buf - IP_HEADER);     // we assume no IP Options !!
 
-      memset(tmp, 0, 14*50 + 5);
-      memcpy(tmp, file, 14*50);
+      memset(tmp, 0, sizeof(tmp));
+      memcpy(tmp, file, sizeof(file));
       if (strlen(tmp) != 0)   // load from file
       {
          FILE *fts;
@@ -1305,7 +1296,7 @@ int Interface_Factory_RAW(u_char *buf)
       }
       else
       {
-         memset(tmp, 0, 14*50 + 5);
+         memset(tmp, 0, sizeof(tmp));
          memcpy(tmp, payload, 14*50);
          datalen = FilterDrop_strescape(payload, tmp);
       }
@@ -1398,3 +1389,4 @@ cancelled:
 #endif   // HAVE_NCURSES
 
 /* EOF */
+
