@@ -17,21 +17,18 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_inject.c,v 1.2 2001/08/30 10:05:19 alor Exp $
+    $Id: ec_interface_inject.c,v 1.7 2001/12/09 20:24:51 alor Exp $
 */
 
 #include "include/ec_main.h"
 
 #ifdef HAVE_NCURSES  // don't compile if ncurses interface is not supported
 
-#include <string.h>
 #ifdef HAVE_NCURSES_H
    #include <ncurses.h>
 #else
    #include <curses.h>
 #endif
-#include <unistd.h>
-#include <stdlib.h>
 #ifdef HAVE_CTYPE_H
    #include <ctype.h>
 #endif
@@ -40,7 +37,6 @@
 #endif
 
 
-
 #include "include/ec_interface.h"
 #include "include/ec_interface_sniff_data.h"
 #include "include/ec_decodedata.h"
@@ -51,11 +47,6 @@
    #include "include/ec_interface_form.h"
 #endif
 
-#ifdef DEBUG
-   #include "include/ec_debug.h"
-#endif
-
-
 #define BOTTOM_COLOR 1        // color schemes
 #define TITLE_COLOR  2
 #define MAIN_COLOR   3
@@ -157,7 +148,8 @@ int Interface_Inject_Run(u_char *inject_data, char proto, char *app)
    wnoutrefresh(inject_window);
    doupdate();
 
-   mvwgetnstr(inject_window, 1, 0, inject_sequence, MAX_INJECT);
+   wmove(inject_window, 1, 0);
+   wgetnstr(inject_window, inject_sequence, MAX_INJECT-1);
 
 #ifdef DEBUG
    Debug_msg("Interface_Inject_Run -- inject_sequence len -- [%d]", strlen(inject_sequence));
@@ -317,7 +309,6 @@ skip:
                               break;
                         }
                      filter_on_source = (filter_on_source) ? 0 : 1;
-                     write(pipe_filter[1], "S", 1);
                   }
 
                   Interface_Inject_FilterStatus();
@@ -355,7 +346,6 @@ skip:
                               break;
                         }
                      filter_on_dest = (filter_on_dest) ? 0 : 1;
-                     write(pipe_filter[1], "D", 1);
                   }
 
                   Interface_Inject_FilterStatus();
@@ -363,6 +353,7 @@ skip:
 
          case 'W':
          case 'w':
+                  filter_on_source = 0;
                   Interface_Inject_EditFilters(Filter_Array_Source);
                      switch(FilterDrop_Validation(Filter_Array_Source))
                      {
@@ -391,6 +382,7 @@ skip:
 
          case 'E':
          case 'e':
+                  filter_on_dest = 0;
                   Interface_Inject_EditFilters(Filter_Array_Dest);
                      switch(FilterDrop_Validation(Filter_Array_Dest))
                      {
@@ -424,7 +416,6 @@ skip:
          case KEY_F(10):
          case 'Q':
          case 'q':
-                  write(pipe_filter[1], "R", 1);  // refresh illithid filters
                   delwin(f_win);
                   delwin(filter_window);
                   doupdate();
@@ -484,22 +475,22 @@ int Interface_Inject_Filter(DROP_FILTER *filters)
       sprintf(tmp, "UDP");
    set_field_buffer(f[1], 0, tmp);
 
-   sprintf(tmp, "%d",  filters[Fil_Pointer].source);
+   snprintf(tmp, sizeof(tmp), "%d",  filters[Fil_Pointer].source);
    set_field_buffer(f[3], 0, tmp);
-   sprintf(tmp, "%d",  filters[Fil_Pointer].dest);
+   snprintf(tmp, sizeof(tmp), "%d",  filters[Fil_Pointer].dest);
    set_field_buffer(f[5], 0, tmp);
    set_field_buffer(f[7], 0, filters[Fil_Pointer].display_search);
-   sprintf(tmp, "%c",  filters[Fil_Pointer].type);
+   snprintf(tmp, sizeof(tmp), "%c",  filters[Fil_Pointer].type);
    set_field_buffer(f[9], 0, tmp);
    set_field_buffer(f[11], 0, filters[Fil_Pointer].display_replace);
 
-   sprintf(tmp, "%d",  filters[Fil_Pointer].go_to);
+   snprintf(tmp, sizeof(tmp), "%d",  filters[Fil_Pointer].go_to);
    if (!strcmp(tmp, "-1"))
       set_field_buffer(f[13], 0, "   ");
    else
       set_field_buffer(f[13], 0, tmp);
 
-   sprintf(tmp, "%d",  filters[Fil_Pointer].else_go_to);
+   snprintf(tmp, sizeof(tmp), "%d",  filters[Fil_Pointer].else_go_to);
    if (!strcmp(tmp, "-1"))
       set_field_buffer(f[15], 0, "   ");
    else
@@ -516,6 +507,8 @@ int Interface_Inject_Filter(DROP_FILTER *filters)
    {
       char tmp_search[MAX_FILTER+1];
 
+      pthread_mutex_lock(&filter_mutex);
+
       memset(&filters[Fil_Pointer], 0, sizeof(DROP_FILTER));
 
       memcpy(&filters[Fil_Pointer].proto, field_buffer(f[1], 0), 1);
@@ -526,7 +519,7 @@ int Interface_Inject_Filter(DROP_FILTER *filters)
 
       memcpy(&filters[Fil_Pointer].display_search, field_buffer(f[7], 0), MAX_FILTER);
       trim_buffer(filters[Fil_Pointer].display_search, ' ');
-      filters[Fil_Pointer].wildcard = FilterDrop_ParseWildcard(tmp_search, filters->display_search);
+      filters[Fil_Pointer].wildcard = FilterDrop_ParseWildcard(tmp_search, filters->display_search, sizeof(tmp_search));
       filters[Fil_Pointer].slen = FilterDrop_strescape(filters[Fil_Pointer].search, tmp_search);
 
       memcpy(&filters[Fil_Pointer].display_replace, field_buffer(f[11], 0), MAX_FILTER);
@@ -546,6 +539,8 @@ int Interface_Inject_Filter(DROP_FILTER *filters)
       else
          filters[Fil_Pointer].else_go_to = atoi(field_buffer(f[15], 0));
 
+      pthread_mutex_unlock(&filter_mutex);
+
       status = 1;
    }
 
@@ -595,7 +590,7 @@ int Interface_Inject_Filter(DROP_FILTER *filters)
       wnoutrefresh(e_win);
       wnoutrefresh(edit_window);
       doupdate();
-   wgetnstr(edit_window, tmp, 10);
+   wgetnstr(edit_window, tmp, 5);
    filters[Fil_Pointer].source = atoi(tmp);
 
 
@@ -603,15 +598,15 @@ int Interface_Inject_Filter(DROP_FILTER *filters)
       wnoutrefresh(e_win);
       wnoutrefresh(edit_window);
       doupdate();
-   wgetnstr(edit_window, tmp, 10);
+   wgetnstr(edit_window, tmp, 5);
    filters[Fil_Pointer].dest = atoi(tmp);
 
    wprintw(edit_window, "Search : ");
       wnoutrefresh(e_win);
       wnoutrefresh(edit_window);
       doupdate();
-   wgetnstr(edit_window, filters[Fil_Pointer].display_search, MAX_FILTER);
-   filters[Fil_Pointer].wildcard = FilterDrop_ParseWildcard(tmp_search, filters[Fil_Pointer].display_search);
+   wgetnstr(edit_window, filters[Fil_Pointer].display_search, MAX_FILTER-1);
+   filters[Fil_Pointer].wildcard = FilterDrop_ParseWildcard(tmp_search, filters[Fil_Pointer].display_search, sizeof(tmp_search));
    filters[Fil_Pointer].slen = FilterDrop_strescape(filters[Fil_Pointer].search, tmp_search);
 
    wprintw(edit_window, "\nAction (Drop/Replace/Log) : ");
@@ -627,7 +622,7 @@ int Interface_Inject_Filter(DROP_FILTER *filters)
          wnoutrefresh(e_win);
          wnoutrefresh(edit_window);
          doupdate();
-      wgetnstr(edit_window, filters[Fil_Pointer].display_replace, MAX_FILTER);
+      wgetnstr(edit_window, filters[Fil_Pointer].display_replace, MAX_FILTER-1);
       filters[Fil_Pointer].rlen = FilterDrop_strescape(filters[Fil_Pointer].replace, filters[Fil_Pointer].display_replace);
    }
 
@@ -835,6 +830,10 @@ void Interface_Inject_EditFilters(DROP_FILTER *FA_ptr)
                      Interface_Inject_SetFilter_Redraw();
                      Interface_PopUp("please re-Edit this filter or ettercap will hang up on it !!");
                      Interface_Inject_SetFilter_Redraw();
+                     if (FA_ptr == Filter_Array_Source)  // safe disable the filter chain
+                        filter_on_source = 0;
+                     else
+                        filter_on_dest = 0;
                   }
                   Interface_Inject_EditFilters_InitList(FA_ptr);
                   break;
