@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_passive.c,v 1.11 2001/12/08 11:22:20 alor Exp $
+    $Id: ec_interface_passive.c,v 1.14 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -30,7 +30,6 @@
    #include <curses.h>
 #endif
 
-#include <sys/time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 
@@ -77,7 +76,7 @@ void Interface_Passive_InitList(void);
 void Interface_Passive_RefreshList(void);
 void Interface_Passive_MakeReport(char mode);
 void Interface_Passive_ShowDetails(int i);
-void Interface_Passive_Submit(char *ip, char *fingerprint);
+void Interface_Passive_Submit(int j);
 void Interface_Passive_Showname(void);
 
 // global variables
@@ -411,7 +410,7 @@ void Interface_Passive_ShowDetails(int i)
    KeyPress = wgetch(detail_window);
 
    if (KeyPress == 'f' ||  KeyPress == 'F')
-      Interface_Passive_Submit(Passive_Host[i].ip, Passive_Host[i].fingerprint);
+      Interface_Passive_Submit(i);
 
    if (found)
    {
@@ -475,13 +474,15 @@ void Interface_Passive_Showname(void)
 }
 
 
-void Interface_Passive_Submit(char *ip, char *fingerprint)
+void Interface_Passive_Submit(int j)
 {
    WINDOW *w_submit, *f_win;
    FILE *f_os, *f_temp;
+   char *fingerprint, *ip;
    int dimY = 8;
    int dimX = 70;
-   int sock, i;
+   socket_handle sock;
+   int i;
    char OS[60];
    char getmsg[500];
    char data[100];
@@ -489,9 +490,12 @@ void Interface_Passive_Submit(char *ip, char *fingerprint)
    char page[] = "/index.php?s=stuff&p=fingerprint";
 
 #ifdef DEBUG
-   Debug_msg("Interface_Passive_Submit");
+   Debug_msg("Interface_Passive_Submit -- [%s]", Passive_Host[j].fingerprint);
 #endif
 
+   fingerprint = strdup(Passive_Host[j].fingerprint);
+   ip = strdup(Passive_Host[j].ip);
+
    f_win = newwin(dimY+2, dimX+2, W_BOTTOMY2/2 - dimY/2, W_MAINX2/2 - dimX/2);
    w_submit = newwin(dimY, dimX, W_BOTTOMY2/2 - dimY/2 +1, W_MAINX2/2 - dimX/2 +1);
    wbkgdset(f_win, COLOR_PAIR(HELP_COLOR));
@@ -556,7 +560,7 @@ void Interface_Passive_Submit(char *ip, char *fingerprint)
       return;
 
 #ifdef DEBUG
-   Debug_msg("Interface_Passive_Submit -- %s %s", fingerprint, OS);
+   Debug_msg("Interface_Passive_Submit - remote - %s %s", fingerprint, OS);
 #endif
 
    for (i=0; i<60; i++)
@@ -570,8 +574,7 @@ void Interface_Passive_Submit(char *ip, char *fingerprint)
       wnoutrefresh(w_submit);
       doupdate();
 
-   if ( (sock = Inet_OpenSocket(host, 80)) == -1)     // if the dns fail... use the hard coded IP
-      sock = Inet_OpenSocket("216.136.171.201", 80);
+   sock = Inet_OpenSocket(host, 80);
 
    wprintw(w_submit, "Submitting the fingerprint to %s...\n\n", page);
       wnoutrefresh(f_win);
@@ -587,8 +590,9 @@ void Interface_Passive_Submit(char *ip, char *fingerprint)
    Debug_msg("Interface_Passive_Submit -- %s", getmsg);
 #endif
 
+
    Inet_Http_Send(sock, getmsg);
-   close(sock);
+   Inet_CloseSocket(sock);
 
    wprintw(w_submit, "\nNew fingerprint submitted to the ettercap website...\n");
       wnoutrefresh(f_win);
@@ -598,6 +602,12 @@ void Interface_Passive_Submit(char *ip, char *fingerprint)
    for (i=0; i<60; i++)
       if (OS[i] == '+') OS[i] = ' ';
 
+   strlcpy(Passive_Host[j].os, OS, 60);
+
+#ifdef DEBUG
+   Debug_msg("Interface_Passive_Submit - local - [%s] [%s] [%s]", fingerprint, OS, Passive_Host[j].os);
+#endif
+
    f_os = fopen( "./" OS_FILE, "r");
    if (f_os == NULL)
    {
@@ -609,8 +619,9 @@ void Interface_Passive_Submit(char *ip, char *fingerprint)
    f_temp = tmpfile();
    fchmod(fileno(f_temp), 0700);
 
-   while(fgets (data, 100, f_os))
+   while(fgets (data, 99, f_os))
    {
+
       if ( strchr(data, '#') || !strlen(data))
       {
          fprintf(f_temp, "%s", data);
@@ -653,6 +664,9 @@ void Interface_Passive_Submit(char *ip, char *fingerprint)
    delwin(w_submit);
    doupdate();
 
+   free(fingerprint);
+   free(ip);
+
 }
 
 
