@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_plugins.c,v 1.5 2001/12/08 11:22:20 alor Exp $
+    $Id: ec_interface_plugins.c,v 1.7 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -32,7 +32,6 @@
 #endif
 
 
-#include <sys/time.h>
 #include <ctype.h>
 
 #include "include/ec_interface.h"
@@ -543,6 +542,7 @@ void Interface_Plugins_Output(void)
          Interface_Plugins_PluginOutput();
          pnoutrefresh(output_window, scroll_out_yp, 0, 1, 2, W_MAINY2-1 , W_MAINX2 - 2);
          doupdate();
+         usleep(5000);
       }
    }
 
