@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_sniff.c,v 1.11 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_interface_sniff.c,v 1.13 2002/02/11 20:31:56 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -30,8 +30,6 @@
    #include <curses.h>
 #endif
 
-#include <sys/time.h>
-
 #include "include/ec_interface.h"
 #include "include/ec_interface_sniff_data.h"
 #include "include/ec_interface_factory.h"
@@ -669,6 +667,7 @@ void Interface_Sniff_Run(short mode)
                         delwin(message_window);
                         touchwin(main_window);
                         wnoutrefresh(main_window);
+                        inject = 0;
                      }
                      #ifdef DEBUG
                         Debug_msg("Interface_Sniff_END");
