@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_interface_sniff_data.c,v 1.8 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_interface_sniff_data.c,v 1.10 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -30,9 +30,7 @@
    #include <curses.h>
 #endif
 
-#include <sys/time.h>
 #include <sys/types.h>
-#include <time.h>
 
 #include "include/ec_interface.h"
 #include "include/ec_interface_inject.h"
@@ -62,44 +60,52 @@
 #define ASCII_VIEW   0        // data in the sniffing windows...
 #define HEX_VIEW     1
 #define TEXT_VIEW    2
+#define JOINED_VIEW  3
 
 // protos...
 
-void Interface_Sniff_Data_Run(char *ips, int portsource, char *ipd, int portdest, char *macs, char *macd, char proto, char *type, short mode);
+void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char *macs, char *macd, char proto, char *type, short mode);
 void Interface_Sniff_Data_Redraw(void);
-void Interface_Sniff_Data_KeyTab(char *ipsource, int portsource, char *ipdest, int portdest);
+void Interface_Sniff_Data_KeyTab(void);
 void Interface_Sniff_Data_SniffData(void);
-void Interface_Sniff_Data_LogToFile(char proto, char *ipsource, int portsource, char *ipdest, int portdest);
+void Interface_Sniff_Data_LogToFile(char proto);
 void Interface_Sniff_Data_Winch(void);
 void Interface_Sniff_Data_StopCont(void);
 void Interface_Sniff_Data_View(short mode);
 void Interface_Sniff_Data_Scroll(short direction);
 void Interface_Sniff_Data_DrawScroller(void);
-void Interface_Sniff_Data_Inject(char proto, char *app, char *ipsource, short portsource, char *ipdest, short portdest);
-void Interface_Sniff_Data_Kill(char proto, char *ipsource, short portsource, char *ipdest, short portdest);
+void Interface_Sniff_Data_Inject(char proto, char *app);
+void Interface_Sniff_Data_Kill(char proto);
 
 // global variables
 
 extern WINDOW *main_window, *bottom_window, *top_window;
 WINDOW *data_source_win, *data_dest_win, *data_source, *data_dest;
 WINDOW *win_pointer;
+WINDOW *data_joined_win, *data_joined;
+
 
 extern int W_MAINX1, W_MAINY1, W_MAINX2, W_MAINY2;
 extern int W_BOTTOMY2;
 
 extern int Conn_Pointer;
 
-short log_source, log_dest;
+short log_source, log_dest, log_joined;
 short view;
 short stop = 0;
 short inject = 0;
+short joined = 0;
 
 int inject_tod=0, inject_tos=0;
 
-short scroll_yd = 0, scroll_ys = 0;
+short scroll_yd = 0, scroll_ys = 0, scroll_yj = 0;
 
-FILE *file_source, *file_dest;
+FILE *file_source, *file_dest, *file_joined;
 
+char ipsource[16];
+char ipdest[16];
+u_short portsource;
+u_short portdest;
 
 //---------------------------
 
@@ -122,22 +128,33 @@ void Interface_Sniff_Data_Redraw(void)
    Debug_msg("Interface_Sniff_Data_Redraw");
 #endif
 
-   redrawwin(data_dest_win);
-   redrawwin(data_source_win);
+   if (joined)
+   {
+      redrawwin(data_joined_win);
 
-   wnoutrefresh(data_dest_win);
-   wnoutrefresh(data_source_win);
-   pnoutrefresh(data_source, scroll_ys,0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 / 2 - 2);
-   pnoutrefresh(data_dest, scroll_yd,0, W_MAINY1 + 3, W_MAINX2 / 2 + 2, W_MAINY2 - 3 , W_MAINX2 - 2);
+      wnoutrefresh(data_joined_win);
+      pnoutrefresh(data_joined, scroll_yj, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 4);
+   }
+   else
+   {
+      redrawwin(data_dest_win);
+      redrawwin(data_source_win);
+
+      wnoutrefresh(data_dest_win);
+      wnoutrefresh(data_source_win);
+      pnoutrefresh(data_source, scroll_ys, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 / 2 - 2);
+      pnoutrefresh(data_dest, scroll_yd, 0, W_MAINY1 + 3, W_MAINX2 / 2 + 2, W_MAINY2 - 3 , W_MAINX2 - 2);
+   }
 
    doupdate();
 }
 
 
 
-void Interface_Sniff_Data_KeyTab(char *ipsource, int portsource, char *ipdest, int portdest)
+void Interface_Sniff_Data_KeyTab(void)
 {
 
+   if (joined) return;     // TAB isnt necessary in joined view
 
    win_pointer = (win_pointer == data_source_win) ? data_dest_win : data_source_win;
 
@@ -194,11 +211,11 @@ void Interface_Sniff_Data_KeyTab(char *ipsource, int portsource, char *ipdest, i
 
 
 
-void Interface_Sniff_Data_LogToFile(char proto, char *ipsource, int portsource, char *ipdest, int portdest)
+void Interface_Sniff_Data_LogToFile(char proto)
 {
    WINDOW *question_window;
    char question[100];
-   char filename[50];
+   char filename[60];
    char answer;
    time_t tt;
    struct tm *dd;
@@ -213,65 +230,95 @@ void Interface_Sniff_Data_LogToFile(char proto, char *ipsource, int portsource,
 
    snprintf(date, sizeof(date), "%04d%02d%02d", dd->tm_year+1900, dd->tm_mon+1, dd->tm_mday);
 
-   if (win_pointer == data_source_win)
+   if (joined)
    {
-      strcpy(question, "Do U want to log SOURCE-to-DEST to this file ? (y/n)");
-      snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d.log", date, proto, ipsource, portsource, ipdest, portdest);
+      strcpy(question, "Do U want to log the trafic to this file ? (y/n)");
+      snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d-FULL.log", date, proto, ipsource, portsource, ipdest, portdest);
    }
    else
    {
-      strcpy(question, "Do U want to log DEST-to-SOURCE to this file ? (y/n)");
-      snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d.log", date, proto, ipdest, portdest, ipsource, portsource);
+      if (win_pointer == data_source_win)
+      {
+         strcpy(question, "Do U want to log SOURCE-to-DEST to this file ? (y/n)");
+         snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d.log", date, proto, ipsource, portsource, ipdest, portdest);
+      }
+      else
+      {
+         strcpy(question, "Do U want to log DEST-to-SOURCE to this file ? (y/n)");
+         snprintf(filename, sizeof(filename), "%s-%c-%s:%d-%s:%d.log", date, proto, ipdest, portdest, ipsource, portsource);
+      }
    }
 
-   question_window = newwin(7, strlen(question) + 4,0,0);
-   mvwin(question_window, W_MAINY1+(W_MAINY2-W_MAINY1)/2-2, W_MAINX2/2 - (strlen(question)+4)/2 );
+   question_window = newwin(7, strlen(question) + 8,0,0);
+   mvwin(question_window, W_MAINY1+(W_MAINY2-W_MAINY1)/2-2, W_MAINX2/2 - (strlen(question)+8)/2 );
    wbkgdset(question_window, COLOR_PAIR(TITLE_COLOR));
    wattron(question_window, A_BOLD);
    box(question_window,ACS_VLINE,ACS_HLINE);
-   mvwprintw(question_window,  2, 2, "%s", question);
+   mvwprintw(question_window,  2, 4, "%s", question);
    wnoutrefresh(question_window);
    doupdate();
 
    wbkgdset(question_window, COLOR_PAIR(HELP_COLOR));
-   mvwprintw(question_window,  4, 4, "%s", filename);
+   if (joined) mvwprintw(question_window,  4, 2, "%s", filename);
+   else mvwprintw(question_window,  4, 6, "%s", filename);
    answer = wgetch(question_window);
    delwin(question_window);
 
    if ( (answer == 'y') || (answer == 'Y') )
    {
-      if (win_pointer == data_source_win)
+      if (joined)
       {
-         file_source = fopen(filename, "a");
-         if (file_source == NULL)
+         file_joined = fopen(filename, "a");
+         if (file_joined == NULL)
             ERROR_MSG("fopen()");
-         log_source = 1;
-         mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 / 2 - 10, "LOGGED");
+         log_joined = 1;
+         mvwprintw(data_joined_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 - 15, "LOGGED");
       }
       else
       {
-         file_dest = fopen(filename, "a");
-         if (file_dest == NULL)
-            ERROR_MSG("fopen()");
-         log_dest = 1;
-         mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 / 2 - 10, "LOGGED");
+         if (win_pointer == data_source_win)
+         {
+            file_source = fopen(filename, "a");
+            if (file_source == NULL)
+               ERROR_MSG("fopen()");
+            log_source = 1;
+            mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 / 2 - 10, "LOGGED");
+         }
+         else
+         {
+            file_dest = fopen(filename, "a");
+            if (file_dest == NULL)
+               ERROR_MSG("fopen()");
+            log_dest = 1;
+            mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 / 2 - 10, "LOGGED");
+         }
       }
    }
    else
    {
-      if (win_pointer == data_source_win)
+      if (joined)
       {
-         if (log_source) fclose(file_source);
-         log_source = 0;
-         wmove(data_source_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 / 2 - 10);
-         whline(data_source_win, ACS_HLINE, 6);
+         if (log_joined) fclose(file_joined);
+         log_joined = 0;
+         wmove(data_joined_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 - 15);
+         whline(data_joined_win, ACS_HLINE, 6);
       }
       else
       {
-         if (log_dest) fclose(file_dest);
-         log_dest = 0;
-         wmove(data_dest_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 / 2 - 10);
-         whline(data_dest_win, ACS_HLINE, 6);
+         if (win_pointer == data_source_win)
+         {
+            if (log_source) fclose(file_source);
+            log_source = 0;
+            wmove(data_source_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 / 2 - 10);
+            whline(data_source_win, ACS_HLINE, 6);
+         }
+         else
+         {
+            if (log_dest) fclose(file_dest);
+            log_dest = 0;
+            wmove(data_dest_win, W_MAINY2 - W_MAINY1 - 4, W_MAINX2 / 2 - 10);
+            whline(data_dest_win, ACS_HLINE, 6);
+         }
       }
    }
 
@@ -295,25 +342,51 @@ void Interface_Sniff_Data_StopCont(void)
 
    if (stop == 0)
    {
-      mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2, "STOPPED");
-      mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2, "STOPPED");
+      if (joined)
+      {
+         mvwprintw(data_joined_win, W_MAINY2 - W_MAINY1 - 4, 2, "STOPPED");
+      }
+      else
+      {
+         mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2, "STOPPED");
+         mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2, "STOPPED");
+      }
       stop = 1;
    }
    else
    {
-      wmove(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_source_win, ACS_HLINE, 7);
-      wmove(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2); whline(data_dest_win, ACS_HLINE, 7);
+      if (joined)
+      {
+         wmove(data_joined_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_joined_win, ACS_HLINE, 7);
+      }
+      else
+      {
+         wmove(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_source_win, ACS_HLINE, 7);
+         wmove(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2); whline(data_dest_win, ACS_HLINE, 7);
+      }
+
       Interface_Sniff_Data_View(view);
       stop = 0;
    }
 
-   redrawwin(data_dest_win);
-   redrawwin(data_source_win);
 
-   wnoutrefresh(data_dest_win);
-   wnoutrefresh(data_source_win);
-   pnoutrefresh(data_source, scroll_ys,0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 / 2 - 2);
-   pnoutrefresh(data_dest, scroll_yd,0, W_MAINY1 + 3, W_MAINX2 / 2 + 2, W_MAINY2 - 3 , W_MAINX2 - 2);
+   if (joined)
+   {
+      redrawwin(data_joined_win);
+
+      wnoutrefresh(data_joined_win);
+      pnoutrefresh(data_joined, scroll_yj, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 4);
+   }
+   else
+   {
+      redrawwin(data_dest_win);
+      redrawwin(data_source_win);
+
+      wnoutrefresh(data_dest_win);
+      wnoutrefresh(data_source_win);
+      pnoutrefresh(data_source, scroll_ys, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 / 2 - 2);
+      pnoutrefresh(data_dest, scroll_yd, 0, W_MAINY1 + 3, W_MAINX2 / 2 + 2, W_MAINY2 - 3 , W_MAINX2 - 2);
+   }
 
    doupdate();
 
@@ -331,35 +404,118 @@ void Interface_Sniff_Data_View(short mode)
    switch(mode)
    {
       case ASCII_VIEW:
-                        wmove(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_source_win, ACS_HLINE, 7);
-                        wmove(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2); whline(data_dest_win, ACS_HLINE, 7);
-                        mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2, "ASCII");
-                        mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2, "ASCII");
+                        if (joined)
+                        {
+                           wmove(data_joined_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_joined_win, ACS_HLINE, 7);
+                           mvwprintw(data_joined_win, W_MAINY2 - W_MAINY1 - 4, 2, "ASCII");
+                        }
+                        else
+                        {
+                           wmove(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_source_win, ACS_HLINE, 7);
+                           wmove(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2); whline(data_dest_win, ACS_HLINE, 7);
+                           mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2, "ASCII");
+                           mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2, "ASCII");
+                        }
                         break;
+
       case HEX_VIEW:
-                        wmove(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_source_win, ACS_HLINE, 7);
-                        wmove(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2); whline(data_dest_win, ACS_HLINE, 7);
-                        mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2, "HEX");
-                        mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2, "HEX");
+                        if (joined)
+                        {
+                           wmove(data_joined_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_joined_win, ACS_HLINE, 7);
+                           mvwprintw(data_joined_win, W_MAINY2 - W_MAINY1 - 4, 2, "HEX");
+                        }
+                        else
+                        {
+                           wmove(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_source_win, ACS_HLINE, 7);
+                           wmove(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2); whline(data_dest_win, ACS_HLINE, 7);
+                           mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2, "HEX");
+                           mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2, "HEX");
+                        }
                         break;
 
       case TEXT_VIEW:
-                        wmove(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_source_win, ACS_HLINE, 7);
-                        wmove(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2); whline(data_dest_win, ACS_HLINE, 7);
-                        mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2, "TEXT");
-                        mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2, "TEXT");
+                        if (joined)
+                        {
+                           wmove(data_joined_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_joined_win, ACS_HLINE, 7);
+                           mvwprintw(data_joined_win, W_MAINY2 - W_MAINY1 - 4, 2, "TEXT");
+                        }
+                        else
+                        {
+                           wmove(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2);   whline(data_source_win, ACS_HLINE, 7);
+                           wmove(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2); whline(data_dest_win, ACS_HLINE, 7);
+                           mvwprintw(data_source_win, W_MAINY2 - W_MAINY1 - 4, 2, "TEXT");
+                           mvwprintw(data_dest_win, W_MAINY2 - W_MAINY1 - 4, 2, "TEXT");
+                        }
+                        break;
+
+      case JOINED_VIEW:
+                        if (joined)
+                        {
+                           joined = 0;
+                           delwin(data_joined_win);
+                           delwin(data_joined);
+
+                           redrawwin(main_window);
+                           redrawwin(data_dest_win);
+                           redrawwin(data_source_win);
+
+                           wnoutrefresh(main_window);
+                           wnoutrefresh(data_dest_win);
+                           wnoutrefresh(data_source_win);
+
+                           pnoutrefresh(data_source, scroll_ys,0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 / 2 - 2);
+                           pnoutrefresh(data_dest, scroll_yd,0, W_MAINY1 + 3, W_MAINX2 / 2 + 2, W_MAINY2 - 3 , W_MAINX2 - 2);
+
+                           doupdate();
+                        }
+                        else
+                        {
+                           joined = 1;
+
+                           data_joined_win = newwin(W_MAINY2 - W_MAINY1 - 3, W_MAINX2 - 4, W_MAINY1 + 2, 2);
+                           data_joined = newpad(PAD_BUFFER, W_MAINX2 - 6);
+
+                           wbkgdset(data_joined_win, COLOR_PAIR(SNIFF_COLOR));
+                           wattron(data_joined_win, A_BOLD);
+                           box(data_joined_win, ACS_VLINE, ACS_HLINE);
+                           mvwprintw(data_joined_win, 0, 1, "%s:%d - %s:%d", ipsource, portsource, ipdest, portdest);
+                           scroll_yj = PAD_BUFFER - (W_MAINY2-10);
+                           mvwprintw(data_joined_win, 0, W_MAINX2 - 15, "JOINED");
+                           scrollok(data_joined_win, TRUE);
+                           wmove(data_joined, scroll_yj, 0);
+
+                           wnoutrefresh(data_joined_win);
+                           pnoutrefresh(data_joined, scroll_yj, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 4);
+                           doupdate();
+
+                           Interface_Sniff_Data_DrawScroller();
+                           Interface_Sniff_Data_View(ASCII_VIEW);
+
+                        }
+
+                        return;
                         break;
    }
 
    view = mode;
 
-   redrawwin(data_dest_win);
-   redrawwin(data_source_win);
+   if (joined)
+   {
+      redrawwin(data_joined_win);
 
-   wnoutrefresh(data_dest_win);
-   wnoutrefresh(data_source_win);
-   pnoutrefresh(data_source, scroll_ys,0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 / 2 - 2);
-   pnoutrefresh(data_dest, scroll_yd,0, W_MAINY1 + 3, W_MAINX2 / 2 + 2, W_MAINY2 - 3 , W_MAINX2 - 2);
+      wnoutrefresh(data_joined_win);
+      pnoutrefresh(data_joined, scroll_yj, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 4);
+   }
+   else
+   {
+      redrawwin(data_dest_win);
+      redrawwin(data_source_win);
+
+      wnoutrefresh(data_dest_win);
+      wnoutrefresh(data_source_win);
+      pnoutrefresh(data_source, scroll_ys, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 / 2 - 2);
+      pnoutrefresh(data_dest, scroll_yd, 0, W_MAINY1 + 3, W_MAINX2 / 2 + 2, W_MAINY2 - 3 , W_MAINX2 - 2);
+   }
 
    doupdate();
 
@@ -380,7 +536,44 @@ void Interface_Sniff_Data_SniffData(void)
        return;
    }
 
-   if ( current_illithid_data.source_ip == data_from_illithid.fast_source_ip)
+   if (joined)
+   {
+      if (log_joined) { write(fileno(file_joined), &data_from_illithid.data, data_from_illithid.datasize); fflush(file_joined);}
+      if (!stop)
+      {
+         if ( current_illithid_data.source_ip == data_from_illithid.fast_source_ip)
+            wbkgdset(data_joined, COLOR_PAIR(TITLE_COLOR));
+         else
+            wbkgdset(data_joined, COLOR_PAIR(BOTTOM_COLOR));
+
+         switch (view)
+         {
+            case ASCII_VIEW:
+                           wprintw(data_joined, "%s", Decodedata_GetAsciiData(data_from_illithid.data, data_from_illithid.datasize));
+                           pnoutrefresh(data_joined, scroll_yj,0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 4);
+                           break;
+
+            case TEXT_VIEW:
+                           wprintw(data_joined, "%s", Decodedata_GetTextData(data_from_illithid.data, data_from_illithid.datasize));
+                           pnoutrefresh(data_joined, scroll_yj,0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 4);
+                           break;
+
+            case HEX_VIEW:
+                           if (data_from_illithid.proto == 'T')
+                              wprintw(data_joined, "\n> S %lx A %lx (%s) <\n%s",
+                                                data_from_illithid.seq,
+                                                data_from_illithid.ack_seq,
+                                                Decodedata_TCPFlags(data_from_illithid.flags),
+                                                Decodedata_GetHexData(data_from_illithid.data, data_from_illithid.datasize, W_MAINX2/2 - 4));
+                           else
+                              wprintw(data_joined, "%s", Decodedata_GetHexData(data_from_illithid.data, data_from_illithid.datasize, W_MAINX2/2 - 4));
+
+                           pnoutrefresh(data_joined, scroll_yj,0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 4);
+                           break;
+         }
+      }
+   }
+   else if ( current_illithid_data.source_ip == data_from_illithid.fast_source_ip)
    {
       if (log_source) { write(fileno(file_source), &data_from_illithid.data, data_from_illithid.datasize); fflush(file_source);}
       if (!stop)
@@ -450,6 +643,7 @@ void Interface_Sniff_Data_DrawScroller(void)
    short sheight = (W_MAINY2-10)*(W_MAINY2-10)/PAD_BUFFER;
    short svpos = (W_MAINY2-6)*scroll_ys/PAD_BUFFER;
    short dvpos = (W_MAINY2-6)*scroll_yd/PAD_BUFFER;
+   short jvpos = (W_MAINY2-6)*scroll_yj/PAD_BUFFER;
 
    sheight = (sheight < 1) ? 1 : sheight;
 
@@ -459,19 +653,33 @@ void Interface_Sniff_Data_DrawScroller(void)
    dvpos = (dvpos == 0) ? 1 : dvpos;
    dvpos = (dvpos > W_MAINY2-9-sheight) ? W_MAINY2-9-sheight : dvpos;
 
+   jvpos = (jvpos == 0) ? 1 : jvpos;
+   jvpos = (jvpos > W_MAINY2-9-sheight) ? W_MAINY2-9-sheight : jvpos;
+
    wattron(win_pointer, A_BOLD);
 
-   mvwvline(data_source_win, 1, W_MAINX2 / 2 - 3, ACS_VLINE, W_MAINY2-10);
-   wattron(data_source_win, A_REVERSE);
-   mvwvline(data_source_win, svpos, W_MAINX2 / 2 - 3, ' ', sheight);
-   wnoutrefresh(data_source_win);
-   wattroff(data_source_win, A_REVERSE);
+   if (joined)
+   {
+      mvwvline(data_joined_win, 1, W_MAINX2 - 5, ACS_VLINE, W_MAINY2-10);
+      wattron(data_joined_win, A_REVERSE);
+      mvwvline(data_joined_win, jvpos, W_MAINX2 - 5, ' ', sheight);
+      wnoutrefresh(data_joined_win);
+      wattroff(data_joined_win, A_REVERSE);
+   }
+   else
+   {
+      mvwvline(data_source_win, 1, W_MAINX2 / 2 - 3, ACS_VLINE, W_MAINY2-10);
+      wattron(data_source_win, A_REVERSE);
+      mvwvline(data_source_win, svpos, W_MAINX2 / 2 - 3, ' ', sheight);
+      wnoutrefresh(data_source_win);
+      wattroff(data_source_win, A_REVERSE);
 
-   mvwvline(data_dest_win, 1, W_MAINX2 / 2 - 3, ACS_VLINE, W_MAINY2-10);
-   wattron(data_dest_win, A_REVERSE);
-   mvwvline(data_dest_win, dvpos, W_MAINX2 / 2 - 3, ' ', sheight);
-   wnoutrefresh(data_dest_win);
-   wattroff(data_dest_win, A_REVERSE);
+      mvwvline(data_dest_win, 1, W_MAINX2 / 2 - 3, ACS_VLINE, W_MAINY2-10);
+      wattron(data_dest_win, A_REVERSE);
+      mvwvline(data_dest_win, dvpos, W_MAINX2 / 2 - 3, ' ', sheight);
+      wnoutrefresh(data_dest_win);
+      wattroff(data_dest_win, A_REVERSE);
+   }
 
 }
 
@@ -479,21 +687,33 @@ void Interface_Sniff_Data_DrawScroller(void)
 void Interface_Sniff_Data_Scroll(short direction)
 {
 
-   if (win_pointer == data_source_win)
+   if (joined)
    {
-      scroll_ys += direction;
-      scroll_ys = (scroll_ys < 0) ? 0 : scroll_ys;
-      scroll_ys = (scroll_ys > PAD_BUFFER - (W_MAINY2-10)) ? PAD_BUFFER - (W_MAINY2-10) : scroll_ys;
-      pnoutrefresh(data_source, scroll_ys,0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 / 2 - 2);
+      scroll_yj += direction;
+      scroll_yj = (scroll_yj < 0) ? 0 : scroll_yj;
+      scroll_yj = (scroll_yj > PAD_BUFFER - (W_MAINY2-10)) ? PAD_BUFFER - (W_MAINY2-10) : scroll_yj;
+      pnoutrefresh(data_joined, scroll_yj, 0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 - 4);
       Interface_Sniff_Data_DrawScroller();
    }
    else
    {
-      scroll_yd += direction;
-      scroll_yd = (scroll_yd < 0) ? 0 : scroll_yd;
-      scroll_yd = (scroll_yd > PAD_BUFFER - (W_MAINY2-10)) ? PAD_BUFFER - (W_MAINY2-10) : scroll_yd;
-      pnoutrefresh(data_dest, scroll_yd,0, W_MAINY1 + 3, W_MAINX2 / 2 + 2, W_MAINY2 - 3 , W_MAINX2 - 2);
-      Interface_Sniff_Data_DrawScroller();
+
+      if (win_pointer == data_source_win)
+      {
+         scroll_ys += direction;
+         scroll_ys = (scroll_ys < 0) ? 0 : scroll_ys;
+         scroll_ys = (scroll_ys > PAD_BUFFER - (W_MAINY2-10)) ? PAD_BUFFER - (W_MAINY2-10) : scroll_ys;
+         pnoutrefresh(data_source, scroll_ys,0, W_MAINY1 + 3, 3, W_MAINY2 - 3 , W_MAINX2 / 2 - 2);
+         Interface_Sniff_Data_DrawScroller();
+      }
+      else
+      {
+         scroll_yd += direction;
+         scroll_yd = (scroll_yd < 0) ? 0 : scroll_yd;
+         scroll_yd = (scroll_yd > PAD_BUFFER - (W_MAINY2-10)) ? PAD_BUFFER - (W_MAINY2-10) : scroll_yd;
+         pnoutrefresh(data_dest, scroll_yd,0, W_MAINY1 + 3, W_MAINX2 / 2 + 2, W_MAINY2 - 3 , W_MAINX2 - 2);
+         Interface_Sniff_Data_DrawScroller();
+      }
    }
 
    doupdate();
@@ -501,7 +721,7 @@ void Interface_Sniff_Data_Scroll(short direction)
 
 
 
-void Interface_Sniff_Data_Inject(char proto, char *app, char *ipsource, short portsource, char *ipdest, short portdest)
+void Interface_Sniff_Data_Inject(char proto, char *app)
 {
 
    INJECTED_DATA inject_data;
@@ -511,6 +731,13 @@ void Interface_Sniff_Data_Inject(char proto, char *app, char *ipsource, short po
    Debug_msg("Interface_Sniff_Data_Inject");
 #endif
 
+   if (joined)
+   {
+      Interface_PopUp("Injection not possible while in JOINED view");
+      Interface_Sniff_Data_Redraw();
+      return;
+   }
+
    memset(&inject_data, 0, sizeof(INJECTED_DATA));
 
    data_len = Interface_Inject_Run(inject_data.data, proto, app);
@@ -566,7 +793,7 @@ void Interface_Sniff_Data_Inject(char proto, char *app, char *ipsource, short po
 
 
 
-void Interface_Sniff_Data_Kill(char proto, char *ipsource, short portsource, char *ipdest, short portdest)
+void Interface_Sniff_Data_Kill(char proto)
 {
    KILL_DATA kill_data;
 
@@ -595,7 +822,7 @@ void Interface_Sniff_Data_Kill(char proto, char *ipsource, short portsource, cha
 
 
 
-void Interface_Sniff_Data_Run(char *ips, int portsource, char *ipd, int portdest, char *macs, char *macd, char proto, char *type, short mode)
+void Interface_Sniff_Data_Run(char *ips, int psource, char *ipd, int pdest, char *macs, char *macd, char proto, char *type, short mode)
 {
    int KeyPress;
    int dimY = W_MAINY2 - W_MAINY1 - 3;
@@ -603,14 +830,15 @@ void Interface_Sniff_Data_Run(char *ips, int portsource, char *ipd, int portdest
    fd_set msk_fd;
    struct timeval TimeOut;
    struct in_addr addr;
-   char ipsource[16];
-   char ipdest[16];
    char macsource[20];
    char macdest[20];
    char app[18];
 
    strlcpy(ipsource, ips, sizeof(ipsource));     // save locally because other threads can
-   strlcpy(ipdest, ipd, sizeof(ipdest));       // realloc the array containing these values
+   strlcpy(ipdest, ipd, sizeof(ipdest));         // realloc the array containing these values
+   portsource = psource;
+   portdest = pdest;
+
    strlcpy(macsource, macs, sizeof(macsource));
    strlcpy(macdest, macd, sizeof(macdest));
    strlcpy(app, type, sizeof(app));
@@ -741,7 +969,7 @@ void Interface_Sniff_Data_Run(char *ips, int portsource, char *ipd, int portdest
 
             case 'L':
             case 'l':
-                  Interface_Sniff_Data_LogToFile(proto, ipsource, portsource, ipdest, portdest);
+                  Interface_Sniff_Data_LogToFile(proto);
                   break;
 
             case 'A':
@@ -759,6 +987,11 @@ void Interface_Sniff_Data_Run(char *ips, int portsource, char *ipd, int portdest
                   Interface_Sniff_Data_View(TEXT_VIEW);
                   break;
 
+            case 'J':
+            case 'j':
+                  Interface_Sniff_Data_View(JOINED_VIEW);
+                  break;
+
             case 'S':
             case 's':
                   Interface_Sniff_Data_StopCont();
@@ -774,7 +1007,7 @@ void Interface_Sniff_Data_Run(char *ips, int portsource, char *ipd, int portdest
                         Interface_Sniff_Data_Redraw();
                      }
                      else
-                        Interface_Sniff_Data_Inject(proto, app, ipsource, portsource, ipdest, portdest);
+                        Interface_Sniff_Data_Inject(proto, app);
                   }
                   else
                   {
@@ -791,12 +1024,12 @@ void Interface_Sniff_Data_Run(char *ips, int portsource, char *ipd, int portdest
 
             case 'K':
             case 'k':
-                  Interface_Sniff_Data_Kill(proto, ipsource, portsource, ipdest, portdest);
+                  Interface_Sniff_Data_Kill(proto);
                   Interface_Sniff_Data_Redraw();
                   break;
 
             case KEY_TAB:
-                  Interface_Sniff_Data_KeyTab(ipsource, portsource, ipdest, portdest);
+                  Interface_Sniff_Data_KeyTab();
                   break;
 
             case KEY_CTRL_L:  // CTRL+L refresh the screen
@@ -828,6 +1061,7 @@ void Interface_Sniff_Data_Run(char *ips, int portsource, char *ipd, int portdest
                         "[aA]      - ASCII view",
                         "[xX]      - HEX view",
                         "[tT]      - TEXT (readable chars) only view",
+                        "[jJ]      - join the two windows",
                         "[sS]      - stop/cont the sniff (only visualization)",
                         "[lL]      - Log to file",
                         NULL};
@@ -841,13 +1075,20 @@ void Interface_Sniff_Data_Run(char *ips, int portsource, char *ipd, int portdest
             case 'q':
                      if (log_dest) fclose(file_dest);
                      if (log_source) fclose(file_source);
-                     log_dest = log_source = 0;
+                     if (log_joined) fclose(file_joined);
+                     log_dest = log_source = log_joined = 0;
                      stop = 0;
                      inject_tod=0; inject_tos=0;  // reset counter
                      delwin(data_source_win);
                      data_source_win = NULL;    // for winching (see ec_signal.c)
                      wbkgdset(bottom_window, COLOR_PAIR(BOTTOM_COLOR));
                      mvwhline(top_window, 2, 55, ' ', 20);
+                     if (joined)
+                     {
+                        delwin(data_joined_win);
+                        delwin(data_joined);
+                        joined = 0;
+                     }
                      delwin(data_dest_win);
                      delwin(data_source);
                      delwin(data_dest);
