@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_logtofile.c,v 1.6 2001/12/05 16:24:29 alor Exp $
+    $Id: ec_logtofile.c,v 1.7 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -187,6 +187,20 @@ char *LogToFile_DumpPass(void)
             fprintf(fto, "\n%s\n", Conn_Between_Hosts[i].info);
          fflush(fto);
       }
+      else if (strlen(Conn_Between_Hosts[i].info))
+      {
+         fprintf(fto, "\n\n%s:%d -> %s:%d\t\t%s\n\n", Conn_Between_Hosts[i].source_ip,
+                                                      Conn_Between_Hosts[i].source_port,
+                                                      Conn_Between_Hosts[i].dest_ip,
+                                                      Conn_Between_Hosts[i].dest_port,
+                                                      Conn_Between_Hosts[i].type
+                                                      );
+         fprintf(fto, "USER : \n");
+         fprintf(fto, "PASS : \n");
+         if (strlen(Conn_Between_Hosts[i].info))
+            fprintf(fto, "\n%s\n", Conn_Between_Hosts[i].info);
+         fflush(fto);
+      }
    }
 
    fclose(fto);
