@@ -17,13 +17,13 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_main.c,v 1.15 2001/12/08 16:38:43 alor Exp $
+    $Id: ec_main.c,v 1.17 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
 
 #include <sys/ioctl.h>
-#ifdef HAVE_TERMIOS_H
+#if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
    #include <termios.h>
 #endif
 #ifdef HAVE_GETOPT_H
@@ -123,7 +123,7 @@ int main(int argc, char *argv[])
    Options.storm_delay = DEFAULT_STORM_DELAY;   // the default delay between arp request on start up (ec_inet)
 
 
-   if (Parser_ParseOptions(argc, argv) == 1) // config file
+   if (Parser_ParseOptions(argc, argv) == 1)    // config file
       Parser_ParseConfFile(optarg);
 
    if (Options.version)
@@ -229,12 +229,17 @@ void Main_Usage(void)
 void Main_Interactive(void)
 {
 #ifdef HAVE_NCURSES
+
+#ifndef CYGWIN
    struct winsize  ws = {0, 0, 0, 0};
 
-#ifdef DEBUG
-   Debug_msg("Main_Interactive");
+   #ifdef DEBUG
+      Debug_msg("Main_Interactive");
+   #endif
+
 #endif
 
+#ifndef CYGWIN
    if ( ioctl(0, TIOCGWINSZ, &ws) < 0)          // syscall for the window size
       Error_msg("ec_main:%d ioctl(TIOCGWINSZ) | ERRNO : %d | %s", __LINE__, errno, strerror(errno));
 
@@ -259,7 +264,9 @@ void Main_Interactive(void)
 
       if (rows < 25 || cols < 80)
          Error_msg("Screen must be at least 25x80 !!");
+
    }
+#endif
 
 #ifdef PERMIT_PLUGINS
    Plugin_LoadAll();
@@ -421,7 +428,11 @@ void Main_Devel_Release(void)
 //   fprintf (stdout, "  but this is NOT for you, so don't blame us for any bugs or problems !\n");
    fprintf (stdout, "==============================================================================\n");
    fprintf (stdout, "\n\n");
-
+// if (!Options.normal)
+// {
+//    fprintf(stdout, "Press return to continue...");
+//    getchar();
+// }
 }
 #endif
 
@@ -429,14 +440,14 @@ void Main_Devel_Release(void)
 void Main_Check_NewRelease(void)
 {
    char answer;
-   int sock;
+   socket_handle sock;
    char *ptr;
    char *latest;
    char getmsg[512];
    char buffer[4096];
    char host[] = "ettercap.sourceforge.net";
    char page[] = "/latest.php";
-//   char host[] = "ghibli.alor.org";
+//   char host[] = "zefiro.alor.org";
 //   char page[] = "/ettercap/latest.php";
 
 #ifdef DEBUG
@@ -483,6 +494,11 @@ void Main_Check_NewRelease(void)
    Debug_msg("Main_Check_NewRelease - ENDRECEIVE -----------------");
 #endif
 
+      Inet_CloseSocket(sock);
+
+      if (!strlen(buffer))
+         Error_msg("The server didn't replied");
+
       ptr = strstr(buffer, "\r\n\r\n") + 4;  // skip the headers.
       if (strncmp(ptr, "LATEST: ", 8))
          Error_msg("Error parsing the response... \n\n");
