@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_parser.c,v 1.15 2001/12/08 16:38:43 alor Exp $
+    $Id: ec_parser.c,v 1.16 2001/12/20 20:09:45 alor Exp $
 */
 
 
@@ -414,11 +414,12 @@ exit_debug:
 
 char * Parser_AddStr(char *list, char *string)
 {
-   list = realloc(list, strlen(list)+strlen(string)+1);
+	int len = strlen(list)+strlen(string)+1;
+
+   list = realloc(list, len);
    if (list == NULL)
       ERROR_MSG("realloc()");
-   strcat(list, string);
-   list[strlen(list)+strlen(string)] = 0;
+   strlcat(list, string, len);
 
    return list;
 }
