@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_plugins.c,v 1.10 2001/12/09 20:24:51 alor Exp $
+    $Id: ec_plugins.c,v 1.12 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -43,12 +43,7 @@
 
 #include <dlfcn.h>
 #include <stdarg.h>
-#include <sys/time.h>
 #include <dirent.h>
-#ifdef SOLARIS
-   #include "./missing/scandir.h"
-#endif
-
 
 #include "include/ec_plugins.h"
 #include "include/ec_error.h"
