@@ -17,14 +17,18 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_signal.c,v 1.3 2001/11/19 09:30:23 alor Exp $
+    $Id: ec_signal.c,v 1.4 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
 
 #include <signal.h>
-#include <sys/time.h>
-#include <sys/resource.h>
+
+#ifndef CYGWIN
+	#include <sys/resource.h>
+#endif
+
+
 
 #ifdef HAVE_NCURSES
    #ifdef HAVE_NCURSES_H
@@ -41,6 +45,9 @@
    extern short ScreenMode;
 
    #ifdef HAVE_TERMIOS_H
+      #ifdef CYGWIN
+         #undef FIONBIO
+      #endif
       #include <termios.h>
       extern struct termios original_term_info;
    #endif
@@ -78,7 +85,11 @@ void Signal_SigBuster(void)
 RETSIGTYPE Signal_SEGV(int sig)
 {
 #ifdef DEBUG
+
+#ifndef CYGWIN
    struct rlimit corelimit = {RLIM_INFINITY, RLIM_INFINITY};
+#endif
+
    if (sig == SIGBUS)
       Debug_msg("[%s] Bus Error...", ECThread_getname(pthread_self()) );
    else if (sig == SIGSEGV)
@@ -128,7 +139,10 @@ RETSIGTYPE Signal_SEGV(int sig)
    fprintf(stderr, "\n\033[01m\033[1m Overriding any 'ulimit -c 0'...\n"
                    " Setting core size to RLIM_INFINITY...\n\n"
                    " Core dumping... (use the 'core' file for gdb analysis)\033[0m\n\n");
+#ifndef CYGWIN
    setrlimit(RLIMIT_CORE, &corelimit);
+#endif
+
    signal(sig, SIG_DFL);
    raise(sig);
 #endif
