@@ -17,15 +17,15 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_simple.c,v 1.14 2001/12/08 11:22:20 alor Exp $
+    $Id: ec_simple.c,v 1.15 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
 
 #include <fcntl.h>
-#include <time.h>
-#include <sys/time.h>
-#include <sys/wait.h>
+#ifndef CYGWIN
+	#include <sys/wait.h>
+#endif
 #include <signal.h>
 
 #include "include/ec_error.h"
@@ -45,8 +45,7 @@
 #include "include/ec_dryad.h"
 #include "include/ec_thread.h"
 
-#ifdef HAVE_TERMIOS_H
-
+#if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
    #include <termios.h>
 
    struct termios old_tc;
@@ -319,7 +318,7 @@ void Simple_Demonize(void)
 }
 
 
-#ifdef HAVE_TERMIOS_H
+#if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
 
 void set_raw_term()        // taken from readchar.c, by M. Andreoli (2000)
 {
@@ -521,7 +520,7 @@ void Simple_Run(void)
 
    if(!Options.quiet)
    {
-      #ifdef HAVE_TERMIOS_H
+      #if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
          set_raw_term();   // non blocking stdin... yes this work !!
       #else
          #ifdef DEBUG
@@ -647,7 +646,7 @@ void Simple_Run(void)
 
             case 'Q':
             case 'q':
-#ifdef HAVE_TERMIOS_H
+#if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
                   if(!Options.quiet) reset_term();
 #endif
                   printf("\n\n\nShutting down all threads... ");
@@ -802,7 +801,7 @@ void Simple_PassiveScan(void)
 
    if(!Options.quiet)
    {
-      #ifdef HAVE_TERMIOS_H
+      #if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
          set_raw_term();   // non blocking stdin... yes this work !!
       #else
          #ifdef DEBUG
@@ -917,7 +916,7 @@ void Simple_PassiveScan(void)
 
                case 'Q':
                case 'q':
-#ifdef HAVE_TERMIOS_H
+#if defined (HAVE_TERMIOS_H) && !defined (CYGWIN)
                      if(!Options.quiet) reset_term();
 #endif
                      printf("\n\n\nShutting down all threads... ");
