@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: ec_threads.c,v 1.3 2001/12/08 11:22:20 alor Exp $
+    $Id: ec_threads.c,v 1.4 2002/02/10 10:07:49 alor Exp $
 */
 
 #include "include/ec_main.h"
@@ -114,13 +114,15 @@ void ECThread_destroy(pthread_t id)
 
    pthread_cancel(id);
 
-#ifndef MACOSX
+#if !defined(MACOSX) && !defined(CYGWIN)
    /*
-    *    Mac OS X (darwin 1.3) doesn't support joinable thread
+    *    Mac OS X (darwin 1.3) and the CYGWIN pthreads implementation
+    *    don't support joinable thread
     *    here is only a workaround, because we actually have to
     *    wait for the cancellation function (for example rearp in
     *    doppleganger)
-    *    FIXME:  urgency high !!
+    *
+    *    XXX - FIXME:  urgency high !!
     */
 
    pthread_join(id, NULL);
