@@ -1,4 +1,7 @@
 
+#if !defined(EC_DECODEDATA_H)
+#define EC_DECODEDATA_H
+
 extern void Decodedata_SetArrayIndex(CONNECTION *data, int index);
 extern int Decodedata_MakeConnectionList(CONNECTION *data);
 extern int Decodedata_RefreshConnectionList(void);
@@ -16,4 +19,6 @@ extern char * Decodedata_TCPFlags(char flags);
 extern void Decodedata_ConvertPassiveToHost(void);
 extern void Decodedata_Passive_SortList(void);
 
+#endif
+
 /* EOF */
