@@ -1,10 +1,14 @@
 
+#if !defined(EC_DISSECTOR_H)
+#define EC_DISSECTOR_H
+
+
 // structures....
 
 typedef struct {
    char mode;
    short proto;
-   short port;
+   u_short port;
    int (*dissector)(u_char *, CONNECTION *, SNIFFED_DATA *, int, short);
    char active;
    char name[15];
@@ -70,7 +74,7 @@ extern FUNC_DISSECTOR(Dissector_rlogin);     // 512 513 514
 extern FUNC_DISSECTOR(Dissector_rip);        // 520              UDP
 extern FUNC_DISSECTOR(Dissector_socks);      // 1080
 extern FUNC_DISSECTOR(Dissector_mysql);      // 3306
-extern FUNC_DISSECTOR(Dissector_icq);        // 4000             UDP
+extern FUNC_DISSECTOR(Dissector_icq);        // 4000 5190 ALL_P  UDP
 extern FUNC_DISSECTOR(Dissector_vnc);        // 5900-5905
 extern FUNC_DISSECTOR(Dissector_x11);        // 6000-6005
 extern FUNC_DISSECTOR(Dissector_napster);    // 6666 7777 8888
@@ -82,4 +86,6 @@ extern FUNC_DISSECTOR(Dissector_pcanywhere); // 65301
 extern FUNC_DISSECTOR(Dissector_mountdTCP);
 extern FUNC_DISSECTOR(Dissector_mountdUDP);
 
+#endif
+
 /* EOF */
