@@ -1,4 +1,8 @@
 
+#if !defined(EC_ERROR_H)
+#define EC_ERROR_H
+
+
 #include <errno.h>
 
 extern void Error_msg(char *message, ...);
@@ -6,4 +10,6 @@ extern void Error_critical_msg(char *file, char *function, int line, char *messa
 
 #define ERROR_MSG(x) Error_critical_msg(__FILE__, __FUNCTION__, __LINE__, x)
 
+#endif
+
 /* EOF */
