@@ -1,4 +1,8 @@
 
+#if !defined(EC_FILTERDROP_H)
+#define EC_FILTERDROP_H
+
+
 extern int FilterDrop_MakefilterTCP(u_char *buf_ip, int *buflen, short maxlen, DROP_FILTER *filters, char *mod);
 extern int FilterDrop_MakefilterUDP(u_char *buf_ip, int *buflen, short maxlen, DROP_FILTER *filters, char *mod);
 
@@ -13,4 +17,6 @@ extern int FilterDrop_Validation(DROP_FILTER *ptr);
 
 extern pthread_mutex_t filter_mutex;
 
+#endif
+
 /* EOF */
