@@ -1,4 +1,8 @@
 
+#if !defined(EC_INTERFACE_FORM_H)
+#define EC_INTERFACE_FORM_H
+
+
 extern FIELD *make_label(int frow, int fcol, char *label);
 extern FIELD *make_field(int frow, int fcol, int rows, int cols, bool secure);
 extern void display_form(FORM *f);
@@ -14,4 +18,6 @@ extern void trim_buffer(char *buffer, char trim);
 #define KEY_RETURN   10
 #define KEY_INS      331
 
+#endif
+
 /* EOF */
