@@ -1,4 +1,8 @@
 
+#if !defined(EC_INTERFACE_SNIFF_DATA_H)
+#define EC_INTERFACE_SNIFF_DATA_H
+
+
 extern void Interface_Sniff_Data_Run(char *ips,
                                      int portsource,
                                      char *ipd,
@@ -11,4 +15,6 @@ extern void Interface_Sniff_Data_Run(char *ips,
 extern void Interface_Sniff_Data_Winch(void);
 extern void Interface_Sniff_Data_Redraw(void);
 
+#endif
+
 /* EOF */
