@@ -1,4 +1,8 @@
 
+#if !defined(EC_PARSER_H)
+#define EC_PARSER_H
+
+
 extern void Parser_ParseConfFile(char *filename);
 extern void Parser_ParseParameters(char *first, char *second, char *third, char *fourth);
 extern int Parser_ParseOptions(int counter, char **values);
@@ -8,4 +12,6 @@ extern int match_pattern(const char *s, const char *pattern);
 extern char Parser_Activated_Plugin(char *name);
 extern char *Parser_StrSpacetoUnder(char *h_name);
 
+#endif
+
 /* EOF */
