@@ -1,4 +1,8 @@
 
+#if !defined(EC_PLUGINS_H)
+#define EC_PLUGINS_H
+
+
 struct plugin_ops
 {
    char *ettercap_version;          /* ettercap version MUST be the global VERSION */
@@ -59,4 +63,6 @@ extern void Plugin_Hook_Output(char *message, ...);
 
 #include <string.h>
 
+#endif // EC_PLUGINS_H
+
 /* EOF */
