@@ -1,4 +1,8 @@
 
+#if !defined(EC_SIMPLE_H)
+#define EC_SIMPLE_H
+
+
 #ifdef PERMIT_PLUGINS
 	extern void Simple_Plugin(void);
 #endif
@@ -10,4 +14,6 @@ extern void Simple_CheckForSwitch(void);
 extern void Simple_CreateCertFile(void);
 extern void Simple_PassiveScan(void);
 
+#endif
+
 /* EOF */
